(* Content-type: application/vnd.wolfram.mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 12.0' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       158,          7]
NotebookDataLength[    294665,       5657]
NotebookOptionsPosition[    290941,       5601]
NotebookOutlinePosition[    291372,       5618]
CellTagsIndexPosition[    291329,       5615]
WindowFrame->Normal*)

(* Beginning of Notebook Content *)
Notebook[{

Cell[CellGroupData[{
Cell[TextData[StyleBox["Mitochondrial Fatty Acid Oxidation Kinetic Model \
Extension with SCFAs Regulation",
 FontFamily->"Times New Roman",
 FontSize->36,
 FontWeight->"Bold",
 FontColor->RGBColor[0.5, 0, 0.5]]], "Section",
 CellChangeTimes->{{3.48489837309375*^9, 3.484898374640625*^9}, {
  3.8192046891988864`*^9, 3.8192047161059775`*^9}, {3.819204746453908*^9, 
  3.8192047649743834`*^9}},ExpressionUUID->"49094d9c-edae-41e2-91f5-\
4c7cb9638d14"],

Cell[TextData[StyleBox["Definitions of the various functions(CPT1 and NAD \
production equations are modified to be a function of Acetate concentration \
in the liver: AcetateMAT=0 with out acetate treatment  and AcetateMAT=1 with  \
3 mM acetate treatment)",
 FontSize->24,
 FontWeight->"Bold"]], "Text",
 CellChangeTimes->{{3.48032243746875*^9, 3.48032245315625*^9}, {
  3.480324407984375*^9, 3.48032454875*^9}, {3.480324587125*^9, 
  3.480324613953125*^9}, {3.480326447015625*^9, 3.480326456375*^9}, {
  3.480326786125*^9, 3.4803267875625*^9}, {3.4803298338125*^9, 
  3.48032984396875*^9}, {3.489830575*^9, 3.489830577375*^9}, {
  3.7584598598112946`*^9, 3.758459960082159*^9}, {3.819204901919394*^9, 
  3.8192050033483315`*^9}, {3.819205449105322*^9, 3.819205492230693*^9}},
 FontSize->16,ExpressionUUID->"c6166c54-c9d0-4d06-9d3d-8a939d8a0f72"],

Cell[BoxData[
 RowBox[{
  RowBox[{"CPT1", "[", 
   RowBox[{
   "sf_", ",", "V_", ",", "Kms1_", ",", "Kms2_", ",", "Kmp1_", ",", "Kmp2_", 
    ",", "Ki1_", ",", "Keq_", ",", "S1_", ",", "S2_", ",", "P1_", ",", "P2_", 
    ",", "I1_", ",", "n_", ",", "vsh_", ",", "Kmsh_", ",", "SH1_", ",", 
    "propacetcpt1_", ",", "propacetmal_", ",", "nc_"}], "]"}], ":=", 
  FractionBox[
   RowBox[{"sf", "*", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"1", "+", "SH1"}], ")"}], "*", "V"}], ")"}], "*", 
    RowBox[{"(", 
     RowBox[{
      FractionBox[
       RowBox[{"S1", "*", "S2"}], 
       RowBox[{"Kms1", "*", "Kms2"}]], "-", 
      FractionBox[
       RowBox[{"P1", "*", "P2"}], 
       RowBox[{"Kms1", "*", "Kms2", "*", "Keq"}]]}], ")"}]}], 
   RowBox[{
    RowBox[{"(", 
     RowBox[{"1", "+", 
      FractionBox["S1", "Kms1"], "+", 
      FractionBox["P1", "Kmp1"], "+", 
      SuperscriptBox[
       RowBox[{"(", 
        FractionBox["I1", "Ki1"], ")"}], "n"]}], ")"}], "*", 
    RowBox[{"(", 
     RowBox[{"1", "+", 
      FractionBox["S2", "Kms2"], "+", 
      FractionBox["P2", "Kmp2"]}], ")"}]}]]}]], "Input",
 CellChangeTimes->{{3.758458663032283*^9, 3.758458753480707*^9}, {
   3.758458854484971*^9, 3.758458856346775*^9}, {3.75852115704287*^9, 
   3.758521231532756*^9}, 3.758521927852461*^9, {3.759141994736902*^9, 
   3.759142067364056*^9}, {3.817114333453951*^9, 3.817114358046179*^9}, {
   3.817114535836675*^9, 3.8171145420610266`*^9}, {3.817114601315557*^9, 
   3.8171146310510225`*^9}},
 CellLabel->
  "In[386]:=",ExpressionUUID->"65d74be1-bddb-4b2c-b6c0-8b394e0dc692"],

Cell[BoxData[""], "Input",
 CellChangeTimes->{{3.758521149503621*^9, 3.758521149503621*^9}, {
  3.7585219232246065`*^9, 3.7585219298848877`*^9}},
 CellLabel->
  "In[387]:=",ExpressionUUID->"35c681e9-f798-4ea9-8810-4a0e39bbc00f"],

Cell[BoxData[
 RowBox[{
  RowBox[{"CACT", "[", 
   RowBox[{
   "Vf_", ",", "Vr_", ",", "Kms1_", ",", "Kms2_", ",", "Kmp1_", ",", "Kmp2_", 
    ",", "Kis1_", ",", "Kip2_", ",", "Keq_", ",", "S1_", ",", "S2_", ",", 
    "P1_", ",", "P2_", ",", "vsh_", ",", "Kmsh_", ",", "SH1_", ",", 
    "propacetcact_"}], "]"}], ":=", 
  FractionBox[
   RowBox[{"Vf", "*", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"S1", "*", "S2"}], "-", 
      FractionBox[
       RowBox[{"P1", "*", "P2"}], "Keq"]}], ")"}]}], 
   RowBox[{
    RowBox[{"S1", "*", "S2"}], "+", 
    RowBox[{"Kms2", "*", "S1"}], "+", 
    RowBox[{"Kms1", "*", "S2", "*", 
     RowBox[{"(", 
      RowBox[{"1", "+", 
       FractionBox["P2", "Kip2"]}], ")"}]}], "+", 
    RowBox[{
     FractionBox["Vf", 
      RowBox[{"Vr", "*", "Keq"}]], "*", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"Kmp2", "*", "P1", "*", 
        RowBox[{"(", 
         RowBox[{"1", "+", 
          FractionBox["S1", "Kis1"]}], ")"}]}], "+", 
       RowBox[{"P2", "*", 
        RowBox[{"(", 
         RowBox[{"Kmp1", "+", "P1"}], ")"}]}]}], ")"}]}]}]]}]], "Input",
 CellChangeTimes->{{3.49034989240625*^9, 3.490349893140625*^9}, {
   3.493530624953125*^9, 3.4935307199375*^9}, {3.493531110515625*^9, 
   3.493531189234375*^9}, {3.493531226859375*^9, 3.493531269453125*^9}, {
   3.49353130775*^9, 3.4935313235625*^9}, {3.7584589990804057`*^9, 
   3.7584590396579266`*^9}, 3.8171143901872177`*^9},
 CellLabel->
  "In[388]:=",ExpressionUUID->"1154a7ed-f6cf-40a7-b435-09f31129a382"],

Cell[BoxData[
 RowBox[{
  RowBox[{"CPT2", "[", 
   RowBox[{
   "sf_", ",", "V_", ",", "Kms1_", ",", "Kms2_", ",", "Kms3_", ",", "Kms4_", 
    ",", "Kms5_", ",", "Kms6_", ",", "Kms7_", ",", "Kms8_", ",", "Kmp1_", ",",
     "Kmp2_", ",", "Kmp3_", ",", "Kmp4_", ",", "Kmp5_", ",", "Kmp6_", ",", 
    "Kmp7_", ",", "Kmp8_", ",", "Keq_", ",", "S1_", ",", "S2_", ",", "S3_", 
    ",", "S4_", ",", "S5_", ",", "S6_", ",", "S7_", ",", "S8_", ",", "P1_", 
    ",", "P2_", ",", "P3_", ",", "P4_", ",", "P5_", ",", "P6_", ",", "P7_", 
    ",", "P8_", ",", "vsh_", ",", "Kmsh_", ",", "SH1_", ",", 
    "propacetcpt2_"}], "]"}], ":=", 
  FractionBox[
   RowBox[{"sf", "*", 
    RowBox[{"(", 
     RowBox[{"V", "*", 
      RowBox[{"(", 
       RowBox[{
        FractionBox[
         RowBox[{"S1", "*", "S8"}], 
         RowBox[{"Kms1", "*", "Kms8"}]], "-", 
        FractionBox[
         RowBox[{"P1", "*", "P8"}], 
         RowBox[{"Kms1", "*", "Kms8", "*", "Keq"}]]}], ")"}]}], ")"}]}], 
   RowBox[{
    RowBox[{"(", 
     RowBox[{"1", "+", 
      FractionBox["S1", "Kms1"], "+", 
      FractionBox["P1", "Kmp1"], "+", 
      FractionBox["S2", "Kms2"], "+", 
      FractionBox["P2", "Kmp2"], "+", 
      FractionBox["S3", "Kms3"], "+", 
      FractionBox["P3", "Kmp3"], "+", 
      FractionBox["S4", "Kms4"], "+", 
      FractionBox["P4", "Kmp4"], "+", 
      FractionBox["S5", "Kms5"], "+", 
      FractionBox["P5", "Kmp5"], "+", 
      FractionBox["S6", "Kms6"], "+", 
      FractionBox["P6", "Kmp6"], "+", 
      FractionBox["S7", "Kms7"], "+", 
      FractionBox["P7", "Kmp7"]}], ")"}], "*", 
    RowBox[{"(", 
     RowBox[{"1", "+", 
      FractionBox["S8", "Kms8"], "+", 
      FractionBox["P8", "Kmp8"]}], ")"}]}]]}]], "Input",
 CellChangeTimes->{{3.4903498875625*^9, 3.4903498885625*^9}, 
   3.493531846421875*^9, {3.4935324259375*^9, 3.493532498484375*^9}, {
   3.50857315153125*^9, 3.508573287203125*^9}, {3.508573623421875*^9, 
   3.5085736880625*^9}, {3.7584592866501737`*^9, 3.758459308911831*^9}, {
   3.8171144074031754`*^9, 3.8171144087655287`*^9}, 3.817114742248622*^9},
 CellLabel->
  "In[389]:=",ExpressionUUID->"44cc4dc8-fa5f-47a6-a1fc-480ead1af464"],

Cell[BoxData[
 RowBox[{
  RowBox[{"VLCAD", "[", 
   RowBox[{
   "sf_", ",", "V_", ",", "Kms1_", ",", "Kms2_", ",", "Kms3_", ",", "Kms4_", 
    ",", "Kmp1_", ",", "Kmp2_", ",", "Kmp3_", ",", "Kmp4_", ",", "Keq_", ",", 
    "S1_", ",", "S2_", ",", "S3_", ",", "S4_", ",", "P1_", ",", "P2_", ",", 
    "P3_", ",", "P4_"}], "]"}], ":=", 
  FractionBox[
   RowBox[{"sf", "*", "V", "*", 
    RowBox[{"(", 
     RowBox[{
      FractionBox[
       RowBox[{"S1", "*", 
        RowBox[{"(", 
         RowBox[{"S4", "-", "P4"}], ")"}]}], 
       RowBox[{"Kms1", "*", "Kms4"}]], "-", 
      FractionBox[
       RowBox[{"P1", "*", "P4"}], 
       RowBox[{"Kms1", "*", "Kms4", "*", "Keq"}]]}], ")"}]}], 
   RowBox[{
    RowBox[{"(", 
     RowBox[{"1", "+", 
      FractionBox["S1", "Kms1"], "+", 
      FractionBox["P1", "Kmp1"], "+", 
      FractionBox["S2", "Kms2"], "+", 
      FractionBox["P2", "Kmp2"], "+", 
      FractionBox["S3", "Kms3"], "+", 
      FractionBox["P3", "Kmp3"]}], ")"}], "*", 
    RowBox[{"(", 
     RowBox[{"1", "+", 
      FractionBox[
       RowBox[{"(", 
        RowBox[{"S4", "-", "P4"}], ")"}], "Kms4"], "+", 
      FractionBox["P4", "Kmp4"]}], ")"}]}]]}]], "Input",
 CellChangeTimes->{{3.490349898546875*^9, 3.490349901765625*^9}, 
   3.490350000359375*^9, {3.49189912965625*^9, 3.491899138796875*^9}, {
   3.49353681325*^9, 3.4935368254375*^9}, {3.49353687090625*^9, 
   3.4935369268125*^9}, {3.4976802293125*^9, 3.497680240421875*^9}},
 CellLabel->
  "In[390]:=",ExpressionUUID->"644e2d1f-80ac-4d10-b6fc-adf6ed462cc1"],

Cell[BoxData[
 RowBox[{
  RowBox[{"LCAD", "[", 
   RowBox[{
   "sf_", ",", "V_", ",", "Kms1_", ",", "Kms2_", ",", "Kms3_", ",", "Kms4_", 
    ",", "Kms5_", ",", "Kms6_", ",", "Kmp1_", ",", "Kmp2_", ",", "Kmp3_", ",",
     "Kmp4_", ",", "Kmp5_", ",", "Kmp6_", ",", "Keq_", ",", "S1_", ",", "S2_",
     ",", "S3_", ",", "S4_", ",", "S5_", ",", "S6_", ",", "P1_", ",", "P2_", 
    ",", "P3_", ",", "P4_", ",", "P5_", ",", "P6_"}], "]"}], ":=", 
  FractionBox[
   RowBox[{"sf", "*", "V", "*", 
    RowBox[{"(", 
     RowBox[{
      FractionBox[
       RowBox[{"S1", "*", 
        RowBox[{"(", 
         RowBox[{"S6", "-", "P6"}], ")"}]}], 
       RowBox[{"Kms1", "*", "Kms6"}]], "-", 
      FractionBox[
       RowBox[{"P1", "*", "P6"}], 
       RowBox[{"Kms1", "*", "Kms6", "*", "Keq"}]]}], ")"}]}], 
   RowBox[{
    RowBox[{"(", 
     RowBox[{"1", "+", 
      FractionBox["S1", "Kms1"], "+", 
      FractionBox["P1", "Kmp1"], "+", 
      FractionBox["S2", "Kms2"], "+", 
      FractionBox["P2", "Kmp2"], "+", 
      FractionBox["S3", "Kms3"], "+", 
      FractionBox["P3", "Kmp3"], "+", 
      FractionBox["S4", "Kms4"], "+", 
      FractionBox["P4", "Kmp4"], "+", 
      FractionBox["S5", "Kms5"], "+", 
      FractionBox["P5", "Kmp5"]}], ")"}], "*", 
    RowBox[{"(", 
     RowBox[{"1", "+", 
      FractionBox[
       RowBox[{"(", 
        RowBox[{"S6", "-", "P6"}], ")"}], "Kms6"], "+", 
      FractionBox["P6", "Kmp6"]}], ")"}]}]]}]], "Input",
 CellChangeTimes->{{3.490349903375*^9, 3.490349903765625*^9}, 
   3.490349992484375*^9, {3.491899136109375*^9, 3.491899143890625*^9}, {
   3.493540040140625*^9, 3.493540092375*^9}, {3.49768032953125*^9, 
   3.497680344125*^9}},
 CellLabel->
  "In[391]:=",ExpressionUUID->"51490068-d40f-4616-afe6-8ed7767bc8bc"],

Cell[BoxData[
 RowBox[{
  RowBox[{"MCAD", "[", 
   RowBox[{
   "sf_", ",", "V_", ",", "Kms1_", ",", "Kms2_", ",", "Kms3_", ",", "Kms4_", 
    ",", "Kms5_", ",", "Kms6_", ",", "Kmp1_", ",", "Kmp2_", ",", "Kmp3_", ",",
     "Kmp4_", ",", "Kmp5_", ",", "Kmp6_", ",", "Keq_", ",", "S1_", ",", "S2_",
     ",", "S3_", ",", "S4_", ",", "S5_", ",", "S6_", ",", "P1_", ",", "P2_", 
    ",", "P3_", ",", "P4_", ",", "P5_", ",", "P6_"}], "]"}], ":=", 
  FractionBox[
   RowBox[{"sf", "*", "V", "*", 
    RowBox[{"(", 
     RowBox[{
      FractionBox[
       RowBox[{"S1", "*", 
        RowBox[{"(", 
         RowBox[{"S6", "-", "P6"}], ")"}]}], 
       RowBox[{"Kms1", "*", "Kms6"}]], "-", 
      FractionBox[
       RowBox[{"P1", "*", "P6"}], 
       RowBox[{"Kms1", "*", "Kms6", "*", "Keq"}]]}], ")"}]}], 
   RowBox[{
    RowBox[{"(", 
     RowBox[{"1", "+", 
      FractionBox["S1", "Kms1"], "+", 
      FractionBox["P1", "Kmp1"], "+", 
      FractionBox["S2", "Kms2"], "+", 
      FractionBox["P2", "Kmp2"], "+", 
      FractionBox["S3", "Kms3"], "+", 
      FractionBox["P3", "Kmp3"], "+", 
      FractionBox["S4", "Kms4"], "+", 
      FractionBox["P4", "Kmp4"], "+", 
      FractionBox["S5", "Kms5"], "+", 
      FractionBox["P5", "Kmp5"]}], ")"}], "*", 
    RowBox[{"(", 
     RowBox[{"1", "+", 
      FractionBox[
       RowBox[{"(", 
        RowBox[{"S6", "-", "P6"}], ")"}], "Kms6"], "+", 
      FractionBox["P6", "Kmp6"]}], ")"}]}]]}]], "Input",
 CellChangeTimes->{{3.490349906171875*^9, 3.49034990665625*^9}, 
   3.490349983*^9, {3.49189915071875*^9, 3.49189915384375*^9}, {
   3.49354199765625*^9, 3.493542007203125*^9}, {3.49768035121875*^9, 
   3.497680360234375*^9}, 3.497680762921875*^9},
 CellLabel->
  "In[392]:=",ExpressionUUID->"b4ab62a6-33b7-4b16-bcca-c53ae51a2133"],

Cell[BoxData[
 RowBox[{
  RowBox[{"SCAD", "[", 
   RowBox[{
   "sf_", ",", "V_", ",", "Kms1_", ",", "Kms2_", ",", "Kms3_", ",", "Kmp1_", 
    ",", "Kmp2_", ",", "Kmp3_", ",", "Keq_", ",", "S1_", ",", "S2_", ",", 
    "S3_", ",", "P1_", ",", "P2_", ",", "P3_"}], "]"}], ":=", 
  FractionBox[
   RowBox[{"sf", "*", "V", "*", 
    RowBox[{"(", 
     RowBox[{
      FractionBox[
       RowBox[{"S1", "*", 
        RowBox[{"(", 
         RowBox[{"S3", "-", "P3"}], ")"}]}], 
       RowBox[{"Kms1", "*", "Kms3"}]], "-", 
      FractionBox[
       RowBox[{"P1", "*", "P3"}], 
       RowBox[{"Kms1", "*", "Kms3", "*", "Keq"}]]}], ")"}]}], 
   RowBox[{
    RowBox[{"(", 
     RowBox[{"1", "+", 
      FractionBox["S1", "Kms1"], "+", 
      FractionBox["P1", "Kmp1"], "+", 
      FractionBox["S2", "Kms2"], "+", 
      FractionBox["P2", "Kmp2"]}], ")"}], "*", 
    RowBox[{"(", 
     RowBox[{"1", "+", 
      FractionBox[
       RowBox[{"(", 
        RowBox[{"S3", "-", "P3"}], ")"}], "Kms3"], "+", 
      FractionBox["P3", "Kmp3"]}], ")"}]}]]}]], "Input",
 CellChangeTimes->{{3.49034990809375*^9, 3.49034990921875*^9}, 
   3.490349975859375*^9, {3.49189916021875*^9, 3.491899162671875*^9}, {
   3.49354259003125*^9, 3.4935425988125*^9}, {3.497680365234375*^9, 
   3.497680376546875*^9}},
 CellLabel->
  "In[393]:=",ExpressionUUID->"fb4a3454-74fb-44e6-9746-3615c64a5631"],

Cell[BoxData[
 RowBox[{
  RowBox[{"CROT", "[", 
   RowBox[{
   "sf_", ",", "V_", ",", "Kms1_", ",", "Kms2_", ",", "Kms3_", ",", "Kms4_", 
    ",", "Kms5_", ",", "Kms6_", ",", "Kms7_", ",", "Kmp1_", ",", "Kmp2_", ",",
     "Kmp3_", ",", "Kmp4_", ",", "Kmp5_", ",", "Kmp6_", ",", "Kmp7_", ",", 
    "Ki1_", ",", "Keq_", ",", "S1_", ",", "S2_", ",", "S3_", ",", "S4_", ",", 
    "S5_", ",", "S6_", ",", "S7_", ",", "P1_", ",", "P2_", ",", "P3_", ",", 
    "P4_", ",", "P5_", ",", "P6_", ",", "P7_", ",", "I1_"}], "]"}], ":=", 
  FractionBox[
   RowBox[{"sf", "*", "V", "*", 
    RowBox[{"(", 
     RowBox[{
      FractionBox["S1", "Kms1"], "-", 
      FractionBox["P1", 
       RowBox[{"Kms1", "*", "Keq"}]]}], ")"}]}], 
   RowBox[{"1", "+", 
    FractionBox["S1", "Kms1"], "+", 
    FractionBox["P1", "Kmp1"], "+", 
    FractionBox["S2", "Kms2"], "+", 
    FractionBox["P2", "Kmp2"], "+", 
    FractionBox["S3", "Kms3"], "+", 
    FractionBox["P3", "Kmp3"], "+", 
    FractionBox["S4", "Kms4"], "+", 
    FractionBox["P4", "Kmp4"], "+", 
    FractionBox["S5", "Kms5"], "+", 
    FractionBox["P5", "Kmp5"], "+", 
    FractionBox["S6", "Kms6"], "+", 
    FractionBox["P6", "Kmp6"], "+", 
    FractionBox["S7", "Kms7"], "+", 
    FractionBox["P7", "Kmp7"], "+", 
    FractionBox["I1", "Ki1"]}]]}]], "Input",
 CellChangeTimes->{{3.490349926671875*^9, 3.49034992771875*^9}, {
  3.494142515140625*^9, 3.4941425468125*^9}, {3.4941426298125*^9, 
  3.494142738453125*^9}, {3.494142792921875*^9, 3.494142960015625*^9}, {
  3.494143271*^9, 3.494143294015625*^9}, {3.520742791984375*^9, 
  3.520742826421875*^9}, {3.520743030625*^9, 3.520743040671875*^9}},
 CellLabel->
  "In[394]:=",ExpressionUUID->"7af20f79-2684-4fd7-8398-bdd9448680d0"],

Cell[BoxData[
 RowBox[{
  RowBox[{"MSCHAD", "[", 
   RowBox[{
   "sf_", ",", "V_", ",", "Kms1_", ",", "Kms2_", ",", "Kms3_", ",", "Kms4_", 
    ",", "Kms5_", ",", "Kms6_", ",", "Kms7_", ",", "Kms8_", ",", "Kmp1_", ",",
     "Kmp2_", ",", "Kmp3_", ",", "Kmp4_", ",", "Kmp5_", ",", "Kmp6_", ",", 
    "Kmp7_", ",", "Kmp8_", ",", "Keq_", ",", "S1_", ",", "S2_", ",", "S3_", 
    ",", "S4_", ",", "S5_", ",", "S6_", ",", "S7_", ",", "S8_", ",", "P1_", 
    ",", "P2_", ",", "P3_", ",", "P4_", ",", "P5_", ",", "P6_", ",", "P7_", 
    ",", "P8_"}], "]"}], ":=", 
  FractionBox[
   RowBox[{"sf", "*", "V", "*", 
    RowBox[{"(", 
     RowBox[{
      FractionBox[
       RowBox[{"S1", "*", 
        RowBox[{"(", 
         RowBox[{"S8", "-", "P8"}], ")"}]}], 
       RowBox[{"Kms1", "*", "Kms8"}]], "-", 
      FractionBox[
       RowBox[{"P1", "*", "P8"}], 
       RowBox[{"Kms1", "*", "Kms8", "*", "Keq"}]]}], ")"}]}], 
   RowBox[{
    RowBox[{"(", 
     RowBox[{"1", "+", 
      FractionBox["S1", "Kms1"], "+", 
      FractionBox["P1", "Kmp1"], "+", 
      FractionBox["S2", "Kms2"], "+", 
      FractionBox["P2", "Kmp2"], "+", 
      FractionBox["S3", "Kms3"], "+", 
      FractionBox["P3", "Kmp3"], "+", 
      FractionBox["S4", "Kms4"], "+", 
      FractionBox["P4", "Kmp4"], "+", 
      FractionBox["S5", "Kms5"], "+", 
      FractionBox["P5", "Kmp5"], "+", 
      FractionBox["S6", "Kms6"], "+", 
      FractionBox["P6", "Kmp6"], "+", 
      FractionBox["S7", "Kms7"], "+", 
      FractionBox["P7", "Kmp7"]}], ")"}], "*", 
    RowBox[{"(", 
     RowBox[{"1", "+", 
      FractionBox[
       RowBox[{"(", 
        RowBox[{"S8", "-", "P8"}], ")"}], "Kms8"], "+", 
      FractionBox["P8", "Kmp8"]}], ")"}]}]]}]], "Input",
 CellChangeTimes->{{3.49034994053125*^9, 3.490349942140625*^9}, 
   3.494234091765625*^9, {3.494235304390625*^9, 3.494235400015625*^9}, {
   3.49768099765625*^9, 3.497681009390625*^9}},
 CellLabel->
  "In[395]:=",ExpressionUUID->"2ade593c-e4c0-478d-8eaf-e9c919d9d895"],

Cell[BoxData[
 RowBox[{
  RowBox[{"MCKATA", "[", 
   RowBox[{
   "sf_", ",", "V_", ",", "Kms1_", ",", "Kms2_", ",", "Kms3_", ",", "Kms4_", 
    ",", "Kms5_", ",", "Kms6_", ",", "Kms7_", ",", "Kms8_", ",", "Kmp1_", ",",
     "Kmp2_", ",", "Kmp3_", ",", "Kmp4_", ",", "Kmp5_", ",", "Kmp6_", ",", 
    "Kmp7_", ",", "Kmp8_", ",", "Keq_", ",", "S1_", ",", "S2_", ",", "S3_", 
    ",", "S4_", ",", "S5_", ",", "S6_", ",", "S7_", ",", "S8_", ",", "P1_", 
    ",", "P2_", ",", "P3_", ",", "P4_", ",", "P5_", ",", "P6_", ",", "P7_", 
    ",", "P8_", ",", "E1_", ",", "KmE1_", ",", "nm_", ",", "vsh_", ",", 
    "Kmsh_", ",", "SH1_", ",", "propacetmckat_"}], "]"}], ":=", 
  RowBox[{
   RowBox[{"(", 
    RowBox[{"sf", "*", 
     RowBox[{"(", 
      RowBox[{"V", "*", 
       RowBox[{"(", 
        RowBox[{
         FractionBox[
          RowBox[{"S1", "*", "S8"}], 
          RowBox[{"Kms1", "*", "Kms8"}]], "-", 
         FractionBox[
          RowBox[{"P1", "*", "P8"}], 
          RowBox[{"Kms1", "*", "Kms8", "*", "Keq"}]]}], ")"}]}], ")"}]}], 
    ")"}], "/", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{"1", "+", 
       FractionBox["S1", "Kms1"], "+", 
       FractionBox["P1", "Kmp1"], "+", 
       FractionBox["S2", "Kms2"], "+", 
       FractionBox["P2", "Kmp2"], "+", 
       FractionBox["S3", "Kms3"], "+", 
       FractionBox["P3", "Kmp3"], "+", 
       FractionBox["S4", "Kms4"], "+", 
       FractionBox["P4", "Kmp4"], "+", 
       FractionBox["S5", "Kms5"], "+", 
       FractionBox["P5", "Kmp5"], "+", 
       FractionBox["S6", "Kms6"], "+", 
       FractionBox["P6", "Kmp6"], "+", 
       FractionBox["S7", "Kms7"], "+", 
       FractionBox["P7", "Kmp7"], "+", 
       FractionBox["P8", "Kmp8"]}], ")"}], "*", 
     RowBox[{"(", 
      RowBox[{"1", "+", 
       FractionBox["S8", "Kms8"], "+", 
       FractionBox["P8", "Kmp8"]}], ")"}]}], ")"}]}]}]], "Input",
 CellChangeTimes->{{3.49034994896875*^9, 3.490349951140625*^9}, 
   3.494302106984375*^9, {3.49481839628125*^9, 3.4948184140625*^9}, 
   3.748925032827672*^9, 3.7489250690907335`*^9, {3.7586210904423327`*^9, 
   3.7586211302556725`*^9}, 3.7586211915578876`*^9, 3.7888627344800014`*^9, 
   3.8126897734826307`*^9, {3.817114431475791*^9, 3.8171144591467867`*^9}},
 CellLabel->
  "In[396]:=",ExpressionUUID->"695562d8-b36a-498c-95db-6427d4bd7804"],

Cell[BoxData[
 RowBox[{
  RowBox[{"MCKATB", "[", 
   RowBox[{
   "sf_", ",", "V_", ",", "Kms1_", ",", "Kms2_", ",", "Kms3_", ",", "Kms4_", 
    ",", "Kms5_", ",", "Kms6_", ",", "Kms7_", ",", "Kms8_", ",", "Kmp1_", ",",
     "Kmp2_", ",", "Kmp3_", ",", "Kmp4_", ",", "Kmp5_", ",", "Kmp6_", ",", 
    "Kmp7_", ",", "Kmp8_", ",", "Keq_", ",", "S1_", ",", "S2_", ",", "S3_", 
    ",", "S4_", ",", "S5_", ",", "S6_", ",", "S7_", ",", "S8_", ",", "P1_", 
    ",", "P2_", ",", "P3_", ",", "P4_", ",", "P5_", ",", "P6_", ",", "P7_", 
    ",", "P8_", ",", "E1_", ",", "KmE1_", ",", "nm_", ",", "vsh_", ",", 
    "Kmsh_", ",", "SH1_", ",", "propacetmckat_"}], "]"}], ":=", 
  RowBox[{
   RowBox[{"(", 
    RowBox[{"sf", "*", 
     RowBox[{"(", 
      RowBox[{"V", "*", 
       RowBox[{"(", 
        RowBox[{
         FractionBox[
          RowBox[{"S1", "*", "S8"}], 
          RowBox[{"Kms1", "*", "Kms8"}]], "-", 
         FractionBox[
          RowBox[{"P8", "*", "P8"}], 
          RowBox[{"Kms1", "*", "Kms8", "*", "Keq"}]]}], ")"}]}], ")"}]}], 
    ")"}], "/", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{"1", "+", 
       FractionBox["S1", "Kms1"], "+", 
       FractionBox["P1", "Kmp1"], "+", 
       FractionBox["S2", "Kms2"], "+", 
       FractionBox["P2", "Kmp2"], "+", 
       FractionBox["S3", "Kms3"], "+", 
       FractionBox["P3", "Kmp3"], "+", 
       FractionBox["S4", "Kms4"], "+", 
       FractionBox["P4", "Kmp4"], "+", 
       FractionBox["S5", "Kms5"], "+", 
       FractionBox["P5", "Kmp5"], "+", 
       FractionBox["S6", "Kms6"], "+", 
       FractionBox["P6", "Kmp6"], "+", 
       FractionBox["S7", "Kms7"], "+", 
       FractionBox["P7", "Kmp7"], "+", 
       FractionBox["P8", "Kmp8"]}], ")"}], "*", 
     RowBox[{"(", 
      RowBox[{"1", "+", 
       FractionBox["S8", "Kms8"], "+", 
       FractionBox["P8", "Kmp8"]}], ")"}]}], ")"}], "  ", 
   RowBox[{"(*", " ", 
    RowBox[{"*", 
     RowBox[{"(", 
      RowBox[{"1", "+", 
       RowBox[{"nm", "*", 
        SuperscriptBox[
         RowBox[{"(", 
          FractionBox["E1", "KmE1"], ")"}], "1"]}]}], ")"}]}], 
    "*)"}]}]}]], "Input",
 CellChangeTimes->{{3.494818427515625*^9, 3.49481844140625*^9}, 
   3.7489250361191397`*^9, 3.748925072107798*^9, {3.758621093819543*^9, 
   3.758621140118312*^9}, 3.758621198243312*^9, 3.7888627397859383`*^9, {
   3.812689783458255*^9, 3.8126898060965433`*^9}, {3.8171144487376213`*^9, 
   3.817114464078593*^9}},
 CellLabel->
  "In[397]:=",ExpressionUUID->"b21983fb-49f4-4b07-a762-697409a383a1"],

Cell[BoxData[
 RowBox[{
  RowBox[{"MTP", "[", 
   RowBox[{
   "sf_", ",", "V_", ",", "Kms1_", ",", "Kms2_", ",", "Kms3_", ",", "Kms4_", 
    ",", "Kms5_", ",", "Kms7_", ",", "Kms8_", ",", "Kmp1_", ",", "Kmp2_", ",",
     "Kmp3_", ",", "Kmp4_", ",", "Kmp5_", ",", "Kmp6_", ",", "Kmp7_", ",", 
    "Kmp8_", ",", "Ki1_", ",", "Keq_", ",", "S1_", ",", "S2_", ",", "S3_", 
    ",", "S4_", ",", "S5_", ",", "S7_", ",", "S8_", ",", "P1_", ",", "P2_", 
    ",", "P3_", ",", "P4_", ",", "P5_", ",", "P6_", ",", "P7_", ",", "P8_", 
    ",", "I1_"}], "]"}], ":=", 
  RowBox[{
   RowBox[{"(", 
    RowBox[{"sf", "*", "V", "*", 
     RowBox[{"(", 
      RowBox[{
       FractionBox[
        RowBox[{"S1", "*", 
         RowBox[{"(", 
          RowBox[{"S7", "-", "P7"}], ")"}], "*", "S8"}], 
        RowBox[{"Kms1", "*", "Kms7", "*", "Kms8"}]], "-", 
       FractionBox[
        RowBox[{"P1", "*", "P7", "*", "P8"}], 
        RowBox[{"Kms1", "*", "Kms7", "*", "Kms8", "*", "Keq"}]]}], ")"}]}], 
    ")"}], "/", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{"1", "+", 
       FractionBox["S1", "Kms1"], "+", 
       FractionBox["P1", "Kmp1"], "+", 
       FractionBox["S2", "Kms2"], "+", 
       FractionBox["P2", "Kmp2"], "+", 
       FractionBox["S3", "Kms3"], "+", 
       FractionBox["P3", "Kmp3"], "+", 
       FractionBox["S4", "Kms4"], "+", 
       FractionBox["P4", "Kmp4"], "+", 
       FractionBox["S5", "Kms5"], "+", 
       FractionBox["P5", "Kmp5"], "+", 
       FractionBox["P6", "Kmp6"], "+", 
       FractionBox["I1", "Ki1"]}], ")"}], "*", 
     RowBox[{"(", 
      RowBox[{"1", "+", 
       FractionBox[
        RowBox[{"(", 
         RowBox[{"S7", "-", "P7"}], ")"}], "Kms7"], "+", 
       FractionBox["P7", "Kmp7"]}], ")"}], "*", 
     RowBox[{"(", 
      RowBox[{"1", "+", 
       FractionBox["S8", "Kms8"], "+", 
       FractionBox["P8", "Kmp8"]}], ")"}]}], ")"}]}]}]], "Input",
 CellChangeTimes->{{3.49189457996875*^9, 3.49189458140625*^9}, 
   3.494821359078125*^9, {3.4948214065*^9, 3.4948217809375*^9}, {
   3.49482194884375*^9, 3.494821980515625*^9}, {3.494822668890625*^9, 
   3.49482267875*^9}, {3.494828226671875*^9, 3.494828382671875*^9}, {
   3.49768104928125*^9, 3.4976810615625*^9}, {3.521171849335596*^9, 
   3.521171870032557*^9}, 3.751874796107088*^9, 3.8192058011800547`*^9},
 CellLabel->
  "In[398]:=",ExpressionUUID->"16b71fc7-21dd-430e-9168-ea4efa2a7c67"],

Cell[BoxData[
 RowBox[{
  RowBox[{"RES", "[", 
   RowBox[{"Ks_", ",", "S_", ",", "K1_"}], "]"}], ":=", 
  RowBox[{"Ks", "*", 
   RowBox[{"(", 
    RowBox[{"S", "-", "K1"}], ")"}]}]}]], "Input",
 CellChangeTimes->{{3.490349959703125*^9, 3.490349960125*^9}, 
   3.490352018328125*^9},
 CellLabel->
  "In[399]:=",ExpressionUUID->"ab492a5b-8f88-4459-96cd-bbc045bded9a"],

Cell[BoxData[
 RowBox[{
  RowBox[{"OXPH", "[", 
   RowBox[{
   "V_", ",", "Kms1_", ",", "Kmp1_", ",", "S1_", ",", "P1_", ",", "vsh_", ",",
     "Kmsh_", ",", "SH1_"}], "]"}], ":=", 
  FractionBox[
   RowBox[{
    RowBox[{"(", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"1", "+", "SH1"}], ")"}], "*", "V"}], ")"}], "*", 
    RowBox[{"(", 
     FractionBox["S1", "Kms1"], ")"}]}], 
   RowBox[{"(", 
    RowBox[{"1", "+", 
     FractionBox["S1", "Kms1"], "+", 
     FractionBox["P1", "Kmp1"]}], ")"}]]}]], "Input",
 CellChangeTimes->{{3.757405749106596*^9, 3.757405854406624*^9}, {
   3.757405890832507*^9, 3.757405891660115*^9}, {3.7574059915858965`*^9, 
   3.757405992758704*^9}, 3.7584584410476723`*^9, {3.7584587652041388`*^9, 
   3.758458769847149*^9}, {3.758458841548337*^9, 3.7584588441857457`*^9}, {
   3.7591420908634*^9, 3.7591421152577953`*^9}, 3.8134712092017727`*^9, {
   3.8134892438574033`*^9, 3.8134892450263085`*^9}, {3.817114477202492*^9, 
   3.8171144860169325`*^9}, {3.817114649005001*^9, 3.817114659706382*^9}, 
   3.819206030560548*^9, {3.832311330278469*^9, 
   3.8323113307597947`*^9}},ExpressionUUID->"365dfb41-a139-4fa6-b04a-\
83da663bb56a"],

Cell[BoxData[
 RowBox[{
  RowBox[{"PDH", "[", 
   RowBox[{"V_", ",", "Kms1_", ",", "Kmp1_", ",", "S1_", ",", "P1_"}], "]"}], 
  ":=", 
  FractionBox[
   RowBox[{"V", "*", 
    RowBox[{"(", 
     FractionBox["S1", "Kms1"], ")"}]}], 
   RowBox[{"(", 
    RowBox[{"1", "+", 
     FractionBox["S1", "Kms1"], "+", 
     FractionBox["P1", "Kmp1"]}], ")"}]]}]], "Input",
 CellChangeTimes->{{3.757411063295637*^9, 3.7574110718932996`*^9}, 
   3.8134712037404118`*^9, {3.8134713923463135`*^9, 3.8134713934213943`*^9}, {
   3.8134892485807767`*^9, 3.813489249012623*^9}, 3.8192061172292223`*^9},
 CellLabel->
  "In[401]:=",ExpressionUUID->"80bd1703-6837-4bbf-8fb5-cc2b56d1e596"],

Cell[BoxData[""], "Input",
 CellChangeTimes->{3.7567224634799213`*^9},
 CellLabel->
  "In[402]:=",ExpressionUUID->"64ec67f6-8148-4e6b-9239-c99870f00ba4"],

Cell[TextData[StyleBox["Define the differential equations",
 FontSize->24,
 FontWeight->"Bold"]], "Text",
 CellChangeTimes->{{3.480327618984375*^9, 3.48032763234375*^9}, {
  3.4803298023125*^9, 3.48032980303125*^9}, {3.737355387664946*^9, 
  3.7373553912401505`*^9}},
 FontSize->16,ExpressionUUID->"b53fc1ed-147a-4f3c-a559-1266eee3f57d"],

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"Odes", "=", 
    RowBox[{"{", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{"C16AcylCarCYT", "'"}], "[", "t", "]"}], "\[Equal]", 
       FractionBox[
        RowBox[{"vcpt1C16", "-", "vcactC16"}], "VCYT"]}], ",", 
      "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{
        RowBox[{"C16AcylCarMAT", "'"}], "[", "t", "]"}], "\[Equal]", 
       FractionBox[
        RowBox[{"vcactC16", "-", "vcpt2C16"}], "VMAT"]}], ",", 
      "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{
        RowBox[{"C16AcylCoAMAT", "'"}], "[", "t", "]"}], "\[Equal]", 
       FractionBox[
        RowBox[{"vcpt2C16", "-", "vvlcadC16", "-", "vlcadC16"}], "VMAT"]}], 
      ",", "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{
        RowBox[{"C16EnoylCoAMAT", "'"}], "[", "t", "]"}], "\[Equal]", 
       FractionBox[
        RowBox[{
        "vvlcadC16", "+", "vlcadC16", "-", "vcrotC16", "-", "vmtpC16"}], 
        "VMAT"]}], ",", "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{
        RowBox[{"C16HydroxyacylCoAMAT", "'"}], "[", "t", "]"}], "\[Equal]", 
       FractionBox[
        RowBox[{"vcrotC16", "-", "vmschadC16"}], "VMAT"]}], ",", 
      "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{
        RowBox[{"C16KetoacylCoAMAT", "'"}], "[", "t", "]"}], "\[Equal]", 
       FractionBox[
        RowBox[{"vmschadC16", "-", "vmckatC16"}], "VMAT"]}], ",", 
      "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{
        RowBox[{"C14AcylCarCYT", "'"}], "[", "t", "]"}], "\[Equal]", 
       FractionBox[
        RowBox[{"-", "vcactC14"}], "VCYT"]}], ",", "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{
        RowBox[{"C14AcylCarMAT", "'"}], "[", "t", "]"}], "\[Equal]", 
       FractionBox[
        RowBox[{"vcactC14", "-", "vcpt2C14"}], "VMAT"]}], ",", 
      "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{
        RowBox[{"C14AcylCoAMAT", "'"}], "[", "t", "]"}], "\[Equal]", 
       FractionBox[
        RowBox[{
        "vcpt2C14", "+", "vmtpC16", "+", "vmckatC16", "-", "vvlcadC14", "-", 
         "vlcadC14"}], "VMAT"]}], ",", "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{
        RowBox[{"C14EnoylCoAMAT", "'"}], "[", "t", "]"}], "\[Equal]", 
       FractionBox[
        RowBox[{
        "vvlcadC14", "+", "vlcadC14", "-", "vcrotC14", "-", "vmtpC14"}], 
        "VMAT"]}], ",", "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{
        RowBox[{"C14HydroxyacylCoAMAT", "'"}], "[", "t", "]"}], "\[Equal]", 
       FractionBox[
        RowBox[{"vcrotC14", "-", "vmschadC14"}], "VMAT"]}], ",", 
      "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{
        RowBox[{"C14KetoacylCoAMAT", "'"}], "[", "t", "]"}], "\[Equal]", 
       FractionBox[
        RowBox[{"vmschadC14", "-", "vmckatC14"}], "VMAT"]}], ",", 
      "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{
        RowBox[{"C12AcylCarCYT", "'"}], "[", "t", "]"}], "\[Equal]", 
       FractionBox[
        RowBox[{"-", "vcactC12"}], "VCYT"]}], ",", "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{
        RowBox[{"C12AcylCarMAT", "'"}], "[", "t", "]"}], "\[Equal]", 
       FractionBox[
        RowBox[{"vcactC12", "-", "vcpt2C12"}], "VMAT"]}], ",", 
      "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{
        RowBox[{"C12AcylCoAMAT", "'"}], "[", "t", "]"}], "\[Equal]", 
       FractionBox[
        RowBox[{
        "vcpt2C12", "+", "vmtpC14", "+", "vmckatC14", "-", "vvlcadC12", "-", 
         "vlcadC12", "-", "vmcadC12"}], "VMAT"]}], ",", "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{
        RowBox[{"C12EnoylCoAMAT", "'"}], "[", "t", "]"}], "\[Equal]", 
       FractionBox[
        RowBox[{
        "vvlcadC12", "+", "vlcadC12", "+", "vmcadC12", "-", "vcrotC12", "-", 
         "vmtpC12"}], "VMAT"]}], ",", "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{
        RowBox[{"C12HydroxyacylCoAMAT", "'"}], "[", "t", "]"}], "\[Equal]", 
       FractionBox[
        RowBox[{"vcrotC12", "-", "vmschadC12"}], "VMAT"]}], ",", 
      "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{
        RowBox[{"C12KetoacylCoAMAT", "'"}], "[", "t", "]"}], "\[Equal]", 
       FractionBox[
        RowBox[{"vmschadC12", "-", "vmckatC12"}], "VMAT"]}], ",", 
      "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{
        RowBox[{"C10AcylCarCYT", "'"}], "[", "t", "]"}], "\[Equal]", 
       FractionBox[
        RowBox[{"-", "vcactC10"}], "VCYT"]}], ",", "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{
        RowBox[{"C10AcylCarMAT", "'"}], "[", "t", "]"}], "\[Equal]", 
       FractionBox[
        RowBox[{"vcactC10", "-", "vcpt2C10"}], "VMAT"]}], ",", 
      "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{
        RowBox[{"C10AcylCoAMAT", "'"}], "[", "t", "]"}], "\[Equal]", 
       FractionBox[
        RowBox[{
        "vcpt2C10", "+", "vmtpC12", "+", "vmckatC12", "-", "vlcadC10", "-", 
         "vmcadC10"}], "VMAT"]}], ",", "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{
        RowBox[{"C10EnoylCoAMAT", "'"}], "[", "t", "]"}], "\[Equal]", 
       FractionBox[
        RowBox[{
        "vlcadC10", "+", "vmcadC10", "-", "vcrotC10", "-", "vmtpC10"}], 
        "VMAT"]}], ",", "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{
        RowBox[{"C10HydroxyacylCoAMAT", "'"}], "[", "t", "]"}], "\[Equal]", 
       FractionBox[
        RowBox[{"vcrotC10", "-", "vmschadC10"}], "VMAT"]}], ",", 
      "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{
        RowBox[{"C10KetoacylCoAMAT", "'"}], "[", "t", "]"}], "\[Equal]", 
       FractionBox[
        RowBox[{"vmschadC10", "-", "vmckatC10"}], "VMAT"]}], ",", 
      "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{
        RowBox[{"C8AcylCarCYT", "'"}], "[", "t", "]"}], "\[Equal]", 
       FractionBox[
        RowBox[{"-", "vcactC8"}], "VCYT"]}], ",", "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{
        RowBox[{"C8AcylCarMAT", "'"}], "[", "t", "]"}], "\[Equal]", 
       FractionBox[
        RowBox[{"vcactC8", "-", "vcpt2C8"}], "VMAT"]}], ",", 
      "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{
        RowBox[{"C8AcylCoAMAT", "'"}], "[", "t", "]"}], "\[Equal]", 
       FractionBox[
        RowBox[{
        "vcpt2C8", "+", "vmtpC10", "+", "vmckatC10", "-", "vlcadC8", "-", 
         "vmcadC8"}], "VMAT"]}], ",", "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{
        RowBox[{"C8EnoylCoAMAT", "'"}], "[", "t", "]"}], "\[Equal]", 
       FractionBox[
        RowBox[{"vlcadC8", "+", "vmcadC8", "-", "vcrotC8", "-", "vmtpC8"}], 
        "VMAT"]}], ",", "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{
        RowBox[{"C8HydroxyacylCoAMAT", "'"}], "[", "t", "]"}], "\[Equal]", 
       FractionBox[
        RowBox[{"vcrotC8", "-", "vmschadC8"}], "VMAT"]}], ",", 
      "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{
        RowBox[{"C8KetoacylCoAMAT", "'"}], "[", "t", "]"}], "\[Equal]", 
       FractionBox[
        RowBox[{"vmschadC8", "-", "vmckatC8"}], "VMAT"]}], ",", 
      "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{
        RowBox[{"C6AcylCarCYT", "'"}], "[", "t", "]"}], "\[Equal]", 
       FractionBox[
        RowBox[{"-", "vcactC6"}], "VCYT"]}], ",", "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{
        RowBox[{"C6AcylCarMAT", "'"}], "[", "t", "]"}], "\[Equal]", 
       FractionBox[
        RowBox[{"vcactC6", "-", "vcpt2C6"}], "VMAT"]}], ",", 
      "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{
        RowBox[{"C6AcylCoAMAT", "'"}], "[", "t", "]"}], "\[Equal]", 
       FractionBox[
        RowBox[{
        "vcpt2C6", "+", "vmtpC8", "+", "vmckatC8", "-", "vmcadC6", "-", 
         "vscadC6"}], "VMAT"]}], ",", "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{
        RowBox[{"C6EnoylCoAMAT", "'"}], "[", "t", "]"}], "\[Equal]", 
       FractionBox[
        RowBox[{"vmcadC6", "+", "vscadC6", "-", "vcrotC6"}], "VMAT"]}], ",", 
      "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{
        RowBox[{"C6HydroxyacylCoAMAT", "'"}], "[", "t", "]"}], "\[Equal]", 
       FractionBox[
        RowBox[{"vcrotC6", "-", "vmschadC6"}], "VMAT"]}], ",", 
      "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{
        RowBox[{"C6KetoacylCoAMAT", "'"}], "[", "t", "]"}], "\[Equal]", 
       FractionBox[
        RowBox[{"vmschadC6", "-", "vmckatC6"}], "VMAT"]}], ",", 
      "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{
        RowBox[{"C4AcylCarCYT", "'"}], "[", "t", "]"}], "\[Equal]", 
       FractionBox[
        RowBox[{"-", "vcactC4"}], "VCYT"]}], ",", "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{
        RowBox[{"C4AcylCarMAT", "'"}], "[", "t", "]"}], "\[Equal]", 
       FractionBox[
        RowBox[{"vcactC4", "-", "vcpt2C4"}], "VMAT"]}], ",", 
      "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{
        RowBox[{"C4AcylCoAMAT", "'"}], "[", "t", "]"}], "\[Equal]", 
       FractionBox[
        RowBox[{"vcpt2C4", "+", "vmckatC6", "-", "vmcadC4", "-", "vscadC4"}], 
        "VMAT"]}], ",", "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{
        RowBox[{"C4EnoylCoAMAT", "'"}], "[", "t", "]"}], "\[Equal]", 
       FractionBox[
        RowBox[{"vmcadC4", "+", "vscadC4", "-", "vcrotC4"}], "VMAT"]}], ",", 
      "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{
        RowBox[{"C4HydroxyacylCoAMAT", "'"}], "[", "t", "]"}], "\[Equal]", 
       FractionBox[
        RowBox[{"vcrotC4", "-", "vmschadC4"}], "VMAT"]}], ",", 
      "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{
        RowBox[{"C4AcetoacylCoAMAT", "'"}], "[", "t", "]"}], "\[Equal]", 
       FractionBox[
        RowBox[{"vmschadC4", "-", "vmckatC4", " "}], "VMAT"]}], ",", 
      "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{
        RowBox[{"AcetylCoAMAT", "'"}], "[", "t", "]"}], "\[Equal]", 
       RowBox[{
        FractionBox["1", "VMAT"], 
        RowBox[{"(", 
         RowBox[{
         "vmtpC16", "+", "vmckatC16", "+", "vmtpC14", "+", "vmckatC14", "+", 
          "vmtpC12", "+", "vmckatC12", "+", "vmtpC10", "+", "vmckatC10", "+", 
          "vmtpC8", "+", "vmckatC8", "+", "vmckatC6", "+", 
          RowBox[{"2", "*", "vmckatC4"}], " ", "-", "vacesink"}], ")"}]}]}], 
      ",", 
      RowBox[{"(*", 
       RowBox[{"-", "vacesink"}], "*)"}], "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{
        RowBox[{"FADHMAT", "'"}], "[", "t", "]"}], "\[Equal]", 
       RowBox[{
        FractionBox["1", "VMAT"], 
        RowBox[{"(", 
         RowBox[{
         "vvlcadC16", "+", "vvlcadC14", "+", "vvlcadC12", "+", "vlcadC16", 
          "+", "vlcadC14", "+", "vlcadC12", "+", "vlcadC10", "+", "vlcadC8", 
          "+", "vmcadC12", "+", "vmcadC10", "+", "vmcadC8", "+", "vmcadC6", 
          "+", "vmcadC4", "+", "vscadC6", "+", "vscadC4", "-", "vfadhsink"}], 
         ")"}]}]}], ",", "\[IndentingNewLine]", 
      StyleBox[
       RowBox[{
        RowBox[{
         RowBox[{"NADHMAT", "'"}], "[", "t", "]"}], "\[Equal]", 
        RowBox[{
         FractionBox["1", "VMAT"], 
         RowBox[{"(", 
          RowBox[{
          "vmtpC16", "+", "vmtpC14", "+", "vmtpC12", "+", "vmtpC10", "+", 
           "vmtpC8", "+", "vmschadC16", "+", "vmschadC14", "+", "vmschadC12", 
           "+", "vmschadC10", "+", "vmschadC8", "+", "vmschadC6", "+", 
           "vmschadC4", "+", "vpdhnad", "-", "voxphnadh"}], ")"}]}]}],
       Background->RGBColor[0.88, 1, 0.88]]}], "\[IndentingNewLine]", 
     StyleBox["}",
      Background->RGBColor[0.88, 1, 0.88]]}]}], 
   StyleBox[";",
    Background->RGBColor[0.88, 1, 0.88]]}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"RateEqs", "=", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"vcpt1C16", "\[Rule]", 
       RowBox[{"CPT1", "[", 
        RowBox[{
        "sfcpt1C16", ",", "Vcpt1", ",", "Kmcpt1C16AcylCoACYT", ",", 
         "Kmcpt1CarCYT", ",", "Kmcpt1C16AcylCarCYT", ",", "Kmcpt1CoACYT", ",",
          "Kicpt1MalCoACYT", ",", "Keqcpt1", ",", "C16AcylCoACYT", ",", 
         "CarCYT", ",", 
         RowBox[{"C16AcylCarCYT", "[", "t", "]"}], ",", "CoACYT", ",", 
         "MalCoACYT", ",", "ncpt1", ",", "vmct1acet", ",", "kmct1acet", ",", 
         "AcetateMAT", ",", "propacetcpt1", ",", "propacetmal", ",", "nc"}], 
        "]"}]}], ",", 
      RowBox[{"vcactC16", "\[Rule]", 
       RowBox[{"CACT", "[", 
        RowBox[{
        "Vfcact", ",", "Vrcact", ",", "KmcactC16AcylCarCYT", ",", 
         "KmcactCarMAT", ",", "KmcactC16AcylCarMAT", ",", "KmcactCarCYT", ",",
          "KicactC16AcylCarCYT", ",", "KicactCarCYT", ",", "Keqcact", ",", 
         RowBox[{"C16AcylCarCYT", "[", "t", "]"}], ",", "CarMAT", ",", 
         RowBox[{"C16AcylCarMAT", "[", "t", "]"}], ",", "CarCYT", ",", 
         "vmct1acet", ",", "kmct1acet", ",", "AcetateMAT", ",", 
         "propacetcact"}], "]"}]}], ",", "\[IndentingNewLine]", 
      RowBox[{"vcactC14", "\[Rule]", 
       RowBox[{"CACT", "[", 
        RowBox[{
        "Vfcact", ",", "Vrcact", ",", "KmcactC14AcylCarCYT", ",", 
         "KmcactCarMAT", ",", "KmcactC14AcylCarMAT", ",", "KmcactCarCYT", ",",
          "KicactC14AcylCarCYT", ",", "KicactCarCYT", ",", "Keqcact", ",", 
         RowBox[{"C14AcylCarCYT", "[", "t", "]"}], ",", "CarMAT", ",", 
         RowBox[{"C14AcylCarMAT", "[", "t", "]"}], ",", "CarCYT", ",", 
         "vmct1acet", ",", "kmct1acet", ",", "AcetateMAT", ",", 
         "propacetcact"}], "]"}]}], ",", 
      RowBox[{"vcactC12", "\[Rule]", 
       RowBox[{"CACT", "[", 
        RowBox[{
        "Vfcact", ",", "Vrcact", ",", "KmcactC12AcylCarCYT", ",", 
         "KmcactCarMAT", ",", "KmcactC12AcylCarMAT", ",", "KmcactCarCYT", ",",
          "KicactC12AcylCarCYT", ",", "KicactCarCYT", ",", "Keqcact", ",", 
         RowBox[{"C12AcylCarCYT", "[", "t", "]"}], ",", "CarMAT", ",", 
         RowBox[{"C12AcylCarMAT", "[", "t", "]"}], ",", "CarCYT", ",", 
         "vmct1acet", ",", "kmct1acet", ",", "AcetateMAT", ",", 
         "propacetcact"}], "]"}]}], ",", 
      RowBox[{"vcactC10", "\[Rule]", 
       RowBox[{"CACT", "[", 
        RowBox[{
        "Vfcact", ",", "Vrcact", ",", "KmcactC10AcylCarCYT", ",", 
         "KmcactCarMAT", ",", "KmcactC10AcylCarMAT", ",", "KmcactCarCYT", ",",
          "KicactC10AcylCarCYT", ",", "KicactCarCYT", ",", "Keqcact", ",", 
         RowBox[{"C10AcylCarCYT", "[", "t", "]"}], ",", "CarMAT", ",", 
         RowBox[{"C10AcylCarMAT", "[", "t", "]"}], ",", "CarCYT", ",", 
         "vmct1acet", ",", "kmct1acet", ",", "AcetateMAT", ",", 
         "propacetcact"}], "]"}]}], ",", 
      RowBox[{"vcactC8", "\[Rule]", 
       RowBox[{"CACT", "[", 
        RowBox[{
        "Vfcact", ",", "Vrcact", ",", "KmcactC8AcylCarCYT", ",", 
         "KmcactCarMAT", ",", "KmcactC8AcylCarMAT", ",", "KmcactCarCYT", ",", 
         "KicactC8AcylCarCYT", ",", "KicactCarCYT", ",", "Keqcact", ",", 
         RowBox[{"C8AcylCarCYT", "[", "t", "]"}], ",", "CarMAT", ",", 
         RowBox[{"C8AcylCarMAT", "[", "t", "]"}], ",", "CarCYT", ",", 
         "vmct1acet", ",", "kmct1acet", ",", "AcetateMAT", ",", 
         "propacetcact"}], "]"}]}], ",", 
      RowBox[{"vcactC6", "\[Rule]", 
       RowBox[{"CACT", "[", 
        RowBox[{
        "Vfcact", ",", "Vrcact", ",", "KmcactC6AcylCarCYT", ",", 
         "KmcactCarMAT", ",", "KmcactC6AcylCarMAT", ",", "KmcactCarCYT", ",", 
         "KicactC6AcylCarCYT", ",", "KicactCarCYT", ",", "Keqcact", ",", 
         RowBox[{"C6AcylCarCYT", "[", "t", "]"}], ",", "CarMAT", ",", 
         RowBox[{"C6AcylCarMAT", "[", "t", "]"}], ",", "CarCYT", ",", 
         "vmct1acet", ",", "kmct1acet", ",", "AcetateMAT", ",", 
         "propacetcact"}], "]"}]}], ",", 
      RowBox[{"vcactC4", "\[Rule]", 
       RowBox[{"CACT", "[", 
        RowBox[{
        "Vfcact", ",", "Vrcact", ",", "KmcactC4AcylCarCYT", ",", 
         "KmcactCarMAT", ",", "KmcactC4AcylCarMAT", ",", "KmcactCarCYT", ",", 
         "KicactC4AcylCarCYT", ",", "KicactCarCYT", ",", "Keqcact", ",", 
         RowBox[{"C4AcylCarCYT", "[", "t", "]"}], ",", "CarMAT", ",", 
         RowBox[{"C4AcylCarMAT", "[", "t", "]"}], ",", "CarCYT", ",", 
         "vmct1acet", ",", "kmct1acet", ",", "AcetateMAT", ",", 
         "propacetcact"}], "]"}]}], ",", 
      RowBox[{"vcpt2C16", "\[Rule]", 
       RowBox[{"CPT2", "[", 
        RowBox[{
        "sfcpt2C16", ",", "Vcpt2", ",", "Kmcpt2C16AcylCarMAT", ",", 
         "Kmcpt2C14AcylCarMAT", ",", "Kmcpt2C12AcylCarMAT", ",", 
         "Kmcpt2C10AcylCarMAT", ",", "Kmcpt2C8AcylCarMAT", ",", 
         "Kmcpt2C6AcylCarMAT", ",", "Kmcpt2C4AcylCarMAT", ",", "Kmcpt2CoAMAT",
          ",", "Kmcpt2C16AcylCoAMAT", ",", "Kmcpt2C14AcylCoAMAT", ",", 
         "Kmcpt2C12AcylCoAMAT", ",", "Kmcpt2C10AcylCoAMAT", ",", 
         "Kmcpt2C8AcylCoAMAT", ",", "Kmcpt2C6AcylCoAMAT", ",", 
         "Kmcpt2C4AcylCoAMAT", ",", "Kmcpt2CarMAT", ",", "Keqcpt2", ",", 
         RowBox[{"C16AcylCarMAT", "[", "t", "]"}], ",", 
         RowBox[{"C14AcylCarMAT", "[", "t", "]"}], ",", 
         RowBox[{"C12AcylCarMAT", "[", "t", "]"}], ",", 
         RowBox[{"C10AcylCarMAT", "[", "t", "]"}], ",", 
         RowBox[{"C8AcylCarMAT", "[", "t", "]"}], ",", 
         RowBox[{"C6AcylCarMAT", "[", "t", "]"}], ",", 
         RowBox[{"C4AcylCarMAT", "[", "t", "]"}], ",", "CoAMAT", ",", 
         RowBox[{"C16AcylCoAMAT", "[", "t", "]"}], ",", 
         RowBox[{"C14AcylCoAMAT", "[", "t", "]"}], ",", 
         RowBox[{"C12AcylCoAMAT", "[", "t", "]"}], ",", 
         RowBox[{"C10AcylCoAMAT", "[", "t", "]"}], ",", 
         RowBox[{"C8AcylCoAMAT", "[", "t", "]"}], ",", 
         RowBox[{"C6AcylCoAMAT", "[", "t", "]"}], ",", 
         RowBox[{"C4AcylCoAMAT", "[", "t", "]"}], ",", "CarMAT", ",", 
         "vmct1acet", ",", "kmct1acet", ",", "AcetateMAT", ",", 
         "propacetcpt2"}], "]"}]}], ",", "\[IndentingNewLine]", 
      RowBox[{"vcpt2C14", "\[Rule]", 
       RowBox[{"CPT2", "[", 
        RowBox[{
        "sfcpt2C14", ",", "Vcpt2", ",", "Kmcpt2C14AcylCarMAT", ",", 
         "Kmcpt2C16AcylCarMAT", ",", "Kmcpt2C12AcylCarMAT", ",", 
         "Kmcpt2C10AcylCarMAT", ",", "Kmcpt2C8AcylCarMAT", ",", 
         "Kmcpt2C6AcylCarMAT", ",", "Kmcpt2C4AcylCoAMAT", ",", "Kmcpt2CoAMAT",
          ",", "Kmcpt2C14AcylCoAMAT", ",", "Kmcpt2C16AcylCoAMAT", ",", 
         "Kmcpt2C12AcylCoAMAT", ",", "Kmcpt2C10AcylCoAMAT", ",", 
         "Kmcpt2C8AcylCoAMAT", ",", "Kmcpt2C6AcylCoAMAT", ",", 
         "Kmcpt2C4AcylCoAMAT", ",", "Kmcpt2CarMAT", ",", "Keqcpt2", ",", 
         RowBox[{"C14AcylCarMAT", "[", "t", "]"}], ",", 
         RowBox[{"C16AcylCarMAT", "[", "t", "]"}], ",", 
         RowBox[{"C12AcylCarMAT", "[", "t", "]"}], ",", 
         RowBox[{"C10AcylCarMAT", "[", "t", "]"}], ",", 
         RowBox[{"C8AcylCarMAT", "[", "t", "]"}], ",", 
         RowBox[{"C6AcylCarMAT", "[", "t", "]"}], ",", 
         RowBox[{"C4AcylCarMAT", "[", "t", "]"}], ",", "CoAMAT", ",", 
         RowBox[{"C14AcylCoAMAT", "[", "t", "]"}], ",", 
         RowBox[{"C16AcylCoAMAT", "[", "t", "]"}], ",", 
         RowBox[{"C12AcylCoAMAT", "[", "t", "]"}], ",", 
         RowBox[{"C10AcylCoAMAT", "[", "t", "]"}], ",", 
         RowBox[{"C8AcylCoAMAT", "[", "t", "]"}], ",", 
         RowBox[{"C6AcylCoAMAT", "[", "t", "]"}], ",", 
         RowBox[{"C4AcylCoAMAT", "[", "t", "]"}], ",", "CarMAT", ",", 
         "vmct1acet", ",", "kmct1acet", ",", "AcetateMAT", ",", 
         "propacetcpt2"}], "]"}]}], ",", 
      RowBox[{"vcpt2C12", "\[Rule]", 
       RowBox[{"CPT2", "[", 
        RowBox[{
        "sfcpt2C12", ",", "Vcpt2", ",", "Kmcpt2C12AcylCarMAT", ",", 
         "Kmcpt2C16AcylCarMAT", ",", "Kmcpt2C14AcylCarMAT", ",", 
         "Kmcpt2C10AcylCarMAT", ",", "Kmcpt2C8AcylCarMAT", ",", 
         "Kmcpt2C6AcylCarMAT", ",", "Kmcpt2C4AcylCarMAT", ",", "Kmcpt2CoAMAT",
          ",", "Kmcpt2C12AcylCoAMAT", ",", "Kmcpt2C16AcylCoAMAT", ",", 
         "Kmcpt2C14AcylCoAMAT", ",", "Kmcpt2C10AcylCoAMAT", ",", 
         "Kmcpt2C8AcylCoAMAT", ",", "Kmcpt2C6AcylCoAMAT", ",", 
         "Kmcpt2C4AcylCoAMAT", ",", "Kmcpt2CarMAT", ",", "Keqcpt2", ",", 
         RowBox[{"C12AcylCarMAT", "[", "t", "]"}], ",", 
         RowBox[{"C16AcylCarMAT", "[", "t", "]"}], ",", 
         RowBox[{"C14AcylCarMAT", "[", "t", "]"}], ",", 
         RowBox[{"C10AcylCarMAT", "[", "t", "]"}], ",", 
         RowBox[{"C8AcylCarMAT", "[", "t", "]"}], ",", 
         RowBox[{"C6AcylCarMAT", "[", "t", "]"}], ",", 
         RowBox[{"C4AcylCarMAT", "[", "t", "]"}], ",", "CoAMAT", ",", 
         RowBox[{"C12AcylCoAMAT", "[", "t", "]"}], ",", 
         RowBox[{"C16AcylCoAMAT", "[", "t", "]"}], ",", 
         RowBox[{"C14AcylCoAMAT", "[", "t", "]"}], ",", 
         RowBox[{"C10AcylCoAMAT", "[", "t", "]"}], ",", 
         RowBox[{"C8AcylCoAMAT", "[", "t", "]"}], ",", 
         RowBox[{"C6AcylCoAMAT", "[", "t", "]"}], ",", 
         RowBox[{"C4AcylCoAMAT", "[", "t", "]"}], ",", "CarMAT", ",", 
         "vmct1acet", ",", "kmct1acet", ",", "AcetateMAT", ",", 
         "propacetcpt2"}], "]"}]}], ",", 
      RowBox[{"vcpt2C10", "\[Rule]", 
       RowBox[{"CPT2", "[", 
        RowBox[{
        "sfcpt2C10", ",", "Vcpt2", ",", "Kmcpt2C10AcylCarMAT", ",", 
         "Kmcpt2C16AcylCarMAT", ",", "Kmcpt2C14AcylCarMAT", ",", 
         "Kmcpt2C12AcylCarMAT", ",", "Kmcpt2C8AcylCarMAT", ",", 
         "Kmcpt2C6AcylCarMAT", ",", "Kmcpt2C4AcylCarMAT", ",", "Kmcpt2CoAMAT",
          ",", "Kmcpt2C10AcylCoAMAT", ",", "Kmcpt2C16AcylCoAMAT", ",", 
         "Kmcpt2C14AcylCoAMAT", ",", "Kmcpt2C12AcylCoAMAT", ",", 
         "Kmcpt2C8AcylCoAMAT", ",", "Kmcpt2C6AcylCoAMAT", ",", 
         "Kmcpt2C4AcylCoAMAT", ",", "Kmcpt2CarMAT", ",", "Keqcpt2", ",", 
         RowBox[{"C10AcylCarMAT", "[", "t", "]"}], ",", 
         RowBox[{"C16AcylCarMAT", "[", "t", "]"}], ",", 
         RowBox[{"C14AcylCarMAT", "[", "t", "]"}], ",", 
         RowBox[{"C12AcylCarMAT", "[", "t", "]"}], ",", 
         RowBox[{"C8AcylCarMAT", "[", "t", "]"}], ",", 
         RowBox[{"C6AcylCarMAT", "[", "t", "]"}], ",", 
         RowBox[{"C4AcylCarMAT", "[", "t", "]"}], ",", "CoAMAT", ",", 
         RowBox[{"C10AcylCoAMAT", "[", "t", "]"}], ",", 
         RowBox[{"C16AcylCoAMAT", "[", "t", "]"}], ",", 
         RowBox[{"C14AcylCoAMAT", "[", "t", "]"}], ",", 
         RowBox[{"C12AcylCoAMAT", "[", "t", "]"}], ",", 
         RowBox[{"C8AcylCoAMAT", "[", "t", "]"}], ",", 
         RowBox[{"C6AcylCoAMAT", "[", "t", "]"}], ",", 
         RowBox[{"C4AcylCoAMAT", "[", "t", "]"}], ",", "CarMAT", ",", 
         "vmct1acet", ",", "kmct1acet", ",", "AcetateMAT", ",", 
         "propacetcpt2"}], "]"}]}], ",", "\[IndentingNewLine]", 
      RowBox[{"vcpt2C8", "\[Rule]", 
       RowBox[{"CPT2", "[", 
        RowBox[{
        "sfcpt2C8", ",", "Vcpt2", ",", "Kmcpt2C8AcylCarMAT", ",", 
         "Kmcpt2C16AcylCarMAT", ",", "Kmcpt2C14AcylCarMAT", ",", 
         "Kmcpt2C12AcylCarMAT", ",", "Kmcpt2C10AcylCarMAT", ",", 
         "Kmcpt2C6AcylCarMAT", ",", "Kmcpt2C4AcylCarMAT", ",", "Kmcpt2CoAMAT",
          ",", "Kmcpt2C8AcylCoAMAT", ",", "Kmcpt2C16AcylCoAMAT", ",", 
         "Kmcpt2C14AcylCoAMAT", ",", "Kmcpt2C12AcylCoAMAT", ",", 
         "Kmcpt2C10AcylCoAMAT", ",", "Kmcpt2C6AcylCoAMAT", ",", 
         "Kmcpt2C4AcylCoAMAT", ",", "Kmcpt2CarMAT", ",", "Keqcpt2", ",", 
         RowBox[{"C8AcylCarMAT", "[", "t", "]"}], ",", 
         RowBox[{"C16AcylCarMAT", "[", "t", "]"}], ",", 
         RowBox[{"C14AcylCarMAT", "[", "t", "]"}], ",", 
         RowBox[{"C12AcylCarMAT", "[", "t", "]"}], ",", 
         RowBox[{"C10AcylCarMAT", "[", "t", "]"}], ",", 
         RowBox[{"C6AcylCarMAT", "[", "t", "]"}], ",", 
         RowBox[{"C4AcylCarMAT", "[", "t", "]"}], ",", "CoAMAT", ",", 
         RowBox[{"C8AcylCoAMAT", "[", "t", "]"}], ",", 
         RowBox[{"C16AcylCoAMAT", "[", "t", "]"}], ",", 
         RowBox[{"C14AcylCoAMAT", "[", "t", "]"}], ",", 
         RowBox[{"C12AcylCoAMAT", "[", "t", "]"}], ",", 
         RowBox[{"C10AcylCoAMAT", "[", "t", "]"}], ",", 
         RowBox[{"C6AcylCoAMAT", "[", "t", "]"}], ",", 
         RowBox[{"C4AcylCoAMAT", "[", "t", "]"}], ",", "CarMAT", ",", 
         "vmct1acet", ",", "kmct1acet", ",", "AcetateMAT", ",", 
         "propacetcpt2"}], "]"}]}], ",", "\[IndentingNewLine]", 
      RowBox[{"vcpt2C6", "\[Rule]", 
       RowBox[{"CPT2", "[", 
        RowBox[{
        "sfcpt2C6", ",", "Vcpt2", ",", "Kmcpt2C6AcylCarMAT", ",", 
         "Kmcpt2C16AcylCarMAT", ",", "Kmcpt2C14AcylCarMAT", ",", 
         "Kmcpt2C12AcylCarMAT", ",", "Kmcpt2C10AcylCarMAT", ",", 
         "Kmcpt2C8AcylCarMAT", ",", "Kmcpt2C4AcylCarMAT", ",", "Kmcpt2CoAMAT",
          ",", "Kmcpt2C6AcylCoAMAT", ",", "Kmcpt2C16AcylCoAMAT", ",", 
         "Kmcpt2C14AcylCoAMAT", ",", "Kmcpt2C12AcylCoAMAT", ",", 
         "Kmcpt2C10AcylCoAMAT", ",", "Kmcpt2C8AcylCoAMAT", ",", 
         "Kmcpt2C4AcylCoAMAT", ",", "Kmcpt2CarMAT", ",", "Keqcpt2", ",", 
         RowBox[{"C6AcylCarMAT", "[", "t", "]"}], ",", 
         RowBox[{"C16AcylCarMAT", "[", "t", "]"}], ",", 
         RowBox[{"C14AcylCarMAT", "[", "t", "]"}], ",", 
         RowBox[{"C12AcylCarMAT", "[", "t", "]"}], ",", 
         RowBox[{"C10AcylCarMAT", "[", "t", "]"}], ",", 
         RowBox[{"C8AcylCarMAT", "[", "t", "]"}], ",", 
         RowBox[{"C4AcylCarMAT", "[", "t", "]"}], ",", "CoAMAT", ",", 
         RowBox[{"C6AcylCoAMAT", "[", "t", "]"}], ",", 
         RowBox[{"C16AcylCoAMAT", "[", "t", "]"}], ",", 
         RowBox[{"C14AcylCoAMAT", "[", "t", "]"}], ",", 
         RowBox[{"C12AcylCoAMAT", "[", "t", "]"}], ",", 
         RowBox[{"C10AcylCoAMAT", "[", "t", "]"}], ",", 
         RowBox[{"C8AcylCoAMAT", "[", "t", "]"}], ",", 
         RowBox[{"C4AcylCoAMAT", "[", "t", "]"}], ",", "CarMAT", ",", 
         "vmct1acet", ",", "kmct1acet", ",", "AcetateMAT", ",", 
         "propacetcpt2"}], "]"}]}], ",", "\[IndentingNewLine]", 
      RowBox[{"vcpt2C4", "\[Rule]", 
       RowBox[{"CPT2", "[", 
        RowBox[{
        "sfcpt2C4", ",", "Vcpt2", ",", "Kmcpt2C4AcylCarMAT", ",", 
         "Kmcpt2C16AcylCarMAT", ",", "Kmcpt2C14AcylCarMAT", ",", 
         "Kmcpt2C12AcylCarMAT", ",", "Kmcpt2C10AcylCarMAT", ",", 
         "Kmcpt2C8AcylCarMAT", ",", "Kmcpt2C6AcylCarMAT", ",", "Kmcpt2CoAMAT",
          ",", "Kmcpt2C4AcylCoAMAT", ",", "Kmcpt2C16AcylCoAMAT", ",", 
         "Kmcpt2C14AcylCoAMAT", ",", "Kmcpt2C12AcylCoAMAT", ",", 
         "Kmcpt2C10AcylCoAMAT", ",", "Kmcpt2C8AcylCoAMAT", ",", 
         "Kmcpt2C6AcylCoAMAT", ",", "Kmcpt2CarMAT", ",", "Keqcpt2", ",", 
         RowBox[{"C4AcylCarMAT", "[", "t", "]"}], ",", 
         RowBox[{"C16AcylCarMAT", "[", "t", "]"}], ",", 
         RowBox[{"C14AcylCarMAT", "[", "t", "]"}], ",", 
         RowBox[{"C12AcylCarMAT", "[", "t", "]"}], ",", 
         RowBox[{"C10AcylCarMAT", "[", "t", "]"}], ",", 
         RowBox[{"C8AcylCarMAT", "[", "t", "]"}], ",", 
         RowBox[{"C6AcylCarMAT", "[", "t", "]"}], ",", "CoAMAT", ",", 
         RowBox[{"C4AcylCoAMAT", "[", "t", "]"}], ",", 
         RowBox[{"C16AcylCoAMAT", "[", "t", "]"}], ",", 
         RowBox[{"C14AcylCoAMAT", "[", "t", "]"}], ",", 
         RowBox[{"C12AcylCoAMAT", "[", "t", "]"}], ",", 
         RowBox[{"C10AcylCoAMAT", "[", "t", "]"}], ",", 
         RowBox[{"C8AcylCoAMAT", "[", "t", "]"}], ",", 
         RowBox[{"C6AcylCoAMAT", "[", "t", "]"}], ",", "CarMAT", ",", 
         "vmct1acet", ",", "kmct1acet", ",", "AcetateMAT", ",", 
         "propacetcpt2"}], "]"}]}], ",", 
      RowBox[{"vvlcadC16", "\[Rule]", 
       RowBox[{"VLCAD", "[", 
        RowBox[{
        "sfvlcadC16", ",", "Vvlcad", ",", "KmvlcadC16AcylCoAMAT", ",", 
         "KmvlcadC14AcylCoAMAT", ",", "KmvlcadC12AcylCoAMAT", ",", 
         "KmvlcadFAD", ",", "KmvlcadC16EnoylCoAMAT", ",", 
         "KmvlcadC14EnoylCoAMAT", ",", "KmvlcadC12EnoylCoAMAT", ",", 
         "KmvlcadFADH", ",", "Keqvlcad", ",", 
         RowBox[{"C16AcylCoAMAT", "[", "t", "]"}], ",", 
         RowBox[{"C14AcylCoAMAT", "[", "t", "]"}], ",", 
         RowBox[{"C12AcylCoAMAT", "[", "t", "]"}], ",", "FADtMAT", ",", 
         RowBox[{"C16EnoylCoAMAT", "[", "t", "]"}], ",", 
         RowBox[{"C14EnoylCoAMAT", "[", "t", "]"}], ",", 
         RowBox[{"C12EnoylCoAMAT", "[", "t", "]"}], ",", 
         RowBox[{"FADHMAT", "[", "t", "]"}]}], "]"}]}], ",", 
      "\[IndentingNewLine]", 
      RowBox[{"vvlcadC14", "\[Rule]", 
       RowBox[{"VLCAD", "[", 
        RowBox[{
        "sfvlcadC14", ",", "Vvlcad", ",", "KmvlcadC14AcylCoAMAT", ",", 
         "KmvlcadC16AcylCoAMAT", ",", "KmvlcadC12AcylCoAMAT", ",", 
         "KmvlcadFAD", ",", "KmvlcadC14EnoylCoAMAT", ",", 
         "KmvlcadC16EnoylCoAMAT", ",", "KmvlcadC12EnoylCoAMAT", ",", 
         "KmvlcadFADH", ",", "Keqvlcad", ",", 
         RowBox[{"C14AcylCoAMAT", "[", "t", "]"}], ",", 
         RowBox[{"C16AcylCoAMAT", "[", "t", "]"}], ",", 
         RowBox[{"C12AcylCoAMAT", "[", "t", "]"}], ",", "FADtMAT", ",", 
         RowBox[{"C14EnoylCoAMAT", "[", "t", "]"}], ",", 
         RowBox[{"C16EnoylCoAMAT", "[", "t", "]"}], ",", 
         RowBox[{"C12EnoylCoAMAT", "[", "t", "]"}], ",", 
         RowBox[{"FADHMAT", "[", "t", "]"}]}], "]"}]}], ",", 
      "\[IndentingNewLine]", 
      RowBox[{"vvlcadC12", "\[Rule]", 
       RowBox[{"VLCAD", "[", 
        RowBox[{
        "sfvlcadC12", ",", "Vvlcad", ",", "KmvlcadC12AcylCoAMAT", ",", 
         "KmvlcadC16AcylCoAMAT", ",", "KmvlcadC14AcylCoAMAT", ",", 
         "KmvlcadFAD", ",", "KmvlcadC12EnoylCoAMAT", ",", 
         "KmvlcadC16EnoylCoAMAT", ",", "KmvlcadC14EnoylCoAMAT", ",", 
         "KmvlcadFADH", ",", "Keqvlcad", ",", 
         RowBox[{"C12AcylCoAMAT", "[", "t", "]"}], ",", 
         RowBox[{"C16AcylCoAMAT", "[", "t", "]"}], ",", 
         RowBox[{"C14AcylCoAMAT", "[", "t", "]"}], ",", "FADtMAT", ",", 
         RowBox[{"C12EnoylCoAMAT", "[", "t", "]"}], ",", 
         RowBox[{"C16EnoylCoAMAT", "[", "t", "]"}], ",", 
         RowBox[{"C14EnoylCoAMAT", "[", "t", "]"}], ",", 
         RowBox[{"FADHMAT", "[", "t", "]"}]}], "]"}]}], ",", 
      "\[IndentingNewLine]", 
      RowBox[{"vlcadC16", "\[Rule]", 
       RowBox[{"LCAD", "[", 
        RowBox[{
        "sflcadC16", ",", "Vlcad", ",", "KmlcadC16AcylCoAMAT", ",", 
         "KmlcadC14AcylCoAMAT", ",", "KmlcadC12AcylCoAMAT", ",", 
         "KmlcadC10AcylCoAMAT", ",", "KmlcadC8AcylCoAMAT", ",", "KmlcadFAD", 
         ",", "KmlcadC16EnoylCoAMAT", ",", "KmlcadC14EnoylCoAMAT", ",", 
         "KmlcadC12EnoylCoAMAT", ",", "KmlcadC10EnoylCoAMAT", ",", 
         "KmlcadC8EnoylCoAMAT", ",", "KmlcadFADH", ",", "Keqlcad", ",", 
         RowBox[{"C16AcylCoAMAT", "[", "t", "]"}], ",", 
         RowBox[{"C14AcylCoAMAT", "[", "t", "]"}], ",", 
         RowBox[{"C12AcylCoAMAT", "[", "t", "]"}], ",", 
         RowBox[{"C10AcylCoAMAT", "[", "t", "]"}], ",", 
         RowBox[{"C8AcylCoAMAT", "[", "t", "]"}], ",", "FADtMAT", ",", 
         RowBox[{"C16EnoylCoAMAT", "[", "t", "]"}], ",", 
         RowBox[{"C14EnoylCoAMAT", "[", "t", "]"}], ",", 
         RowBox[{"C12EnoylCoAMAT", "[", "t", "]"}], ",", 
         RowBox[{"C10EnoylCoAMAT", "[", "t", "]"}], ",", 
         RowBox[{"C8EnoylCoAMAT", "[", "t", "]"}], ",", 
         RowBox[{"FADHMAT", "[", "t", "]"}]}], "]"}]}], ",", 
      "\[IndentingNewLine]", 
      RowBox[{"vlcadC14", "\[Rule]", 
       RowBox[{"LCAD", "[", 
        RowBox[{
        "sflcadC14", ",", "Vlcad", ",", "KmlcadC14AcylCoAMAT", ",", 
         "KmlcadC16AcylCoAMAT", ",", "KmlcadC12AcylCoAMAT", ",", 
         "KmlcadC10AcylCoAMAT", ",", "KmlcadC8AcylCoAMAT", ",", "KmlcadFAD", 
         ",", "KmlcadC14EnoylCoAMAT", ",", "KmlcadC16EnoylCoAMAT", ",", 
         "KmlcadC12EnoylCoAMAT", ",", "KmlcadC10EnoylCoAMAT", ",", 
         "KmlcadC8EnoylCoAMAT", ",", "KmlcadFADH", ",", "Keqlcad", ",", 
         RowBox[{"C14AcylCoAMAT", "[", "t", "]"}], ",", 
         RowBox[{"C16AcylCoAMAT", "[", "t", "]"}], ",", 
         RowBox[{"C12AcylCoAMAT", "[", "t", "]"}], ",", 
         RowBox[{"C10AcylCoAMAT", "[", "t", "]"}], ",", 
         RowBox[{"C8AcylCoAMAT", "[", "t", "]"}], ",", "FADtMAT", ",", 
         RowBox[{"C14EnoylCoAMAT", "[", "t", "]"}], ",", 
         RowBox[{"C16EnoylCoAMAT", "[", "t", "]"}], ",", 
         RowBox[{"C12EnoylCoAMAT", "[", "t", "]"}], ",", 
         RowBox[{"C10EnoylCoAMAT", "[", "t", "]"}], ",", 
         RowBox[{"C8EnoylCoAMAT", "[", "t", "]"}], ",", 
         RowBox[{"FADHMAT", "[", "t", "]"}]}], "]"}]}], ",", 
      "\[IndentingNewLine]", 
      RowBox[{"vlcadC12", "\[Rule]", 
       RowBox[{"LCAD", "[", 
        RowBox[{
        "sflcadC12", ",", "Vlcad", ",", "KmlcadC12AcylCoAMAT", ",", 
         "KmlcadC16AcylCoAMAT", ",", "KmlcadC14AcylCoAMAT", ",", 
         "KmlcadC10AcylCoAMAT", ",", "KmlcadC8AcylCoAMAT", ",", "KmlcadFAD", 
         ",", "KmlcadC12EnoylCoAMAT", ",", "KmlcadC16EnoylCoAMAT", ",", 
         "KmlcadC14EnoylCoAMAT", ",", "KmlcadC10EnoylCoAMAT", ",", 
         "KmlcadC8EnoylCoAMAT", ",", "KmlcadFADH", ",", "Keqlcad", ",", 
         RowBox[{"C12AcylCoAMAT", "[", "t", "]"}], ",", 
         RowBox[{"C16AcylCoAMAT", "[", "t", "]"}], ",", 
         RowBox[{"C14AcylCoAMAT", "[", "t", "]"}], ",", 
         RowBox[{"C10AcylCoAMAT", "[", "t", "]"}], ",", 
         RowBox[{"C8AcylCoAMAT", "[", "t", "]"}], ",", "FADtMAT", ",", 
         RowBox[{"C14EnoylCoAMAT", "[", "t", "]"}], ",", 
         RowBox[{"C16EnoylCoAMAT", "[", "t", "]"}], ",", 
         RowBox[{"C14EnoylCoAMAT", "[", "t", "]"}], ",", 
         RowBox[{"C10EnoylCoAMAT", "[", "t", "]"}], ",", 
         RowBox[{"C8EnoylCoAMAT", "[", "t", "]"}], ",", 
         RowBox[{"FADHMAT", "[", "t", "]"}]}], "]"}]}], ",", 
      "\[IndentingNewLine]", 
      RowBox[{"vlcadC10", "\[Rule]", 
       RowBox[{"LCAD", "[", 
        RowBox[{
        "sflcadC10", ",", "Vlcad", ",", "KmlcadC10AcylCoAMAT", ",", 
         "KmlcadC16AcylCoAMAT", ",", "KmlcadC14AcylCoAMAT", ",", 
         "KmlcadC12AcylCoAMAT", ",", "KmlcadC8AcylCoAMAT", ",", "KmlcadFAD", 
         ",", "KmlcadC10EnoylCoAMAT", ",", "KmlcadC16EnoylCoAMAT", ",", 
         "KmlcadC14EnoylCoAMAT", ",", "KmlcadC12EnoylCoAMAT", ",", 
         "KmlcadC8EnoylCoAMAT", ",", "KmlcadFADH", ",", "Keqlcad", ",", 
         RowBox[{"C10AcylCoAMAT", "[", "t", "]"}], ",", 
         RowBox[{"C16AcylCoAMAT", "[", "t", "]"}], ",", 
         RowBox[{"C14AcylCoAMAT", "[", "t", "]"}], ",", 
         RowBox[{"C12AcylCoAMAT", "[", "t", "]"}], ",", 
         RowBox[{"C8AcylCoAMAT", "[", "t", "]"}], ",", "FADtMAT", ",", 
         RowBox[{"C10EnoylCoAMAT", "[", "t", "]"}], ",", 
         RowBox[{"C16EnoylCoAMAT", "[", "t", "]"}], ",", 
         RowBox[{"C14EnoylCoAMAT", "[", "t", "]"}], ",", 
         RowBox[{"C12EnoylCoAMAT", "[", "t", "]"}], ",", 
         RowBox[{"C8EnoylCoAMAT", "[", "t", "]"}], ",", 
         RowBox[{"FADHMAT", "[", "t", "]"}]}], "]"}]}], ",", 
      "\[IndentingNewLine]", 
      RowBox[{"vlcadC8", "\[Rule]", 
       RowBox[{"LCAD", "[", 
        RowBox[{
        "sflcadC8", ",", "Vlcad", ",", "KmlcadC8AcylCoAMAT", ",", 
         "KmlcadC16AcylCoAMAT", ",", "KmlcadC14AcylCoAMAT", ",", 
         "KmlcadC12AcylCoAMAT", ",", "KmlcadC10AcylCoAMAT", ",", "KmlcadFAD", 
         ",", "KmlcadC8EnoylCoAMAT", ",", "KmlcadC16EnoylCoAMAT", ",", 
         "KmlcadC14EnoylCoAMAT", ",", "KmlcadC12EnoylCoAMAT", ",", 
         "KmlcadC10EnoylCoAMAT", ",", "KmlcadFADH", ",", "Keqlcad", ",", 
         RowBox[{"C8AcylCoAMAT", "[", "t", "]"}], ",", 
         RowBox[{"C16AcylCoAMAT", "[", "t", "]"}], ",", 
         RowBox[{"C14AcylCoAMAT", "[", "t", "]"}], ",", 
         RowBox[{"C12AcylCoAMAT", "[", "t", "]"}], ",", 
         RowBox[{"C10AcylCoAMAT", "[", "t", "]"}], ",", "FADtMAT", ",", 
         RowBox[{"C8EnoylCoAMAT", "[", "t", "]"}], ",", 
         RowBox[{"C16EnoylCoAMAT", "[", "t", "]"}], ",", 
         RowBox[{"C14EnoylCoAMAT", "[", "t", "]"}], ",", 
         RowBox[{"C12EnoylCoAMAT", "[", "t", "]"}], ",", 
         RowBox[{"C10EnoylCoAMAT", "[", "t", "]"}], ",", 
         RowBox[{"FADHMAT", "[", "t", "]"}]}], "]"}]}], ",", 
      "\[IndentingNewLine]", 
      RowBox[{"vmcadC12", "\[Rule]", 
       RowBox[{"MCAD", "[", 
        RowBox[{
        "sfmcadC12", ",", "Vmcad", ",", "KmmcadC12AcylCoAMAT", ",", 
         "KmmcadC10AcylCoAMAT", ",", "KmmcadC8AcylCoAMAT", ",", 
         "KmmcadC6AcylCoAMAT", ",", "KmmcadC4AcylCoAMAT", ",", "KmmcadFAD", 
         ",", "KmmcadC12EnoylCoAMAT", ",", "KmmcadC10EnoylCoAMAT", ",", 
         "KmmcadC8EnoylCoAMAT", ",", "KmmcadC6EnoylCoAMAT", ",", 
         "KmmcadC4EnoylCoAMAT", ",", "KmmcadFADH", ",", "Keqmcad", ",", 
         RowBox[{"C12AcylCoAMAT", "[", "t", "]"}], ",", 
         RowBox[{"C10AcylCoAMAT", "[", "t", "]"}], ",", 
         RowBox[{"C8AcylCoAMAT", "[", "t", "]"}], ",", 
         RowBox[{"C6AcylCoAMAT", "[", "t", "]"}], ",", 
         RowBox[{"C4AcylCoAMAT", "[", "t", "]"}], ",", "FADtMAT", ",", 
         RowBox[{"C12EnoylCoAMAT", "[", "t", "]"}], ",", 
         RowBox[{"C10EnoylCoAMAT", "[", "t", "]"}], ",", 
         RowBox[{"C8EnoylCoAMAT", "[", "t", "]"}], ",", 
         RowBox[{"C6EnoylCoAMAT", "[", "t", "]"}], ",", 
         RowBox[{"C4EnoylCoAMAT", "[", "t", "]"}], ",", 
         RowBox[{"FADHMAT", "[", "t", "]"}]}], "]"}]}], ",", 
      "\[IndentingNewLine]", 
      RowBox[{"vmcadC10", "\[Rule]", 
       RowBox[{"MCAD", "[", 
        RowBox[{
        "sfmcadC10", ",", "Vmcad", ",", "KmmcadC10AcylCoAMAT", ",", 
         "KmmcadC12AcylCoAMAT", ",", "KmmcadC8AcylCoAMAT", ",", 
         "KmmcadC6AcylCoAMAT", ",", "KmmcadC4AcylCoAMAT", ",", "KmmcadFAD", 
         ",", "KmmcadC10EnoylCoAMAT", ",", "KmmcadC12EnoylCoAMAT", ",", 
         "KmmcadC8EnoylCoAMAT", ",", "KmmcadC6EnoylCoAMAT", ",", 
         "KmmcadC4EnoylCoAMAT", ",", "KmmcadFADH", ",", "Keqmcad", ",", 
         RowBox[{"C10AcylCoAMAT", "[", "t", "]"}], ",", 
         RowBox[{"C12AcylCoAMAT", "[", "t", "]"}], ",", 
         RowBox[{"C8AcylCoAMAT", "[", "t", "]"}], ",", 
         RowBox[{"C6AcylCoAMAT", "[", "t", "]"}], ",", 
         RowBox[{"C4AcylCoAMAT", "[", "t", "]"}], ",", "FADtMAT", ",", 
         RowBox[{"C10EnoylCoAMAT", "[", "t", "]"}], ",", 
         RowBox[{"C12EnoylCoAMAT", "[", "t", "]"}], ",", 
         RowBox[{"C8EnoylCoAMAT", "[", "t", "]"}], ",", 
         RowBox[{"C6EnoylCoAMAT", "[", "t", "]"}], ",", 
         RowBox[{"C4EnoylCoAMAT", "[", "t", "]"}], ",", 
         RowBox[{"FADHMAT", "[", "t", "]"}]}], "]"}]}], ",", 
      "\[IndentingNewLine]", 
      RowBox[{"vmcadC8", "\[Rule]", 
       RowBox[{"MCAD", "[", 
        RowBox[{
        "sfmcadC8", ",", "Vmcad", ",", "KmmcadC8AcylCoAMAT", ",", 
         "KmmcadC12AcylCoAMAT", ",", "KmmcadC10AcylCoAMAT", ",", 
         "KmmcadC6AcylCoAMAT", ",", "KmmcadC4AcylCoAMAT", ",", "KmmcadFAD", 
         ",", "KmmcadC8EnoylCoAMAT", ",", "KmmcadC12EnoylCoAMAT", ",", 
         "KmmcadC10EnoylCoAMAT", ",", "KmmcadC6EnoylCoAMAT", ",", 
         "KmmcadC4EnoylCoAMAT", ",", "KmmcadFADH", ",", "Keqmcad", ",", 
         RowBox[{"C8AcylCoAMAT", "[", "t", "]"}], ",", 
         RowBox[{"C12AcylCoAMAT", "[", "t", "]"}], ",", 
         RowBox[{"C10AcylCoAMAT", "[", "t", "]"}], ",", 
         RowBox[{"C6AcylCoAMAT", "[", "t", "]"}], ",", 
         RowBox[{"C4AcylCoAMAT", "[", "t", "]"}], ",", "FADtMAT", ",", 
         RowBox[{"C8EnoylCoAMAT", "[", "t", "]"}], ",", 
         RowBox[{"C12EnoylCoAMAT", "[", "t", "]"}], ",", 
         RowBox[{"C10EnoylCoAMAT", "[", "t", "]"}], ",", 
         RowBox[{"C6EnoylCoAMAT", "[", "t", "]"}], ",", 
         RowBox[{"C4EnoylCoAMAT", "[", "t", "]"}], ",", 
         RowBox[{"FADHMAT", "[", "t", "]"}]}], "]"}]}], ",", 
      "\[IndentingNewLine]", 
      RowBox[{"vmcadC6", "\[Rule]", 
       RowBox[{"MCAD", "[", 
        RowBox[{
        "sfmcadC6", ",", "Vmcad", ",", "KmmcadC6AcylCoAMAT", ",", 
         "KmmcadC12AcylCoAMAT", ",", "KmmcadC10AcylCoAMAT", ",", 
         "KmmcadC8AcylCoAMAT", ",", "KmmcadC4AcylCoAMAT", ",", "KmmcadFAD", 
         ",", "KmmcadC6EnoylCoAMAT", ",", "KmmcadC12EnoylCoAMAT", ",", 
         "KmmcadC10EnoylCoAMAT", ",", "KmmcadC8EnoylCoAMAT", ",", 
         "KmmcadC4EnoylCoAMAT", ",", "KmmcadFADH", ",", "Keqmcad", ",", 
         RowBox[{"C6AcylCoAMAT", "[", "t", "]"}], ",", 
         RowBox[{"C12AcylCoAMAT", "[", "t", "]"}], ",", 
         RowBox[{"C10AcylCoAMAT", "[", "t", "]"}], ",", 
         RowBox[{"C8AcylCoAMAT", "[", "t", "]"}], ",", 
         RowBox[{"C4AcylCoAMAT", "[", "t", "]"}], ",", "FADtMAT", ",", 
         RowBox[{"C6EnoylCoAMAT", "[", "t", "]"}], ",", 
         RowBox[{"C12EnoylCoAMAT", "[", "t", "]"}], ",", 
         RowBox[{"C10EnoylCoAMAT", "[", "t", "]"}], ",", 
         RowBox[{"C8EnoylCoAMAT", "[", "t", "]"}], ",", 
         RowBox[{"C4EnoylCoAMAT", "[", "t", "]"}], ",", 
         RowBox[{"FADHMAT", "[", "t", "]"}]}], "]"}]}], ",", 
      "\[IndentingNewLine]", 
      RowBox[{"vmcadC4", "\[Rule]", 
       RowBox[{"MCAD", "[", 
        RowBox[{
        "sfmcadC4", ",", "Vmcad", ",", "KmmcadC4AcylCoAMAT", ",", 
         "KmmcadC12AcylCoAMAT", ",", "KmmcadC10AcylCoAMAT", ",", 
         "KmmcadC8AcylCoAMAT", ",", "KmmcadC6AcylCoAMAT", ",", "KmmcadFAD", 
         ",", "KmmcadC4EnoylCoAMAT", ",", "KmmcadC12EnoylCoAMAT", ",", 
         "KmmcadC10EnoylCoAMAT", ",", "KmmcadC8EnoylCoAMAT", ",", 
         "KmmcadC6EnoylCoAMAT", ",", "KmmcadFADH", ",", "Keqmcad", ",", 
         RowBox[{"C4AcylCoAMAT", "[", "t", "]"}], ",", 
         RowBox[{"C12AcylCoAMAT", "[", "t", "]"}], ",", 
         RowBox[{"C10AcylCoAMAT", "[", "t", "]"}], ",", 
         RowBox[{"C8AcylCoAMAT", "[", "t", "]"}], ",", 
         RowBox[{"C6AcylCoAMAT", "[", "t", "]"}], ",", "FADtMAT", ",", 
         RowBox[{"C4EnoylCoAMAT", "[", "t", "]"}], ",", 
         RowBox[{"C12EnoylCoAMAT", "[", "t", "]"}], ",", 
         RowBox[{"C10EnoylCoAMAT", "[", "t", "]"}], ",", 
         RowBox[{"C8EnoylCoAMAT", "[", "t", "]"}], ",", 
         RowBox[{"C6EnoylCoAMAT", "[", "t", "]"}], ",", 
         RowBox[{"FADHMAT", "[", "t", "]"}]}], "]"}]}], ",", 
      "\[IndentingNewLine]", 
      RowBox[{"vscadC6", "\[Rule]", 
       RowBox[{"SCAD", "[", 
        RowBox[{
        "sfscadC6", ",", "Vscad", ",", "KmscadC6AcylCoAMAT", ",", 
         "KmscadC4AcylCoAMAT", ",", "KmscadFAD", ",", "KmscadC6EnoylCoAMAT", 
         ",", "KmscadC4EnoylCoAMAT", ",", "KmscadFADH", ",", "Keqscad", ",", 
         RowBox[{"C6AcylCoAMAT", "[", "t", "]"}], ",", 
         RowBox[{"C4AcylCoAMAT", "[", "t", "]"}], ",", "FADtMAT", ",", 
         RowBox[{"C6EnoylCoAMAT", "[", "t", "]"}], ",", 
         RowBox[{"C4EnoylCoAMAT", "[", "t", "]"}], ",", 
         RowBox[{"FADHMAT", "[", "t", "]"}]}], "]"}]}], ",", 
      "\[IndentingNewLine]", 
      RowBox[{"vscadC4", "\[Rule]", 
       RowBox[{"SCAD", "[", 
        RowBox[{
        "sfscadC4", ",", "Vscad", ",", "KmscadC4AcylCoAMAT", ",", 
         "KmscadC6AcylCoAMAT", ",", "KmscadFAD", ",", "KmscadC4EnoylCoAMAT", 
         ",", "KmscadC6EnoylCoAMAT", ",", "KmscadFADH", ",", "Keqscad", ",", 
         RowBox[{"C4AcylCoAMAT", "[", "t", "]"}], ",", 
         RowBox[{"C6AcylCoAMAT", "[", "t", "]"}], ",", "FADtMAT", ",", 
         RowBox[{"C4EnoylCoAMAT", "[", "t", "]"}], ",", 
         RowBox[{"C6EnoylCoAMAT", "[", "t", "]"}], ",", 
         RowBox[{"FADHMAT", "[", "t", "]"}]}], "]"}]}], ",", 
      "\[IndentingNewLine]", 
      RowBox[{"vcrotC16", "\[Rule]", 
       RowBox[{"CROT", "[", 
        RowBox[{
        "sfcrotC16", ",", "Vcrot", ",", "KmcrotC16EnoylCoAMAT", ",", 
         "KmcrotC14EnoylCoAMAT", ",", "KmcrotC12EnoylCoAMAT", ",", 
         "KmcrotC10EnoylCoAMAT", ",", "KmcrotC8EnoylCoAMAT", ",", 
         "KmcrotC6EnoylCoAMAT", ",", "KmcrotC4EnoylCoAMAT", ",", 
         "KmcrotC16HydroxyacylCoAMAT", ",", "KmcrotC14HydroxyacylCoAMAT", ",",
          "KmcrotC12HydroxyacylCoAMAT", ",", "KmcrotC10HydroxyacylCoAMAT", 
         ",", "KmcrotC8HydroxyacylCoAMAT", ",", "KmcrotC6HydroxyacylCoAMAT", 
         ",", "KmcrotC4HydroxyacylCoAMAT", ",", "KicrotC4AcetoacylCoA", ",", 
         "Keqcrot", ",", 
         RowBox[{"C16EnoylCoAMAT", "[", "t", "]"}], ",", 
         RowBox[{"C14EnoylCoAMAT", "[", "t", "]"}], ",", 
         RowBox[{"C12EnoylCoAMAT", "[", "t", "]"}], ",", 
         RowBox[{"C10EnoylCoAMAT", "[", "t", "]"}], ",", 
         RowBox[{"C8EnoylCoAMAT", "[", "t", "]"}], ",", 
         RowBox[{"C6EnoylCoAMAT", "[", "t", "]"}], ",", 
         RowBox[{"C4EnoylCoAMAT", "[", "t", "]"}], ",", 
         RowBox[{"C16HydroxyacylCoAMAT", "[", "t", "]"}], ",", 
         RowBox[{"C14HydroxyacylCoAMAT", "[", "t", "]"}], ",", 
         RowBox[{"C12HydroxyacylCoAMAT", "[", "t", "]"}], ",", 
         RowBox[{"C10HydroxyacylCoAMAT", "[", "t", "]"}], ",", 
         RowBox[{"C8HydroxyacylCoAMAT", "[", "t", "]"}], ",", 
         RowBox[{"C6HydroxyacylCoAMAT", "[", "t", "]"}], ",", 
         RowBox[{"C4HydroxyacylCoAMAT", "[", "t", "]"}], ",", 
         RowBox[{"C4AcetoacylCoAMAT", "[", "t", "]"}]}], "]"}]}], ",", 
      "\[IndentingNewLine]", 
      RowBox[{"vcrotC14", "\[Rule]", 
       RowBox[{"CROT", "[", 
        RowBox[{
        "sfcrotC14", ",", "Vcrot", ",", "KmcrotC14EnoylCoAMAT", ",", 
         "KmcrotC16EnoylCoAMAT", ",", "KmcrotC12EnoylCoAMAT", ",", 
         "KmcrotC10EnoylCoAMAT", ",", "KmcrotC8EnoylCoAMAT", ",", 
         "KmcrotC6EnoylCoAMAT", ",", "KmcrotC4EnoylCoAMAT", ",", 
         "KmcrotC14HydroxyacylCoAMAT", ",", "KmcrotC16HydroxyacylCoAMAT", ",",
          "KmcrotC12HydroxyacylCoAMAT", ",", "KmcrotC10HydroxyacylCoAMAT", 
         ",", "KmcrotC8HydroxyacylCoAMAT", ",", "KmcrotC6HydroxyacylCoAMAT", 
         ",", "KmcrotC4HydroxyacylCoAMAT", ",", "KicrotC4AcetoacylCoA", ",", 
         "Keqcrot", ",", 
         RowBox[{"C14EnoylCoAMAT", "[", "t", "]"}], ",", 
         RowBox[{"C16EnoylCoAMAT", "[", "t", "]"}], ",", 
         RowBox[{"C12EnoylCoAMAT", "[", "t", "]"}], ",", 
         RowBox[{"C10EnoylCoAMAT", "[", "t", "]"}], ",", 
         RowBox[{"C8EnoylCoAMAT", "[", "t", "]"}], ",", 
         RowBox[{"C6EnoylCoAMAT", "[", "t", "]"}], ",", 
         RowBox[{"C4EnoylCoAMAT", "[", "t", "]"}], ",", 
         RowBox[{"C14HydroxyacylCoAMAT", "[", "t", "]"}], ",", 
         RowBox[{"C16HydroxyacylCoAMAT", "[", "t", "]"}], ",", 
         RowBox[{"C12HydroxyacylCoAMAT", "[", "t", "]"}], ",", 
         RowBox[{"C10HydroxyacylCoAMAT", "[", "t", "]"}], ",", 
         RowBox[{"C8HydroxyacylCoAMAT", "[", "t", "]"}], ",", 
         RowBox[{"C6HydroxyacylCoAMAT", "[", "t", "]"}], ",", 
         RowBox[{"C4HydroxyacylCoAMAT", "[", "t", "]"}], ",", 
         RowBox[{"C4AcetoacylCoAMAT", "[", "t", "]"}]}], "]"}]}], ",", 
      "\[IndentingNewLine]", 
      RowBox[{"vcrotC12", "\[Rule]", 
       RowBox[{"CROT", "[", 
        RowBox[{
        "sfcrotC12", ",", "Vcrot", ",", "KmcrotC12EnoylCoAMAT", ",", 
         "KmcrotC16EnoylCoAMAT", ",", "KmcrotC14EnoylCoAMAT", ",", 
         "KmcrotC10EnoylCoAMAT", ",", "KmcrotC8EnoylCoAMAT", ",", 
         "KmcrotC6EnoylCoAMAT", ",", "KmcrotC4EnoylCoAMAT", ",", 
         "KmcrotC12HydroxyacylCoAMAT", ",", "KmcrotC16HydroxyacylCoAMAT", ",",
          "KmcrotC14HydroxyacylCoAMAT", ",", "KmcrotC10HydroxyacylCoAMAT", 
         ",", "KmcrotC8HydroxyacylCoAMAT", ",", "KmcrotC6HydroxyacylCoAMAT", 
         ",", "KmcrotC4HydroxyacylCoAMAT", ",", "KicrotC4AcetoacylCoA", ",", 
         "Keqcrot", ",", 
         RowBox[{"C12EnoylCoAMAT", "[", "t", "]"}], ",", 
         RowBox[{"C16EnoylCoAMAT", "[", "t", "]"}], ",", 
         RowBox[{"C14EnoylCoAMAT", "[", "t", "]"}], ",", 
         RowBox[{"C10EnoylCoAMAT", "[", "t", "]"}], ",", 
         RowBox[{"C8EnoylCoAMAT", "[", "t", "]"}], ",", 
         RowBox[{"C6EnoylCoAMAT", "[", "t", "]"}], ",", 
         RowBox[{"C4EnoylCoAMAT", "[", "t", "]"}], ",", 
         RowBox[{"C12HydroxyacylCoAMAT", "[", "t", "]"}], ",", 
         RowBox[{"C16HydroxyacylCoAMAT", "[", "t", "]"}], ",", 
         RowBox[{"C14HydroxyacylCoAMAT", "[", "t", "]"}], ",", 
         RowBox[{"C10HydroxyacylCoAMAT", "[", "t", "]"}], ",", 
         RowBox[{"C8HydroxyacylCoAMAT", "[", "t", "]"}], ",", 
         RowBox[{"C6HydroxyacylCoAMAT", "[", "t", "]"}], ",", 
         RowBox[{"C4HydroxyacylCoAMAT", "[", "t", "]"}], ",", 
         RowBox[{"C4AcetoacylCoAMAT", "[", "t", "]"}]}], "]"}]}], ",", 
      "\[IndentingNewLine]", 
      RowBox[{"vcrotC10", "\[Rule]", 
       RowBox[{"CROT", "[", 
        RowBox[{
        "sfcrotC10", ",", "Vcrot", ",", "KmcrotC10EnoylCoAMAT", ",", 
         "KmcrotC16EnoylCoAMAT", ",", "KmcrotC14EnoylCoAMAT", ",", 
         "KmcrotC12EnoylCoAMAT", ",", "KmcrotC8EnoylCoAMAT", ",", 
         "KmcrotC6EnoylCoAMAT", ",", "KmcrotC4EnoylCoAMAT", ",", 
         "KmcrotC10HydroxyacylCoAMAT", ",", "KmcrotC16HydroxyacylCoAMAT", ",",
          "KmcrotC14HydroxyacylCoAMAT", ",", "KmcrotC12HydroxyacylCoAMAT", 
         ",", "KmcrotC8HydroxyacylCoAMAT", ",", "KmcrotC6HydroxyacylCoAMAT", 
         ",", "KmcrotC4HydroxyacylCoAMAT", ",", "KicrotC4AcetoacylCoA", ",", 
         "Keqcrot", ",", 
         RowBox[{"C10EnoylCoAMAT", "[", "t", "]"}], ",", 
         RowBox[{"C16EnoylCoAMAT", "[", "t", "]"}], ",", 
         RowBox[{"C14EnoylCoAMAT", "[", "t", "]"}], ",", 
         RowBox[{"C12EnoylCoAMAT", "[", "t", "]"}], ",", 
         RowBox[{"C8EnoylCoAMAT", "[", "t", "]"}], ",", 
         RowBox[{"C6EnoylCoAMAT", "[", "t", "]"}], ",", 
         RowBox[{"C4EnoylCoAMAT", "[", "t", "]"}], ",", 
         RowBox[{"C10HydroxyacylCoAMAT", "[", "t", "]"}], ",", 
         RowBox[{"C16HydroxyacylCoAMAT", "[", "t", "]"}], ",", 
         RowBox[{"C14HydroxyacylCoAMAT", "[", "t", "]"}], ",", 
         RowBox[{"C12HydroxyacylCoAMAT", "[", "t", "]"}], ",", 
         RowBox[{"C8HydroxyacylCoAMAT", "[", "t", "]"}], ",", 
         RowBox[{"C6HydroxyacylCoAMAT", "[", "t", "]"}], ",", 
         RowBox[{"C4HydroxyacylCoAMAT", "[", "t", "]"}], ",", 
         RowBox[{"C4AcetoacylCoAMAT", "[", "t", "]"}]}], "]"}]}], ",", 
      "\[IndentingNewLine]", 
      RowBox[{"vcrotC8", "\[Rule]", 
       RowBox[{"CROT", "[", 
        RowBox[{
        "sfcrotC8", ",", "Vcrot", ",", "KmcrotC8EnoylCoAMAT", ",", 
         "KmcrotC16EnoylCoAMAT", ",", "KmcrotC14EnoylCoAMAT", ",", 
         "KmcrotC12EnoylCoAMAT", ",", "KmcrotC10EnoylCoAMAT", ",", 
         "KmcrotC6EnoylCoAMAT", ",", "KmcrotC4EnoylCoAMAT", ",", 
         "KmcrotC8HydroxyacylCoAMAT", ",", "KmcrotC16HydroxyacylCoAMAT", ",", 
         "KmcrotC14HydroxyacylCoAMAT", ",", "KmcrotC12HydroxyacylCoAMAT", ",",
          "KmcrotC10HydroxyacylCoAMAT", ",", "KmcrotC6HydroxyacylCoAMAT", ",",
          "KmcrotC4HydroxyacylCoAMAT", ",", "KicrotC4AcetoacylCoA", ",", 
         "Keqcrot", ",", 
         RowBox[{"C8EnoylCoAMAT", "[", "t", "]"}], ",", 
         RowBox[{"C16EnoylCoAMAT", "[", "t", "]"}], ",", 
         RowBox[{"C14EnoylCoAMAT", "[", "t", "]"}], ",", 
         RowBox[{"C12EnoylCoAMAT", "[", "t", "]"}], ",", 
         RowBox[{"C10EnoylCoAMAT", "[", "t", "]"}], ",", 
         RowBox[{"C6EnoylCoAMAT", "[", "t", "]"}], ",", 
         RowBox[{"C4EnoylCoAMAT", "[", "t", "]"}], ",", 
         RowBox[{"C8HydroxyacylCoAMAT", "[", "t", "]"}], ",", 
         RowBox[{"C16HydroxyacylCoAMAT", "[", "t", "]"}], ",", 
         RowBox[{"C14HydroxyacylCoAMAT", "[", "t", "]"}], ",", 
         RowBox[{"C12HydroxyacylCoAMAT", "[", "t", "]"}], ",", 
         RowBox[{"C10HydroxyacylCoAMAT", "[", "t", "]"}], ",", 
         RowBox[{"C6HydroxyacylCoAMAT", "[", "t", "]"}], ",", 
         RowBox[{"C4HydroxyacylCoAMAT", "[", "t", "]"}], ",", 
         RowBox[{"C4AcetoacylCoAMAT", "[", "t", "]"}]}], "]"}]}], ",", 
      "\[IndentingNewLine]", 
      RowBox[{"vcrotC6", "\[Rule]", 
       RowBox[{"CROT", "[", 
        RowBox[{
        "sfcrotC6", ",", "Vcrot", ",", "KmcrotC6EnoylCoAMAT", ",", 
         "KmcrotC16EnoylCoAMAT", ",", "KmcrotC14EnoylCoAMAT", ",", 
         "KmcrotC12EnoylCoAMAT", ",", "KmcrotC10EnoylCoAMAT", ",", 
         "KmcrotC8EnoylCoAMAT", ",", "KmcrotC4EnoylCoAMAT", ",", 
         "KmcrotC6HydroxyacylCoAMAT", ",", "KmcrotC16HydroxyacylCoAMAT", ",", 
         "KmcrotC14HydroxyacylCoAMAT", ",", "KmcrotC12HydroxyacylCoAMAT", ",",
          "KmcrotC10HydroxyacylCoAMAT", ",", "KmcrotC8HydroxyacylCoAMAT", ",",
          "KmcrotC4HydroxyacylCoAMAT", ",", "KicrotC4AcetoacylCoA", ",", 
         "Keqcrot", ",", 
         RowBox[{"C6EnoylCoAMAT", "[", "t", "]"}], ",", 
         RowBox[{"C16EnoylCoAMAT", "[", "t", "]"}], ",", 
         RowBox[{"C14EnoylCoAMAT", "[", "t", "]"}], ",", 
         RowBox[{"C12EnoylCoAMAT", "[", "t", "]"}], ",", 
         RowBox[{"C10EnoylCoAMAT", "[", "t", "]"}], ",", 
         RowBox[{"C8EnoylCoAMAT", "[", "t", "]"}], ",", 
         RowBox[{"C4EnoylCoAMAT", "[", "t", "]"}], ",", 
         RowBox[{"C6HydroxyacylCoAMAT", "[", "t", "]"}], ",", 
         RowBox[{"C16HydroxyacylCoAMAT", "[", "t", "]"}], ",", 
         RowBox[{"C14HydroxyacylCoAMAT", "[", "t", "]"}], ",", 
         RowBox[{"C12HydroxyacylCoAMAT", "[", "t", "]"}], ",", 
         RowBox[{"C10HydroxyacylCoAMAT", "[", "t", "]"}], ",", 
         RowBox[{"C8HydroxyacylCoAMAT", "[", "t", "]"}], ",", 
         RowBox[{"C4HydroxyacylCoAMAT", "[", "t", "]"}], ",", 
         RowBox[{"C4AcetoacylCoAMAT", "[", "t", "]"}]}], "]"}]}], ",", 
      "\[IndentingNewLine]", 
      RowBox[{"vcrotC4", "\[Rule]", 
       RowBox[{"CROT", "[", 
        RowBox[{
        "sfcrotC4", ",", "Vcrot", ",", "KmcrotC4EnoylCoAMAT", ",", 
         "KmcrotC16EnoylCoAMAT", ",", "KmcrotC14EnoylCoAMAT", ",", 
         "KmcrotC12EnoylCoAMAT", ",", "KmcrotC10EnoylCoAMAT", ",", 
         "KmcrotC8EnoylCoAMAT", ",", "KmcrotC6EnoylCoAMAT", ",", 
         "KmcrotC4HydroxyacylCoAMAT", ",", "KmcrotC16HydroxyacylCoAMAT", ",", 
         "KmcrotC14HydroxyacylCoAMAT", ",", "KmcrotC12HydroxyacylCoAMAT", ",",
          "KmcrotC10HydroxyacylCoAMAT", ",", "KmcrotC8HydroxyacylCoAMAT", ",",
          "KmcrotC6HydroxyacylCoAMAT", ",", "KicrotC4AcetoacylCoA", ",", 
         "Keqcrot", ",", 
         RowBox[{"C4EnoylCoAMAT", "[", "t", "]"}], ",", 
         RowBox[{"C16EnoylCoAMAT", "[", "t", "]"}], ",", 
         RowBox[{"C14EnoylCoAMAT", "[", "t", "]"}], ",", 
         RowBox[{"C12EnoylCoAMAT", "[", "t", "]"}], ",", 
         RowBox[{"C10EnoylCoAMAT", "[", "t", "]"}], ",", 
         RowBox[{"C8EnoylCoAMAT", "[", "t", "]"}], ",", 
         RowBox[{"C6EnoylCoAMAT", "[", "t", "]"}], ",", 
         RowBox[{"C4HydroxyacylCoAMAT", "[", "t", "]"}], ",", 
         RowBox[{"C16HydroxyacylCoAMAT", "[", "t", "]"}], ",", 
         RowBox[{"C14HydroxyacylCoAMAT", "[", "t", "]"}], ",", 
         RowBox[{"C12HydroxyacylCoAMAT", "[", "t", "]"}], ",", 
         RowBox[{"C10HydroxyacylCoAMAT", "[", "t", "]"}], ",", 
         RowBox[{"C8HydroxyacylCoAMAT", "[", "t", "]"}], ",", 
         RowBox[{"C6HydroxyacylCoAMAT", "[", "t", "]"}], ",", 
         RowBox[{"C4AcetoacylCoAMAT", "[", "t", "]"}]}], "]"}]}], ",", " ", 
      "\[IndentingNewLine]", 
      RowBox[{"vmschadC16", "\[Rule]", 
       RowBox[{"MSCHAD", "[", 
        RowBox[{
        "sfmschadC16", ",", "Vmschad", ",", "KmmschadC16HydroxyacylCoAMAT", 
         ",", "KmmschadC14HydroxyacylCoAMAT", ",", 
         "KmmschadC12HydroxyacylCoAMAT", ",", "KmmschadC10HydroxyacylCoAMAT", 
         ",", "KmmschadC8HydroxyacylCoAMAT", ",", 
         "KmmschadC6HydroxyacylCoAMAT", ",", "KmmschadC4HydroxyacylCoAMAT", 
         ",", "KmmschadNADMAT", ",", "KmmschadC16KetoacylCoAMAT", ",", 
         "KmmschadC14KetoacylCoAMAT", ",", "KmmschadC12KetoacylCoAMAT", ",", 
         "KmmschadC10KetoacylCoAMAT", ",", "KmmschadC8KetoacylCoAMAT", ",", 
         "KmmschadC6KetoacylCoAMAT", ",", "KmmschadC4AcetoacylCoAMAT", ",", 
         "KmmschadNADHMAT", ",", "Keqmschad", ",", 
         RowBox[{"C16HydroxyacylCoAMAT", "[", "t", "]"}], ",", 
         RowBox[{"C14HydroxyacylCoAMAT", "[", "t", "]"}], ",", 
         RowBox[{"C12HydroxyacylCoAMAT", "[", "t", "]"}], ",", 
         RowBox[{"C10HydroxyacylCoAMAT", "[", "t", "]"}], ",", 
         RowBox[{"C8HydroxyacylCoAMAT", "[", "t", "]"}], ",", 
         RowBox[{"C6HydroxyacylCoAMAT", "[", "t", "]"}], ",", 
         RowBox[{"C4HydroxyacylCoAMAT", "[", "t", "]"}], ",", "NADtMAT", ",", 
         RowBox[{"C16KetoacylCoAMAT", "[", "t", "]"}], ",", 
         RowBox[{"C14KetoacylCoAMAT", "[", "t", "]"}], ",", 
         RowBox[{"C12KetoacylCoAMAT", "[", "t", "]"}], ",", 
         RowBox[{"C10KetoacylCoAMAT", "[", "t", "]"}], ",", 
         RowBox[{"C8KetoacylCoAMAT", "[", "t", "]"}], ",", 
         RowBox[{"C6KetoacylCoAMAT", "[", "t", "]"}], ",", 
         RowBox[{"C4AcetoacylCoAMAT", "[", "t", "]"}], ",", 
         RowBox[{"NADHMAT", "[", "t", "]"}]}], "]"}]}], ",", 
      "\[IndentingNewLine]", 
      RowBox[{"vmschadC14", "\[Rule]", 
       RowBox[{"MSCHAD", "[", 
        RowBox[{
        "sfmschadC14", ",", "Vmschad", ",", "KmmschadC14HydroxyacylCoAMAT", 
         ",", "KmmschadC16HydroxyacylCoAMAT", ",", 
         "KmmschadC12HydroxyacylCoAMAT", ",", "KmmschadC10HydroxyacylCoAMAT", 
         ",", "KmmschadC8HydroxyacylCoAMAT", ",", 
         "KmmschadC6HydroxyacylCoAMAT", ",", "KmmschadC4HydroxyacylCoAMAT", 
         ",", "KmmschadNADMAT", ",", "KmmschadC14KetoacylCoAMAT", ",", 
         "KmmschadC16KetoacylCoAMAT", ",", "KmmschadC12KetoacylCoAMAT", ",", 
         "KmmschadC10KetoacylCoAMAT", ",", "KmmschadC8KetoacylCoAMAT", ",", 
         "KmmschadC6KetoacylCoAMAT", ",", "KmmschadC4AcetoacylCoAMAT", ",", 
         "KmmschadNADHMAT", ",", "Keqmschad", ",", 
         RowBox[{"C14HydroxyacylCoAMAT", "[", "t", "]"}], ",", 
         RowBox[{"C16HydroxyacylCoAMAT", "[", "t", "]"}], ",", 
         RowBox[{"C12HydroxyacylCoAMAT", "[", "t", "]"}], ",", 
         RowBox[{"C10HydroxyacylCoAMAT", "[", "t", "]"}], ",", 
         RowBox[{"C8HydroxyacylCoAMAT", "[", "t", "]"}], ",", 
         RowBox[{"C6HydroxyacylCoAMAT", "[", "t", "]"}], ",", 
         RowBox[{"C4HydroxyacylCoAMAT", "[", "t", "]"}], ",", "NADtMAT", ",", 
         RowBox[{"C14KetoacylCoAMAT", "[", "t", "]"}], ",", 
         RowBox[{"C16KetoacylCoAMAT", "[", "t", "]"}], ",", 
         RowBox[{"C12KetoacylCoAMAT", "[", "t", "]"}], ",", 
         RowBox[{"C10KetoacylCoAMAT", "[", "t", "]"}], ",", 
         RowBox[{"C8KetoacylCoAMAT", "[", "t", "]"}], ",", 
         RowBox[{"C6KetoacylCoAMAT", "[", "t", "]"}], ",", 
         RowBox[{"C4AcetoacylCoAMAT", "[", "t", "]"}], ",", 
         RowBox[{"NADHMAT", "[", "t", "]"}]}], "]"}]}], ",", 
      "\[IndentingNewLine]", 
      RowBox[{"vmschadC12", "\[Rule]", 
       RowBox[{"MSCHAD", "[", 
        RowBox[{
        "sfmschadC12", ",", "Vmschad", ",", "KmmschadC12HydroxyacylCoAMAT", 
         ",", "KmmschadC16HydroxyacylCoAMAT", ",", 
         "KmmschadC14HydroxyacylCoAMAT", ",", "KmmschadC10HydroxyacylCoAMAT", 
         ",", "KmmschadC8HydroxyacylCoAMAT", ",", 
         "KmmschadC6HydroxyacylCoAMAT", ",", "KmmschadC4HydroxyacylCoAMAT", 
         ",", "KmmschadNADMAT", ",", "KmmschadC12KetoacylCoAMAT", ",", 
         "KmmschadC16KetoacylCoAMAT", ",", "KmmschadC14KetoacylCoAMAT", ",", 
         "KmmschadC10KetoacylCoAMAT", ",", "KmmschadC8KetoacylCoAMAT", ",", 
         "KmmschadC6KetoacylCoAMAT", ",", "KmmschadC4AcetoacylCoAMAT", ",", 
         "KmmschadNADHMAT", ",", "Keqmschad", ",", 
         RowBox[{"C12HydroxyacylCoAMAT", "[", "t", "]"}], ",", 
         RowBox[{"C16HydroxyacylCoAMAT", "[", "t", "]"}], ",", 
         RowBox[{"C14HydroxyacylCoAMAT", "[", "t", "]"}], ",", 
         RowBox[{"C10HydroxyacylCoAMAT", "[", "t", "]"}], ",", 
         RowBox[{"C8HydroxyacylCoAMAT", "[", "t", "]"}], ",", 
         RowBox[{"C6HydroxyacylCoAMAT", "[", "t", "]"}], ",", 
         RowBox[{"C4HydroxyacylCoAMAT", "[", "t", "]"}], ",", "NADtMAT", ",", 
         RowBox[{"C12KetoacylCoAMAT", "[", "t", "]"}], ",", 
         RowBox[{"C16KetoacylCoAMAT", "[", "t", "]"}], ",", 
         RowBox[{"C14KetoacylCoAMAT", "[", "t", "]"}], ",", 
         RowBox[{"C10KetoacylCoAMAT", "[", "t", "]"}], ",", 
         RowBox[{"C8KetoacylCoAMAT", "[", "t", "]"}], ",", 
         RowBox[{"C6KetoacylCoAMAT", "[", "t", "]"}], ",", 
         RowBox[{"C4AcetoacylCoAMAT", "[", "t", "]"}], ",", 
         RowBox[{"NADHMAT", "[", "t", "]"}]}], "]"}]}], ",", 
      "\[IndentingNewLine]", 
      RowBox[{"vmschadC10", "\[Rule]", 
       RowBox[{"MSCHAD", "[", 
        RowBox[{
        "sfmschadC10", ",", "Vmschad", ",", "KmmschadC10HydroxyacylCoAMAT", 
         ",", "KmmschadC16HydroxyacylCoAMAT", ",", 
         "KmmschadC14HydroxyacylCoAMAT", ",", "KmmschadC12HydroxyacylCoAMAT", 
         ",", "KmmschadC8HydroxyacylCoAMAT", ",", 
         "KmmschadC6HydroxyacylCoAMAT", ",", "KmmschadC4HydroxyacylCoAMAT", 
         ",", "KmmschadNADMAT", ",", "KmmschadC10KetoacylCoAMAT", ",", 
         "KmmschadC16KetoacylCoAMAT", ",", "KmmschadC14KetoacylCoAMAT", ",", 
         "KmmschadC12KetoacylCoAMAT", ",", "KmmschadC8KetoacylCoAMAT", ",", 
         "KmmschadC6KetoacylCoAMAT", ",", "KmmschadC4AcetoacylCoAMAT", ",", 
         "KmmschadNADHMAT", ",", "Keqmschad", ",", 
         RowBox[{"C10HydroxyacylCoAMAT", "[", "t", "]"}], ",", 
         RowBox[{"C16HydroxyacylCoAMAT", "[", "t", "]"}], ",", 
         RowBox[{"C14HydroxyacylCoAMAT", "[", "t", "]"}], ",", 
         RowBox[{"C12HydroxyacylCoAMAT", "[", "t", "]"}], ",", 
         RowBox[{"C8HydroxyacylCoAMAT", "[", "t", "]"}], ",", 
         RowBox[{"C6HydroxyacylCoAMAT", "[", "t", "]"}], ",", 
         RowBox[{"C4HydroxyacylCoAMAT", "[", "t", "]"}], ",", "NADtMAT", ",", 
         RowBox[{"C10KetoacylCoAMAT", "[", "t", "]"}], ",", 
         RowBox[{"C16KetoacylCoAMAT", "[", "t", "]"}], ",", 
         RowBox[{"C14KetoacylCoAMAT", "[", "t", "]"}], ",", 
         RowBox[{"C12KetoacylCoAMAT", "[", "t", "]"}], ",", 
         RowBox[{"C8KetoacylCoAMAT", "[", "t", "]"}], ",", 
         RowBox[{"C6KetoacylCoAMAT", "[", "t", "]"}], ",", 
         RowBox[{"C4AcetoacylCoAMAT", "[", "t", "]"}], ",", 
         RowBox[{"NADHMAT", "[", "t", "]"}]}], "]"}]}], ",", 
      "\[IndentingNewLine]", 
      RowBox[{"vmschadC8", "\[Rule]", 
       RowBox[{"MSCHAD", "[", 
        RowBox[{
        "sfmschadC8", ",", "Vmschad", ",", "KmmschadC8HydroxyacylCoAMAT", ",",
          "KmmschadC16HydroxyacylCoAMAT", ",", "KmmschadC14HydroxyacylCoAMAT",
          ",", "KmmschadC12HydroxyacylCoAMAT", ",", 
         "KmmschadC10HydroxyacylCoAMAT", ",", "KmmschadC6HydroxyacylCoAMAT", 
         ",", "KmmschadC4HydroxyacylCoAMAT", ",", "KmmschadNADMAT", ",", 
         "KmmschadC8KetoacylCoAMAT", ",", "KmmschadC16KetoacylCoAMAT", ",", 
         "KmmschadC14KetoacylCoAMAT", ",", "KmmschadC12KetoacylCoAMAT", ",", 
         "KmmschadC10KetoacylCoAMAT", ",", "KmmschadC6KetoacylCoAMAT", ",", 
         "KmmschadC4AcetoacylCoAMAT", ",", "KmmschadNADHMAT", ",", 
         "Keqmschad", ",", 
         RowBox[{"C8HydroxyacylCoAMAT", "[", "t", "]"}], ",", 
         RowBox[{"C16HydroxyacylCoAMAT", "[", "t", "]"}], ",", 
         RowBox[{"C14HydroxyacylCoAMAT", "[", "t", "]"}], ",", 
         RowBox[{"C12HydroxyacylCoAMAT", "[", "t", "]"}], ",", 
         RowBox[{"C10HydroxyacylCoAMAT", "[", "t", "]"}], ",", 
         RowBox[{"C6HydroxyacylCoAMAT", "[", "t", "]"}], ",", 
         RowBox[{"C4HydroxyacylCoAMAT", "[", "t", "]"}], ",", "NADtMAT", ",", 
         RowBox[{"C8KetoacylCoAMAT", "[", "t", "]"}], ",", 
         RowBox[{"C16KetoacylCoAMAT", "[", "t", "]"}], ",", 
         RowBox[{"C14KetoacylCoAMAT", "[", "t", "]"}], ",", 
         RowBox[{"C12KetoacylCoAMAT", "[", "t", "]"}], ",", 
         RowBox[{"C10KetoacylCoAMAT", "[", "t", "]"}], ",", 
         RowBox[{"C6KetoacylCoAMAT", "[", "t", "]"}], ",", 
         RowBox[{"C4AcetoacylCoAMAT", "[", "t", "]"}], ",", 
         RowBox[{"NADHMAT", "[", "t", "]"}]}], "]"}]}], ",", 
      "\[IndentingNewLine]", 
      RowBox[{"vmschadC6", "\[Rule]", 
       RowBox[{"MSCHAD", "[", 
        RowBox[{
        "sfmschadC6", ",", "Vmschad", ",", "KmmschadC6HydroxyacylCoAMAT", ",",
          "KmmschadC16HydroxyacylCoAMAT", ",", "KmmschadC14HydroxyacylCoAMAT",
          ",", "KmmschadC12HydroxyacylCoAMAT", ",", 
         "KmmschadC10HydroxyacylCoAMAT", ",", "KmmschadC8HydroxyacylCoAMAT", 
         ",", "KmmschadC4HydroxyacylCoAMAT", ",", "KmmschadNADMAT", ",", 
         "KmmschadC6KetoacylCoAMAT", ",", "KmmschadC16KetoacylCoAMAT", ",", 
         "KmmschadC14KetoacylCoAMAT", ",", "KmmschadC12KetoacylCoAMAT", ",", 
         "KmmschadC10KetoacylCoAMAT", ",", "KmmschadC8KetoacylCoAMAT", ",", 
         "KmmschadC4AcetoacylCoAMAT", ",", "KmmschadNADHMAT", ",", 
         "Keqmschad", ",", 
         RowBox[{"C6HydroxyacylCoAMAT", "[", "t", "]"}], ",", 
         RowBox[{"C16HydroxyacylCoAMAT", "[", "t", "]"}], ",", 
         RowBox[{"C14HydroxyacylCoAMAT", "[", "t", "]"}], ",", 
         RowBox[{"C12HydroxyacylCoAMAT", "[", "t", "]"}], ",", 
         RowBox[{"C10HydroxyacylCoAMAT", "[", "t", "]"}], ",", 
         RowBox[{"C8HydroxyacylCoAMAT", "[", "t", "]"}], ",", 
         RowBox[{"C4HydroxyacylCoAMAT", "[", "t", "]"}], ",", "NADtMAT", ",", 
         RowBox[{"C6KetoacylCoAMAT", "[", "t", "]"}], ",", 
         RowBox[{"C16KetoacylCoAMAT", "[", "t", "]"}], ",", 
         RowBox[{"C14KetoacylCoAMAT", "[", "t", "]"}], ",", 
         RowBox[{"C12KetoacylCoAMAT", "[", "t", "]"}], ",", 
         RowBox[{"C10KetoacylCoAMAT", "[", "t", "]"}], ",", 
         RowBox[{"C8KetoacylCoAMAT", "[", "t", "]"}], ",", 
         RowBox[{"C4AcetoacylCoAMAT", "[", "t", "]"}], ",", 
         RowBox[{"NADHMAT", "[", "t", "]"}]}], "]"}]}], ",", 
      "\[IndentingNewLine]", 
      RowBox[{"vmschadC4", "\[Rule]", 
       RowBox[{"MSCHAD", "[", 
        RowBox[{
        "sfmschadC4", ",", "Vmschad", ",", "KmmschadC4HydroxyacylCoAMAT", ",",
          "KmmschadC16HydroxyacylCoAMAT", ",", "KmmschadC14HydroxyacylCoAMAT",
          ",", "KmmschadC12HydroxyacylCoAMAT", ",", 
         "KmmschadC10HydroxyacylCoAMAT", ",", "KmmschadC8HydroxyacylCoAMAT", 
         ",", "KmmschadC6HydroxyacylCoAMAT", ",", "KmmschadNADMAT", ",", 
         "KmmschadC4AcetoacylCoAMAT", ",", "KmmschadC16KetoacylCoAMAT", ",", 
         "KmmschadC14KetoacylCoAMAT", ",", "KmmschadC12KetoacylCoAMAT", ",", 
         "KmmschadC10KetoacylCoAMAT", ",", "KmmschadC8KetoacylCoAMAT", ",", 
         "KmmschadC6KetoacylCoAMAT", ",", "KmmschadNADHMAT", ",", "Keqmschad",
          ",", 
         RowBox[{"C4HydroxyacylCoAMAT", "[", "t", "]"}], ",", 
         RowBox[{"C16HydroxyacylCoAMAT", "[", "t", "]"}], ",", 
         RowBox[{"C14HydroxyacylCoAMAT", "[", "t", "]"}], ",", 
         RowBox[{"C12HydroxyacylCoAMAT", "[", "t", "]"}], ",", 
         RowBox[{"C10HydroxyacylCoAMAT", "[", "t", "]"}], ",", 
         RowBox[{"C8HydroxyacylCoAMAT", "[", "t", "]"}], ",", 
         RowBox[{"C6HydroxyacylCoAMAT", "[", "t", "]"}], ",", "NADtMAT", ",", 
         RowBox[{"C4AcetoacylCoAMAT", "[", "t", "]"}], ",", 
         RowBox[{"C16KetoacylCoAMAT", "[", "t", "]"}], ",", 
         RowBox[{"C14KetoacylCoAMAT", "[", "t", "]"}], ",", 
         RowBox[{"C12KetoacylCoAMAT", "[", "t", "]"}], ",", 
         RowBox[{"C10KetoacylCoAMAT", "[", "t", "]"}], ",", 
         RowBox[{"C8KetoacylCoAMAT", "[", "t", "]"}], ",", 
         RowBox[{"C6KetoacylCoAMAT", "[", "t", "]"}], ",", 
         RowBox[{"NADHMAT", "[", "t", "]"}]}], "]"}]}], ",", 
      "\[IndentingNewLine]", 
      RowBox[{"vmckatC16", "\[Rule]", 
       RowBox[{"MCKATA", "[", 
        RowBox[{
        "sfmckatC16", ",", "Vmckat", ",", "KmmckatC16KetoacylCoAMAT", ",", 
         "KmmckatC14KetoacylCoAMAT", ",", "KmmckatC12KetoacylCoAMAT", ",", 
         "KmmckatC10KetoacylCoAMAT", ",", "KmmckatC8KetoacylCoAMAT", ",", 
         "KmmckatC6KetoacylCoAMAT", ",", "KmmckatC4AcetoacylCoAMAT", ",", 
         "KmmckatCoAMAT", ",", "KmmckatC14AcylCoAMAT", ",", 
         "KmmckatC16AcylCoAMAT", ",", "KmmckatC12AcylCoAMAT", ",", 
         "KmmckatC10AcylCoAMAT", ",", "KmmckatC8AcylCoAMAT", ",", 
         "KmmckatC6AcylCoAMAT", ",", "KmmckatC4AcylCoAMAT", ",", 
         "KmmckatAcetylCoAMAT", ",", "Keqmckat", ",", 
         RowBox[{"C16KetoacylCoAMAT", "[", "t", "]"}], ",", 
         RowBox[{"C14KetoacylCoAMAT", "[", "t", "]"}], ",", 
         RowBox[{"C12KetoacylCoAMAT", "[", "t", "]"}], ",", 
         RowBox[{"C10KetoacylCoAMAT", "[", "t", "]"}], ",", 
         RowBox[{"C8KetoacylCoAMAT", "[", "t", "]"}], ",", 
         RowBox[{"C6KetoacylCoAMAT", "[", "t", "]"}], ",", 
         RowBox[{"C4AcetoacylCoAMAT", "[", "t", "]"}], ",", "CoAMAT", ",", 
         RowBox[{"C14AcylCoAMAT", "[", "t", "]"}], ",", 
         RowBox[{"C16AcylCoAMAT", "[", "t", "]"}], ",", 
         RowBox[{"C12AcylCoAMAT", "[", "t", "]"}], ",", 
         RowBox[{"C10AcylCoAMAT", "[", "t", "]"}], ",", 
         RowBox[{"C8AcylCoAMAT", "[", "t", "]"}], ",", 
         RowBox[{"C6AcylCoAMAT", "[", "t", "]"}], ",", 
         RowBox[{"C4AcylCoAMAT", "[", "t", "]"}], ",", 
         RowBox[{"AcetylCoAMAT", "[", "t", "]"}], ",", "CE1", ",", "KmCE1", 
         ",", "nE1", ",", "vmct1acet", ",", "kmct1acet", ",", "AcetateMAT", 
         ",", "propacetmckat"}], "]"}]}], ",", "\[IndentingNewLine]", 
      RowBox[{"vmckatC14", "\[Rule]", 
       RowBox[{"MCKATA", "[", 
        RowBox[{
        "sfmckatC14", ",", "Vmckat", ",", "KmmckatC14KetoacylCoAMAT", ",", 
         "KmmckatC16KetoacylCoAMAT", ",", "KmmckatC12KetoacylCoAMAT", ",", 
         "KmmckatC10KetoacylCoAMAT", ",", "KmmckatC8KetoacylCoAMAT", ",", 
         "KmmckatC6KetoacylCoAMAT", ",", "KmmckatC4AcetoacylCoAMAT", ",", 
         "KmmckatCoAMAT", ",", "KmmckatC12AcylCoAMAT", ",", 
         "KmmckatC16AcylCoAMAT", ",", "KmmckatC14AcylCoAMAT", ",", 
         "KmmckatC10AcylCoAMAT", ",", "KmmckatC8AcylCoAMAT", ",", 
         "KmmckatC6AcylCoAMAT", ",", "KmmckatC4AcylCoAMAT", ",", 
         "KmmckatAcetylCoAMAT", ",", "Keqmckat", ",", 
         RowBox[{"C14KetoacylCoAMAT", "[", "t", "]"}], ",", 
         RowBox[{"C16KetoacylCoAMAT", "[", "t", "]"}], ",", 
         RowBox[{"C12KetoacylCoAMAT", "[", "t", "]"}], ",", 
         RowBox[{"C10KetoacylCoAMAT", "[", "t", "]"}], ",", 
         RowBox[{"C8KetoacylCoAMAT", "[", "t", "]"}], ",", 
         RowBox[{"C6KetoacylCoAMAT", "[", "t", "]"}], ",", 
         RowBox[{"C4AcetoacylCoAMAT", "[", "t", "]"}], ",", "CoAMAT", ",", 
         RowBox[{"C12AcylCoAMAT", "[", "t", "]"}], ",", 
         RowBox[{"C16AcylCoAMAT", "[", "t", "]"}], ",", 
         RowBox[{"C14AcylCoAMAT", "[", "t", "]"}], ",", 
         RowBox[{"C10AcylCoAMAT", "[", "t", "]"}], ",", 
         RowBox[{"C8AcylCoAMAT", "[", "t", "]"}], ",", 
         RowBox[{"C6AcylCoAMAT", "[", "t", "]"}], ",", 
         RowBox[{"C4AcylCoAMAT", "[", "t", "]"}], ",", 
         RowBox[{"AcetylCoAMAT", "[", "t", "]"}], ",", "CE1", ",", "KmCE1", 
         ",", "nE1", ",", "vmct1acet", ",", "kmct1acet", ",", "AcetateMAT", 
         ",", "propacetmckat"}], "]"}]}], ",", "\[IndentingNewLine]", 
      RowBox[{"vmckatC12", "\[Rule]", 
       RowBox[{"MCKATA", "[", 
        RowBox[{
        "sfmckatC12", ",", "Vmckat", ",", "KmmckatC12KetoacylCoAMAT", ",", 
         "KmmckatC16KetoacylCoAMAT", ",", "KmmckatC14KetoacylCoAMAT", ",", 
         "KmmckatC10KetoacylCoAMAT", ",", "KmmckatC8KetoacylCoAMAT", ",", 
         "KmmckatC6KetoacylCoAMAT", ",", "KmmckatC4AcetoacylCoAMAT", ",", 
         "KmmckatCoAMAT", ",", "KmmckatC10AcylCoAMAT", ",", 
         "KmmckatC16AcylCoAMAT", ",", "KmmckatC14AcylCoAMAT", ",", 
         "KmmckatC12AcylCoAMAT", ",", "KmmckatC8AcylCoAMAT", ",", 
         "KmmckatC6AcylCoAMAT", ",", "KmmckatC4AcylCoAMAT", ",", 
         "KmmckatAcetylCoAMAT", ",", "Keqmckat", ",", 
         RowBox[{"C12KetoacylCoAMAT", "[", "t", "]"}], ",", 
         RowBox[{"C16KetoacylCoAMAT", "[", "t", "]"}], ",", 
         RowBox[{"C14KetoacylCoAMAT", "[", "t", "]"}], ",", 
         RowBox[{"C10KetoacylCoAMAT", "[", "t", "]"}], ",", 
         RowBox[{"C8KetoacylCoAMAT", "[", "t", "]"}], ",", 
         RowBox[{"C6KetoacylCoAMAT", "[", "t", "]"}], ",", 
         RowBox[{"C4AcetoacylCoAMAT", "[", "t", "]"}], ",", "CoAMAT", ",", 
         RowBox[{"C10AcylCoAMAT", "[", "t", "]"}], ",", 
         RowBox[{"C16AcylCoAMAT", "[", "t", "]"}], ",", 
         RowBox[{"C14AcylCoAMAT", "[", "t", "]"}], ",", 
         RowBox[{"C12AcylCoAMAT", "[", "t", "]"}], ",", 
         RowBox[{"C8AcylCoAMAT", "[", "t", "]"}], ",", 
         RowBox[{"C6AcylCoAMAT", "[", "t", "]"}], ",", 
         RowBox[{"C4AcylCoAMAT", "[", "t", "]"}], ",", 
         RowBox[{"AcetylCoAMAT", "[", "t", "]"}], ",", "CE1", ",", "KmCE1", 
         ",", "nE1", ",", "vmct1acet", ",", "kmct1acet", ",", "AcetateMAT", 
         ",", "propacetmckat"}], "]"}]}], ",", "\[IndentingNewLine]", 
      RowBox[{"vmckatC10", "\[Rule]", 
       RowBox[{"MCKATA", "[", 
        RowBox[{
        "sfmckatC10", ",", "Vmckat", ",", "KmmckatC10KetoacylCoAMAT", ",", 
         "KmmckatC16KetoacylCoAMAT", ",", "KmmckatC14KetoacylCoAMAT", ",", 
         "KmmckatC12KetoacylCoAMAT", ",", "KmmckatC8KetoacylCoAMAT", ",", 
         "KmmckatC6KetoacylCoAMAT", ",", "KmmckatC4AcetoacylCoAMAT", ",", 
         "KmmckatCoAMAT", ",", "KmmckatC8AcylCoAMAT", ",", 
         "KmmckatC16AcylCoAMAT", ",", "KmmckatC14AcylCoAMAT", ",", 
         "KmmckatC12AcylCoAMAT", ",", "KmmckatC10AcylCoAMAT", ",", 
         "KmmckatC6AcylCoAMAT", ",", "KmmckatC4AcylCoAMAT", ",", 
         "KmmckatAcetylCoAMAT", ",", "Keqmckat", ",", 
         RowBox[{"C10KetoacylCoAMAT", "[", "t", "]"}], ",", 
         RowBox[{"C16KetoacylCoAMAT", "[", "t", "]"}], ",", 
         RowBox[{"C14KetoacylCoAMAT", "[", "t", "]"}], ",", 
         RowBox[{"C12KetoacylCoAMAT", "[", "t", "]"}], ",", 
         RowBox[{"C8KetoacylCoAMAT", "[", "t", "]"}], ",", 
         RowBox[{"C6KetoacylCoAMAT", "[", "t", "]"}], ",", 
         RowBox[{"C4AcetoacylCoAMAT", "[", "t", "]"}], ",", "CoAMAT", ",", 
         RowBox[{"C8AcylCoAMAT", "[", "t", "]"}], ",", 
         RowBox[{"C16AcylCoAMAT", "[", "t", "]"}], ",", 
         RowBox[{"C14AcylCoAMAT", "[", "t", "]"}], ",", 
         RowBox[{"C12AcylCoAMAT", "[", "t", "]"}], ",", 
         RowBox[{"C10AcylCoAMAT", "[", "t", "]"}], ",", 
         RowBox[{"C6AcylCoAMAT", "[", "t", "]"}], ",", 
         RowBox[{"C4AcylCoAMAT", "[", "t", "]"}], ",", 
         RowBox[{"AcetylCoAMAT", "[", "t", "]"}], ",", "CE1", ",", "KmCE1", 
         ",", "nE1", ",", "vmct1acet", ",", "kmct1acet", ",", "AcetateMAT", 
         ",", "propacetmckat"}], "]"}]}], ",", "\[IndentingNewLine]", 
      RowBox[{"vmckatC8", "\[Rule]", 
       RowBox[{"MCKATA", "[", 
        RowBox[{
        "sfmckatC8", ",", "Vmckat", ",", "KmmckatC8KetoacylCoAMAT", ",", 
         "KmmckatC16KetoacylCoAMAT", ",", "KmmckatC14KetoacylCoAMAT", ",", 
         "KmmckatC12KetoacylCoAMAT", ",", "KmmckatC10KetoacylCoAMAT", ",", 
         "KmmckatC6KetoacylCoAMAT", ",", "KmmckatC4AcetoacylCoAMAT", ",", 
         "KmmckatCoAMAT", ",", "KmmckatC6AcylCoAMAT", ",", 
         "KmmckatC16AcylCoAMAT", ",", "KmmckatC14AcylCoAMAT", ",", 
         "KmmckatC12AcylCoAMAT", ",", "KmmckatC10AcylCoAMAT", ",", 
         "KmmckatC8AcylCoAMAT", ",", "KmmckatC4AcylCoAMAT", ",", 
         "KmmckatAcetylCoAMAT", ",", "Keqmckat", ",", 
         RowBox[{"C8KetoacylCoAMAT", "[", "t", "]"}], ",", 
         RowBox[{"C16KetoacylCoAMAT", "[", "t", "]"}], ",", 
         RowBox[{"C14KetoacylCoAMAT", "[", "t", "]"}], ",", 
         RowBox[{"C12KetoacylCoAMAT", "[", "t", "]"}], ",", 
         RowBox[{"C10KetoacylCoAMAT", "[", "t", "]"}], ",", 
         RowBox[{"C6KetoacylCoAMAT", "[", "t", "]"}], ",", 
         RowBox[{"C4AcetoacylCoAMAT", "[", "t", "]"}], ",", "CoAMAT", ",", 
         RowBox[{"C6AcylCoAMAT", "[", "t", "]"}], ",", 
         RowBox[{"C16AcylCoAMAT", "[", "t", "]"}], ",", 
         RowBox[{"C14AcylCoAMAT", "[", "t", "]"}], ",", 
         RowBox[{"C12AcylCoAMAT", "[", "t", "]"}], ",", 
         RowBox[{"C10AcylCoAMAT", "[", "t", "]"}], ",", 
         RowBox[{"C8AcylCoAMAT", "[", "t", "]"}], ",", 
         RowBox[{"C4AcylCoAMAT", "[", "t", "]"}], ",", 
         RowBox[{"AcetylCoAMAT", "[", "t", "]"}], ",", "CE1", ",", "KmCE1", 
         ",", "nE1", ",", "vmct1acet", ",", "kmct1acet", ",", "AcetateMAT", 
         ",", "propacetmckat"}], "]"}]}], ",", "\[IndentingNewLine]", 
      RowBox[{"vmckatC6", "\[Rule]", 
       RowBox[{"MCKATA", "[", 
        RowBox[{
        "sfmckatC6", ",", "Vmckat", ",", "KmmckatC6KetoacylCoAMAT", ",", 
         "KmmckatC16KetoacylCoAMAT", ",", "KmmckatC14KetoacylCoAMAT", ",", 
         "KmmckatC12KetoacylCoAMAT", ",", "KmmckatC10KetoacylCoAMAT", ",", 
         "KmmckatC8KetoacylCoAMAT", ",", "KmmckatC4AcetoacylCoAMAT", ",", 
         "KmmckatCoAMAT", ",", "KmmckatC4AcylCoAMAT", ",", 
         "KmmckatC16AcylCoAMAT", ",", "KmmckatC14AcylCoAMAT", ",", 
         "KmmckatC12AcylCoAMAT", ",", "KmmckatC10AcylCoAMAT", ",", 
         "KmmckatC8AcylCoAMAT", ",", "KmmckatC6AcylCoAMAT", ",", 
         "KmmckatAcetylCoAMAT", ",", "Keqmckat", ",", 
         RowBox[{"C6KetoacylCoAMAT", "[", "t", "]"}], ",", 
         RowBox[{"C16KetoacylCoAMAT", "[", "t", "]"}], ",", 
         RowBox[{"C14KetoacylCoAMAT", "[", "t", "]"}], ",", 
         RowBox[{"C12KetoacylCoAMAT", "[", "t", "]"}], ",", 
         RowBox[{"C10KetoacylCoAMAT", "[", "t", "]"}], ",", 
         RowBox[{"C8KetoacylCoAMAT", "[", "t", "]"}], ",", 
         RowBox[{"C4AcetoacylCoAMAT", "[", "t", "]"}], ",", "CoAMAT", ",", 
         RowBox[{"C4AcylCoAMAT", "[", "t", "]"}], ",", 
         RowBox[{"C16AcylCoAMAT", "[", "t", "]"}], ",", 
         RowBox[{"C14AcylCoAMAT", "[", "t", "]"}], ",", 
         RowBox[{"C12AcylCoAMAT", "[", "t", "]"}], ",", 
         RowBox[{"C10AcylCoAMAT", "[", "t", "]"}], ",", 
         RowBox[{"C8AcylCoAMAT", "[", "t", "]"}], ",", 
         RowBox[{"C6AcylCoAMAT", "[", "t", "]"}], ",", 
         RowBox[{"AcetylCoAMAT", "[", "t", "]"}], ",", "CE1", ",", "KmCE1", 
         ",", "nE1", ",", "vmct1acet", ",", "kmct1acet", ",", "AcetateMAT", 
         ",", "propacetmckat"}], "]"}]}], ",", "\[IndentingNewLine]", 
      RowBox[{"vmckatC4", "\[Rule]", 
       RowBox[{"MCKATB", "[", 
        RowBox[{
        "sfmckatC4", ",", "Vmckat", ",", "KmmckatC4AcetoacylCoAMAT", ",", 
         "KmmckatC16KetoacylCoAMAT", ",", "KmmckatC14KetoacylCoAMAT", ",", 
         "KmmckatC12KetoacylCoAMAT", ",", "KmmckatC10KetoacylCoAMAT", ",", 
         "KmmckatC8KetoacylCoAMAT", ",", "KmmckatC6KetoacylCoAMAT", ",", 
         "KmmckatCoAMAT", ",", "KmmckatC4AcylCoAMAT", ",", 
         "KmmckatC16AcylCoAMAT", ",", "KmmckatC14AcylCoAMAT", ",", 
         "KmmckatC12AcylCoAMAT", ",", "KmmckatC10AcylCoAMAT", ",", 
         "KmmckatC8AcylCoAMAT", ",", "KmmckatC6AcylCoAMAT", ",", 
         "KmmckatAcetylCoAMAT", ",", "Keqmckat", ",", 
         RowBox[{"C4AcetoacylCoAMAT", "[", "t", "]"}], ",", 
         RowBox[{"C16KetoacylCoAMAT", "[", "t", "]"}], ",", 
         RowBox[{"C14KetoacylCoAMAT", "[", "t", "]"}], ",", 
         RowBox[{"C12KetoacylCoAMAT", "[", "t", "]"}], ",", 
         RowBox[{"C10KetoacylCoAMAT", "[", "t", "]"}], ",", 
         RowBox[{"C8KetoacylCoAMAT", "[", "t", "]"}], ",", 
         RowBox[{"C6KetoacylCoAMAT", "[", "t", "]"}], ",", "CoAMAT", ",", 
         RowBox[{"C4AcylCoAMAT", "[", "t", "]"}], ",", 
         RowBox[{"C16AcylCoAMAT", "[", "t", "]"}], ",", 
         RowBox[{"C14AcylCoAMAT", "[", "t", "]"}], ",", 
         RowBox[{"C12AcylCoAMAT", "[", "t", "]"}], ",", 
         RowBox[{"C10AcylCoAMAT", "[", "t", "]"}], ",", 
         RowBox[{"C8AcylCoAMAT", "[", "t", "]"}], ",", 
         RowBox[{"C6AcylCoAMAT", "[", "t", "]"}], ",", 
         RowBox[{"AcetylCoAMAT", "[", "t", "]"}], ",", "CE1", ",", "KmCE1", 
         ",", "nE1", ",", "vmct1acet", ",", "kmct1acet", ",", "AcetateMAT", 
         ",", "propacetmckat"}], "]"}]}], ",", "\[IndentingNewLine]", 
      RowBox[{"vmtpC16", "\[Rule]", 
       RowBox[{"MTP", "[", 
        RowBox[{
        "sfmtpC16", ",", "Vmtp", ",", "KmmtpC16EnoylCoAMAT", ",", 
         "KmmtpC14EnoylCoAMAT", ",", "KmmtpC12EnoylCoAMAT", ",", 
         "KmmtpC10EnoylCoAMAT", ",", "KmmtpC8EnoylCoAMAT", ",", "KmmtpNADMAT",
          ",", "KmmtpCoAMAT", ",", "KmmtpC14AcylCoAMAT", ",", 
         "KmmtpC16AcylCoAMAT", ",", "KmmtpC12AcylCoAMAT", ",", 
         "KmmtpC10AcylCoAMAT", ",", "KmmtpC8AcylCoAMAT", ",", 
         "KmmtpC6AcylCoAMAT", ",", "KmmtpNADHMAT", ",", "KmmtpAcetylCoAMAT", 
         ",", "KicrotC4AcetoacylCoA", ",", "Keqmtp", ",", 
         RowBox[{"C16EnoylCoAMAT", "[", "t", "]"}], ",", 
         RowBox[{"C14EnoylCoAMAT", "[", "t", "]"}], ",", 
         RowBox[{"C12EnoylCoAMAT", "[", "t", "]"}], ",", 
         RowBox[{"C10EnoylCoAMAT", "[", "t", "]"}], ",", 
         RowBox[{"C8EnoylCoAMAT", "[", "t", "]"}], ",", "NADtMAT", ",", 
         "CoAMAT", ",", 
         RowBox[{"C14AcylCoAMAT", "[", "t", "]"}], ",", 
         RowBox[{"C16AcylCoAMAT", "[", "t", "]"}], ",", 
         RowBox[{"C12AcylCoAMAT", "[", "t", "]"}], ",", 
         RowBox[{"C10AcylCoAMAT", "[", "t", "]"}], ",", 
         RowBox[{"C8AcylCoAMAT", "[", "t", "]"}], ",", 
         RowBox[{"C6AcylCoAMAT", "[", "t", "]"}], ",", 
         RowBox[{"NADHMAT", "[", "t", "]"}], ",", 
         RowBox[{"AcetylCoAMAT", "[", "t", "]"}], ",", 
         RowBox[{"C4AcetoacylCoAMAT", "[", "t", "]"}]}], "]"}]}], ",", 
      "\[IndentingNewLine]", 
      RowBox[{"vmtpC14", "\[Rule]", 
       RowBox[{"MTP", "[", 
        RowBox[{
        "sfmtpC14", ",", "Vmtp", ",", "KmmtpC14EnoylCoAMAT", ",", 
         "KmmtpC16EnoylCoAMAT", ",", "KmmtpC12EnoylCoAMAT", ",", 
         "KmmtpC10EnoylCoAMAT", ",", "KmmtpC8EnoylCoAMAT", ",", "KmmtpNADMAT",
          ",", "KmmtpCoAMAT", ",", "KmmtpC12AcylCoAMAT", ",", 
         "KmmtpC16AcylCoAMAT", ",", "KmmtpC14AcylCoAMAT", ",", 
         "KmmtpC10AcylCoAMAT", ",", "KmmtpC8AcylCoAMAT", ",", 
         "KmmtpC6AcylCoAMAT", ",", "KmmtpNADHMAT", ",", "KmmtpAcetylCoAMAT", 
         ",", "KicrotC4AcetoacylCoA", ",", "Keqmtp", ",", 
         RowBox[{"C14EnoylCoAMAT", "[", "t", "]"}], ",", 
         RowBox[{"C16EnoylCoAMAT", "[", "t", "]"}], ",", 
         RowBox[{"C12EnoylCoAMAT", "[", "t", "]"}], ",", 
         RowBox[{"C10EnoylCoAMAT", "[", "t", "]"}], ",", 
         RowBox[{"C8EnoylCoAMAT", "[", "t", "]"}], ",", "NADtMAT", ",", 
         "CoAMAT", ",", 
         RowBox[{"C12AcylCoAMAT", "[", "t", "]"}], ",", 
         RowBox[{"C16AcylCoAMAT", "[", "t", "]"}], ",", 
         RowBox[{"C14AcylCoAMAT", "[", "t", "]"}], ",", 
         RowBox[{"C10AcylCoAMAT", "[", "t", "]"}], ",", 
         RowBox[{"C8AcylCoAMAT", "[", "t", "]"}], ",", 
         RowBox[{"C6AcylCoAMAT", "[", "t", "]"}], ",", 
         RowBox[{"NADHMAT", "[", "t", "]"}], ",", 
         RowBox[{"AcetylCoAMAT", "[", "t", "]"}], ",", 
         RowBox[{"C4AcetoacylCoAMAT", "[", "t", "]"}]}], "]"}]}], ",", 
      "\[IndentingNewLine]", 
      RowBox[{"vmtpC12", "\[Rule]", 
       RowBox[{"MTP", "[", 
        RowBox[{
        "sfmtpC12", ",", "Vmtp", ",", "KmmtpC12EnoylCoAMAT", ",", 
         "KmmtpC16EnoylCoAMAT", ",", "KmmtpC14EnoylCoAMAT", ",", 
         "KmmtpC10EnoylCoAMAT", ",", "KmmtpC8EnoylCoAMAT", ",", "KmmtpNADMAT",
          ",", "KmmtpCoAMAT", ",", "KmmtpC10AcylCoAMAT", ",", 
         "KmmtpC16AcylCoAMAT", ",", "KmmtpC14AcylCoAMAT", ",", 
         "KmmtpC12AcylCoAMAT", ",", "KmmtpC8AcylCoAMAT", ",", 
         "KmmtpC6AcylCoAMAT", ",", "KmmtpNADHMAT", ",", "KmmtpAcetylCoAMAT", 
         ",", "KicrotC4AcetoacylCoA", ",", "Keqmtp", ",", 
         RowBox[{"C12EnoylCoAMAT", "[", "t", "]"}], ",", 
         RowBox[{"C16EnoylCoAMAT", "[", "t", "]"}], ",", 
         RowBox[{"C14EnoylCoAMAT", "[", "t", "]"}], ",", 
         RowBox[{"C10EnoylCoAMAT", "[", "t", "]"}], ",", 
         RowBox[{"C8EnoylCoAMAT", "[", "t", "]"}], ",", "NADtMAT", ",", 
         "CoAMAT", ",", 
         RowBox[{"C10AcylCoAMAT", "[", "t", "]"}], ",", 
         RowBox[{"C16AcylCoAMAT", "[", "t", "]"}], ",", 
         RowBox[{"C14AcylCoAMAT", "[", "t", "]"}], ",", 
         RowBox[{"C12AcylCoAMAT", "[", "t", "]"}], ",", 
         RowBox[{"C8AcylCoAMAT", "[", "t", "]"}], ",", 
         RowBox[{"C6AcylCoAMAT", "[", "t", "]"}], ",", 
         RowBox[{"NADHMAT", "[", "t", "]"}], ",", 
         RowBox[{"AcetylCoAMAT", "[", "t", "]"}], ",", 
         RowBox[{"C4AcetoacylCoAMAT", "[", "t", "]"}]}], "]"}]}], ",", 
      "\[IndentingNewLine]", 
      RowBox[{"vmtpC10", "\[Rule]", 
       RowBox[{"MTP", "[", 
        RowBox[{
        "sfmtpC10", ",", "Vmtp", ",", "KmmtpC10EnoylCoAMAT", ",", 
         "KmmtpC16EnoylCoAMAT", ",", "KmmtpC14EnoylCoAMAT", ",", 
         "KmmtpC12EnoylCoAMAT", ",", "KmmtpC8EnoylCoAMAT", ",", "KmmtpNADMAT",
          ",", "KmmtpCoAMAT", ",", "KmmtpC8AcylCoAMAT", ",", 
         "KmmtpC16AcylCoAMAT", ",", "KmmtpC14AcylCoAMAT", ",", 
         "KmmtpC12AcylCoAMAT", ",", "KmmtpC10AcylCoAMAT", ",", 
         "KmmtpC6AcylCoAMAT", ",", "KmmtpNADHMAT", ",", "KmmtpAcetylCoAMAT", 
         ",", "KicrotC4AcetoacylCoA", ",", "Keqmtp", ",", 
         RowBox[{"C10EnoylCoAMAT", "[", "t", "]"}], ",", 
         RowBox[{"C16EnoylCoAMAT", "[", "t", "]"}], ",", 
         RowBox[{"C14EnoylCoAMAT", "[", "t", "]"}], ",", 
         RowBox[{"C12EnoylCoAMAT", "[", "t", "]"}], ",", 
         RowBox[{"C8EnoylCoAMAT", "[", "t", "]"}], ",", "NADtMAT", ",", 
         "CoAMAT", ",", 
         RowBox[{"C8AcylCoAMAT", "[", "t", "]"}], ",", 
         RowBox[{"C16AcylCoAMAT", "[", "t", "]"}], ",", 
         RowBox[{"C14AcylCoAMAT", "[", "t", "]"}], ",", 
         RowBox[{"C12AcylCoAMAT", "[", "t", "]"}], ",", 
         RowBox[{"C10AcylCoAMAT", "[", "t", "]"}], ",", 
         RowBox[{"C6AcylCoAMAT", "[", "t", "]"}], ",", 
         RowBox[{"NADHMAT", "[", "t", "]"}], ",", 
         RowBox[{"AcetylCoAMAT", "[", "t", "]"}], ",", 
         RowBox[{"C4AcetoacylCoAMAT", "[", "t", "]"}]}], "]"}]}], ",", 
      "\[IndentingNewLine]", 
      RowBox[{"vmtpC8", "\[Rule]", 
       RowBox[{"MTP", "[", 
        RowBox[{
        "sfmtpC8", ",", "Vmtp", ",", "KmmtpC8EnoylCoAMAT", ",", 
         "KmmtpC16EnoylCoAMAT", ",", "KmmtpC14EnoylCoAMAT", ",", 
         "KmmtpC12EnoylCoAMAT", ",", "KmmtpC10EnoylCoAMAT", ",", 
         "KmmtpNADMAT", ",", "KmmtpCoAMAT", ",", "KmmtpC6AcylCoAMAT", ",", 
         "KmmtpC16AcylCoAMAT", ",", "KmmtpC14AcylCoAMAT", ",", 
         "KmmtpC12AcylCoAMAT", ",", "KmmtpC10AcylCoAMAT", ",", 
         "KmmtpC8AcylCoAMAT", ",", "KmmtpNADHMAT", ",", "KmmtpAcetylCoAMAT", 
         ",", "KicrotC4AcetoacylCoA", ",", "Keqmtp", ",", 
         RowBox[{"C8EnoylCoAMAT", "[", "t", "]"}], ",", 
         RowBox[{"C16EnoylCoAMAT", "[", "t", "]"}], ",", 
         RowBox[{"C14EnoylCoAMAT", "[", "t", "]"}], ",", 
         RowBox[{"C12EnoylCoAMAT", "[", "t", "]"}], ",", 
         RowBox[{"C10EnoylCoAMAT", "[", "t", "]"}], ",", "NADtMAT", ",", 
         "CoAMAT", ",", 
         RowBox[{"C6AcylCoAMAT", "[", "t", "]"}], ",", 
         RowBox[{"C16AcylCoAMAT", "[", "t", "]"}], ",", 
         RowBox[{"C14AcylCoAMAT", "[", "t", "]"}], ",", 
         RowBox[{"C12AcylCoAMAT", "[", "t", "]"}], ",", 
         RowBox[{"C10AcylCoAMAT", "[", "t", "]"}], ",", 
         RowBox[{"C8AcylCoAMAT", "[", "t", "]"}], ",", 
         RowBox[{"NADHMAT", "[", "t", "]"}], ",", 
         RowBox[{"AcetylCoAMAT", "[", "t", "]"}], ",", 
         RowBox[{"C4AcetoacylCoAMAT", "[", "t", "]"}]}], "]"}]}], ",", 
      "\[IndentingNewLine]", 
      RowBox[{"vacesink", "\[Rule]", 
       RowBox[{"RES", "[", 
        RowBox[{"Ksacesink", ",", 
         RowBox[{"AcetylCoAMAT", "[", "t", "]"}], ",", "K1acesink"}], "]"}]}],
       ",", " ", "\[IndentingNewLine]", 
      RowBox[{"vfadhsink", "\[Rule]", 
       RowBox[{"RES", "[", 
        RowBox[{"Ksfadhsink", ",", 
         RowBox[{"FADHMAT", "[", "t", "]"}], ",", "K1fadhsink"}], "]"}]}], 
      ",", "\[IndentingNewLine]", 
      RowBox[{"voxphnadh", "\[Rule]", 
       RowBox[{"OXPH", "[", 
        RowBox[{
         StyleBox["VmaxOxPh",
          Background->RGBColor[0.5843137254901961, 1., 0.5843137254901961]], 
         StyleBox[",",
          Background->RGBColor[0.5843137254901961, 1., 0.5843137254901961]], 
         StyleBox["KmnadhOxPh",
          Background->RGBColor[0.5843137254901961, 1., 0.5843137254901961]], 
         StyleBox[",",
          Background->RGBColor[0.5843137254901961, 1., 0.5843137254901961]], 
         StyleBox["KmnadOxPh",
          Background->RGBColor[0.5843137254901961, 1., 0.5843137254901961]], 
         StyleBox[",",
          Background->RGBColor[0.5843137254901961, 1., 0.5843137254901961]], 
         RowBox[{"NADHMAT", "[", "t", "]"}], ",", 
         RowBox[{"NADtMAT", "-", 
          RowBox[{"NADHMAT", "[", "t", "]"}]}], ",", "vmct1acet", ",", 
         "kmct1acet", ",", "AcetateMAT"}], "]"}]}], ",", 
      "\[IndentingNewLine]", 
      RowBox[{"vpdhnad", "\[Rule]", 
       RowBox[{"PDH", "[", 
        RowBox[{
         StyleBox["Vmaxpdh",
          Background->RGBColor[0.5843137254901961, 1., 0.5843137254901961]], 
         StyleBox[",",
          Background->RGBColor[0.5843137254901961, 1., 0.5843137254901961]], 
         StyleBox["KmnadPDH",
          Background->RGBColor[0.5843137254901961, 1., 0.5843137254901961]], 
         StyleBox[",",
          Background->RGBColor[0.5843137254901961, 1., 0.5843137254901961]], 
         StyleBox["KmnadhPDH",
          Background->RGBColor[0.5843137254901961, 1., 0.5843137254901961]], 
         StyleBox[",",
          Background->RGBColor[0.5843137254901961, 1., 0.5843137254901961]], 
         RowBox[{"NADtMAT", "-", 
          RowBox[{"NADHMAT", "[", "t", "]"}]}], ",", 
         RowBox[{"NADHMAT", "[", "t", "]"}]}], "]"}]}]}], 
     "\[IndentingNewLine]", "}"}]}], ";"}], "\[IndentingNewLine]", 
  "\[IndentingNewLine]", "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"CoAMATX", "=", 
    RowBox[{"{", 
     RowBox[{"CoAMAT", "\[Rule]", 
      RowBox[{"CoAMATt", "-", 
       RowBox[{"C16AcylCoAMAT", "[", "t", "]"}], "-", 
       RowBox[{"C16EnoylCoAMAT", "[", "t", "]"}], "-", 
       RowBox[{"C16HydroxyacylCoAMAT", "[", "t", "]"}], "-", 
       RowBox[{"C16KetoacylCoAMAT", "[", "t", "]"}], "-", 
       RowBox[{"C14AcylCoAMAT", "[", "t", "]"}], "-", 
       RowBox[{"C14EnoylCoAMAT", "[", "t", "]"}], "-", 
       RowBox[{"C14HydroxyacylCoAMAT", "[", "t", "]"}], "-", 
       RowBox[{"C14KetoacylCoAMAT", "[", "t", "]"}], "-", 
       RowBox[{"C12AcylCoAMAT", "[", "t", "]"}], "-", 
       RowBox[{"C12EnoylCoAMAT", "[", "t", "]"}], "-", 
       RowBox[{"C12HydroxyacylCoAMAT", "[", "t", "]"}], "-", 
       RowBox[{"C12KetoacylCoAMAT", "[", "t", "]"}], "-", 
       RowBox[{"C10AcylCoAMAT", "[", "t", "]"}], "-", 
       RowBox[{"C10EnoylCoAMAT", "[", "t", "]"}], "-", 
       RowBox[{"C10HydroxyacylCoAMAT", "[", "t", "]"}], "-", 
       RowBox[{"C10KetoacylCoAMAT", "[", "t", "]"}], "-", 
       RowBox[{"C8AcylCoAMAT", "[", "t", "]"}], "-", 
       RowBox[{"C8EnoylCoAMAT", "[", "t", "]"}], "-", 
       RowBox[{"C8HydroxyacylCoAMAT", "[", "t", "]"}], "-", 
       RowBox[{"C8KetoacylCoAMAT", "[", "t", "]"}], "-", 
       RowBox[{"C6AcylCoAMAT", "[", "t", "]"}], "-", 
       RowBox[{"C6EnoylCoAMAT", "[", "t", "]"}], "-", 
       RowBox[{"C6HydroxyacylCoAMAT", "[", "t", "]"}], "-", 
       RowBox[{"C6KetoacylCoAMAT", "[", "t", "]"}], "-", 
       RowBox[{"C4AcylCoAMAT", "[", "t", "]"}], "-", 
       RowBox[{"C4EnoylCoAMAT", "[", "t", "]"}], "-", 
       RowBox[{"C4HydroxyacylCoAMAT", "[", "t", "]"}], "-", 
       RowBox[{"C4AcetoacylCoAMAT", "[", "t", "]"}], "-", 
       RowBox[{"AcetylCoAMAT", "[", "t", "]"}]}]}], "}"}]}], ";", "    ", 
   RowBox[{"(*", 
    RowBox[{
     RowBox[{
      RowBox[{"+", 
       RowBox[{"COATCA", "[", "t", "]"}]}], "}"}], ";"}], "*)"}], 
   "\[IndentingNewLine]", "\[IndentingNewLine]", "\[IndentingNewLine]", 
   RowBox[{"Parm", "=", 
    RowBox[{"{", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"sfcpt1C16", "\[Rule]", "1"}], ",", 
      RowBox[{"Vcpt1", "\[Rule]", "0.012"}], ",", 
      RowBox[{"Kmcpt1C16AcylCoACYT", "\[Rule]", "13.8"}], ",", 
      RowBox[{"Kmcpt1CarCYT", "\[Rule]", "250"}], ",", 
      RowBox[{"Kmcpt1C16AcylCarCYT", "\[Rule]", "136"}], ",", 
      RowBox[{"Kmcpt1CoACYT", "\[Rule]", "40.7"}], ",", 
      RowBox[{"Kicpt1MalCoACYT", "\[Rule]", "9.1"}], ",", 
      RowBox[{"Keqcpt1", "\[Rule]", "0.45"}], ",", " ", 
      RowBox[{"ncpt1", "\[Rule]", "2.4799"}], ",", "\[IndentingNewLine]", 
      RowBox[{"Vfcact", "\[Rule]", "0.42"}], ",", 
      RowBox[{"Vrcact", "\[Rule]", "0.42"}], ",", 
      RowBox[{"KmcactC16AcylCarCYT", "\[Rule]", "15"}], ",", 
      RowBox[{"KmcactC14AcylCarCYT", "\[Rule]", "15"}], ",", 
      RowBox[{"KmcactC12AcylCarCYT", "\[Rule]", "15"}], ",", 
      RowBox[{"KmcactC10AcylCarCYT", "\[Rule]", "15"}], ",", 
      RowBox[{"KmcactC8AcylCarCYT", "\[Rule]", "15"}], ",", 
      RowBox[{"KmcactC6AcylCarCYT", "\[Rule]", "15"}], ",", 
      RowBox[{"KmcactC4AcylCarCYT", "\[Rule]", "15"}], ",", 
      RowBox[{"KmcactCarMAT", "\[Rule]", "130"}], ",", 
      RowBox[{"KmcactC16AcylCarMAT", "\[Rule]", "15"}], ",", 
      RowBox[{"KmcactC14AcylCarMAT", "\[Rule]", "15"}], ",", 
      RowBox[{"KmcactC12AcylCarMAT", "\[Rule]", "15"}], ",", 
      RowBox[{"KmcactC10AcylCarMAT", "\[Rule]", "15"}], ",", 
      RowBox[{"KmcactC8AcylCarMAT", "\[Rule]", "15"}], ",", 
      RowBox[{"KmcactC6AcylCarMAT", "\[Rule]", "15"}], ",", 
      RowBox[{"KmcactC4AcylCarMAT", "\[Rule]", "15"}], ",", 
      RowBox[{"KmcactCarCYT", "\[Rule]", "130"}], ",", 
      RowBox[{"KicactC16AcylCarCYT", "\[Rule]", "56"}], ",", 
      RowBox[{"KicactC14AcylCarCYT", "\[Rule]", "56"}], ",", 
      RowBox[{"KicactC12AcylCarCYT", "\[Rule]", "56"}], ",", 
      RowBox[{"KicactC10AcylCarCYT", "\[Rule]", "56"}], ",", 
      RowBox[{"KicactC8AcylCarCYT", "\[Rule]", "56"}], ",", 
      RowBox[{"KicactC6AcylCarCYT", "\[Rule]", "56"}], ",", 
      RowBox[{"KicactC4AcylCarCYT", "\[Rule]", "56"}], ",", 
      RowBox[{"KicactCarCYT", "\[Rule]", "200"}], ",", 
      RowBox[{"Keqcact", "\[Rule]", "1"}], ",", "\[IndentingNewLine]", 
      RowBox[{"sfcpt2C16", "\[Rule]", "0.85"}], ",", 
      RowBox[{"sfcpt2C14", "\[Rule]", "1"}], ",", 
      RowBox[{"sfcpt2C12", "\[Rule]", "0.95"}], ",", 
      RowBox[{"sfcpt2C10", "\[Rule]", "0.95"}], ",", 
      RowBox[{"sfcpt2C8", "\[Rule]", "0.35"}], ",", 
      RowBox[{"sfcpt2C6", "\[Rule]", "0.15"}], ",", 
      RowBox[{"sfcpt2C4", "\[Rule]", "0.01"}], ",", 
      RowBox[{"Vcpt2", "\[Rule]", "0.391"}], ",", 
      RowBox[{"Kmcpt2C16AcylCarMAT", "\[Rule]", "51"}], ",", 
      RowBox[{"Kmcpt2C14AcylCarMAT", "\[Rule]", "51"}], ",", 
      RowBox[{"Kmcpt2C12AcylCarMAT", "\[Rule]", "51"}], ",", 
      RowBox[{"Kmcpt2C10AcylCarMAT", "\[Rule]", "51"}], ",", 
      RowBox[{"Kmcpt2C8AcylCarMAT", "\[Rule]", "51"}], ",", 
      RowBox[{"Kmcpt2C6AcylCarMAT", "\[Rule]", "51"}], ",", 
      RowBox[{"Kmcpt2C4AcylCarMAT", "\[Rule]", "51"}], ",", 
      RowBox[{"Kmcpt2CoAMAT", "\[Rule]", "30"}], ",", 
      RowBox[{"Kmcpt2C16AcylCoAMAT", "\[Rule]", "38"}], ",", 
      RowBox[{"Kmcpt2C14AcylCoAMAT", "\[Rule]", "38"}], ",", 
      RowBox[{"Kmcpt2C12AcylCoAMAT", "\[Rule]", "38"}], ",", 
      RowBox[{"Kmcpt2C10AcylCoAMAT", "\[Rule]", "38"}], ",", 
      RowBox[{"Kmcpt2C8AcylCoAMAT", "\[Rule]", "38"}], ",", 
      RowBox[{"Kmcpt2C6AcylCoAMAT", "\[Rule]", "1000"}], ",", 
      RowBox[{"Kmcpt2C4AcylCoAMAT", "\[Rule]", "1000000"}], ",", 
      RowBox[{"Kmcpt2CarMAT", "\[Rule]", "350"}], ",", 
      RowBox[{"Keqcpt2", "\[Rule]", "2.22"}], ",", "\[IndentingNewLine]", 
      RowBox[{"sfvlcadC16", "\[Rule]", "1"}], ",", 
      RowBox[{"sfvlcadC14", "\[Rule]", "0.42"}], ",", 
      RowBox[{"sfvlcadC12", "\[Rule]", "0.11"}], ",", 
      RowBox[{"Vvlcad", "\[Rule]", "0.008"}], ",", 
      RowBox[{"KmvlcadC16AcylCoAMAT", "\[Rule]", "6.5"}], ",", 
      RowBox[{"KmvlcadC14AcylCoAMAT", "\[Rule]", "4"}], ",", 
      RowBox[{"KmvlcadC12AcylCoAMAT", "\[Rule]", "2.7"}], ",", 
      RowBox[{"KmvlcadFAD", "\[Rule]", "0.12"}], ",", 
      RowBox[{"KmvlcadC16EnoylCoAMAT", "\[Rule]", "1.08"}], ",", 
      RowBox[{"KmvlcadC14EnoylCoAMAT", "\[Rule]", "1.08"}], ",", 
      RowBox[{"KmvlcadC12EnoylCoAMAT", "\[Rule]", "1.08"}], ",", 
      RowBox[{"KmvlcadFADH", "\[Rule]", "24.2"}], ",", 
      RowBox[{"Keqvlcad", "\[Rule]", "6"}], ",", "\[IndentingNewLine]", 
      RowBox[{"sflcadC16", "\[Rule]", "0.9"}], ",", 
      RowBox[{"sflcadC14", "\[Rule]", "1"}], ",", 
      RowBox[{"sflcadC12", "\[Rule]", "0.9"}], ",", 
      RowBox[{"sflcadC10", "\[Rule]", "0.75"}], ",", 
      RowBox[{"sflcadC8", "\[Rule]", "0.4"}], ",", 
      RowBox[{"Vlcad", "\[Rule]", "0.01"}], ",", 
      RowBox[{"KmlcadC16AcylCoAMAT", "\[Rule]", "2.5"}], ",", 
      RowBox[{"KmlcadC14AcylCoAMAT", "\[Rule]", "7.4"}], ",", 
      RowBox[{"KmlcadC12AcylCoAMAT", "\[Rule]", "9"}], ",", 
      RowBox[{"KmlcadC10AcylCoAMAT", "\[Rule]", "24.3"}], ",", 
      RowBox[{"KmlcadC8AcylCoAMAT", "\[Rule]", "123"}], ",", 
      RowBox[{"KmlcadFAD", "\[Rule]", "0.12"}], ",", 
      RowBox[{"KmlcadC16EnoylCoAMAT", "\[Rule]", "1.08"}], ",", 
      RowBox[{"KmlcadC14EnoylCoAMAT", "\[Rule]", "1.08"}], ",", 
      RowBox[{"KmlcadC12EnoylCoAMAT", "\[Rule]", "1.08"}], ",", 
      RowBox[{"KmlcadC10EnoylCoAMAT", "\[Rule]", "1.08"}], ",", 
      RowBox[{"KmlcadC8EnoylCoAMAT", "\[Rule]", "1.08"}], ",", 
      RowBox[{"KmlcadFADH", "\[Rule]", "24.2"}], ",", 
      RowBox[{"Keqlcad", "\[Rule]", "6"}], ",", "\[IndentingNewLine]", 
      RowBox[{"sfmcadC12", "\[Rule]", "0.38"}], ",", 
      RowBox[{"sfmcadC10", "\[Rule]", "0.8"}], ",", 
      RowBox[{"sfmcadC8", "\[Rule]", "0.87"}], ",", 
      RowBox[{"sfmcadC6", "\[Rule]", "1"}], ",", 
      RowBox[{"sfmcadC4", "\[Rule]", "0.12"}], ",", 
      RowBox[{"Vmcad", "\[Rule]", " ", "0.081"}], ",", 
      RowBox[{"KmmcadC12AcylCoAMAT", "\[Rule]", "5.7"}], ",", 
      RowBox[{"KmmcadC10AcylCoAMAT", "\[Rule]", "5.4"}], ",", 
      RowBox[{"KmmcadC8AcylCoAMAT", "\[Rule]", "4"}], ",", 
      RowBox[{"KmmcadC6AcylCoAMAT", "\[Rule]", "9.4"}], ",", 
      RowBox[{"KmmcadC4AcylCoAMAT", "\[Rule]", "135"}], ",", 
      RowBox[{"KmmcadFAD", "\[Rule]", "0.12"}], ",", 
      RowBox[{"KmmcadC12EnoylCoAMAT", "\[Rule]", "1.08"}], ",", 
      RowBox[{"KmmcadC10EnoylCoAMAT", "\[Rule]", "1.08"}], ",", 
      RowBox[{"KmmcadC8EnoylCoAMAT", "\[Rule]", "1.08"}], ",", 
      RowBox[{"KmmcadC6EnoylCoAMAT", "\[Rule]", "1.08"}], ",", 
      RowBox[{"KmmcadC4EnoylCoAMAT", "\[Rule]", "1.08"}], ",", 
      RowBox[{"KmmcadFADH", "\[Rule]", "24.2"}], ",", 
      RowBox[{"Keqmcad", "\[Rule]", "6"}], ",", "\[IndentingNewLine]", 
      RowBox[{"sfscadC6", "\[Rule]", "0.3"}], ",", 
      RowBox[{"sfscadC4", "\[Rule]", "1"}], ",", 
      RowBox[{"Vscad", "\[Rule]", "0.081"}], ",", 
      RowBox[{"KmscadC6AcylCoAMAT", "\[Rule]", "285"}], ",", 
      RowBox[{"KmscadC4AcylCoAMAT", "\[Rule]", "10.7"}], ",", 
      RowBox[{"KmscadFAD", "\[Rule]", "0.12"}], ",", 
      RowBox[{"KmscadC6EnoylCoAMAT", "\[Rule]", "1.08"}], ",", 
      RowBox[{"KmscadC4EnoylCoAMAT", "\[Rule]", "1.08"}], ",", 
      RowBox[{"KmscadFADH", "\[Rule]", "24.2"}], ",", 
      RowBox[{"Keqscad", "->", "6"}], ",", "\[IndentingNewLine]", 
      RowBox[{"sfcrotC16", "\[Rule]", "0.13"}], ",", 
      RowBox[{"sfcrotC14", "\[Rule]", "0.2"}], ",", 
      RowBox[{"sfcrotC12", "\[Rule]", "0.25"}], ",", 
      RowBox[{"sfcrotC10", "\[Rule]", "0.33"}], ",", 
      RowBox[{"sfcrotC8", "\[Rule]", "0.58"}], ",", 
      RowBox[{"sfcrotC6", "\[Rule]", "0.83"}], ",", 
      RowBox[{"sfcrotC4", "\[Rule]", "1"}], ",", 
      RowBox[{"Vcrot", "\[Rule]", "3.6"}], ",", 
      RowBox[{"KmcrotC16EnoylCoAMAT", "\[Rule]", "150"}], ",", 
      RowBox[{"KmcrotC14EnoylCoAMAT", "\[Rule]", "100"}], ",", 
      RowBox[{"KmcrotC12EnoylCoAMAT", "\[Rule]", "25"}], ",", 
      RowBox[{"KmcrotC10EnoylCoAMAT", "\[Rule]", "25"}], ",", 
      RowBox[{"KmcrotC8EnoylCoAMAT", "\[Rule]", "25"}], ",", 
      RowBox[{"KmcrotC6EnoylCoAMAT", "\[Rule]", "25"}], ",", 
      RowBox[{"KmcrotC4EnoylCoAMAT", "\[Rule]", "40"}], ",", 
      RowBox[{"KmcrotC16HydroxyacylCoAMAT", "\[Rule]", "45"}], ",", 
      RowBox[{"KmcrotC14HydroxyacylCoAMAT", "\[Rule]", "45"}], ",", 
      RowBox[{"KmcrotC12HydroxyacylCoAMAT", "\[Rule]", "45"}], ",", 
      RowBox[{"KmcrotC10HydroxyacylCoAMAT", "\[Rule]", "45"}], ",", 
      RowBox[{"KmcrotC8HydroxyacylCoAMAT", "\[Rule]", "45"}], ",", 
      RowBox[{"KmcrotC6HydroxyacylCoAMAT", "\[Rule]", "45"}], ",", 
      RowBox[{"KmcrotC4HydroxyacylCoAMAT", "\[Rule]", "45"}], ",", 
      RowBox[{"KicrotC4AcetoacylCoA", "\[Rule]", "1.6"}], ",", 
      RowBox[{"Keqcrot", "\[Rule]", "3.13"}], ",", "\[IndentingNewLine]", 
      RowBox[{"sfmschadC16", "\[Rule]", "0.6"}], ",", 
      RowBox[{"sfmschadC14", "\[Rule]", "0.5"}], ",", 
      RowBox[{"sfmschadC12", "\[Rule]", "0.43"}], ",", 
      RowBox[{"sfmschadC10", "\[Rule]", "0.64"}], ",", 
      RowBox[{"sfmschadC8", "\[Rule]", "0.89"}], ",", 
      RowBox[{"sfmschadC6", "\[Rule]", "1"}], ",", 
      RowBox[{"sfmschadC4", "\[Rule]", "0.67"}], ",", 
      RowBox[{"Vmschad", "\[Rule]", "1"}], ",", 
      RowBox[{"KmmschadC16HydroxyacylCoAMAT", "\[Rule]", "1.5"}], ",", 
      RowBox[{"KmmschadC14HydroxyacylCoAMAT", "\[Rule]", "1.8"}], ",", 
      RowBox[{"KmmschadC12HydroxyacylCoAMAT", "\[Rule]", "3.7"}], ",", 
      RowBox[{"KmmschadC10HydroxyacylCoAMAT", "\[Rule]", "8.8"}], ",", 
      RowBox[{"KmmschadC8HydroxyacylCoAMAT", "\[Rule]", "16.3"}], ",", 
      RowBox[{"KmmschadC6HydroxyacylCoAMAT", "\[Rule]", "28.6"}], ",", 
      RowBox[{"KmmschadC4HydroxyacylCoAMAT", "\[Rule]", "69.9"}], ",", 
      RowBox[{"KmmschadNADMAT", "\[Rule]", "58.5"}], ",", 
      RowBox[{"KmmschadC16KetoacylCoAMAT", "\[Rule]", "1.4"}], ",", 
      RowBox[{"KmmschadC14KetoacylCoAMAT", "\[Rule]", "1.4"}], ",", 
      RowBox[{"KmmschadC12KetoacylCoAMAT", "\[Rule]", "1.6"}], ",", 
      RowBox[{"KmmschadC10KetoacylCoAMAT", "\[Rule]", "2.3"}], ",", 
      RowBox[{"KmmschadC8KetoacylCoAMAT", "\[Rule]", "4.1"}], ",", 
      RowBox[{"KmmschadC6KetoacylCoAMAT", "\[Rule]", "5.8"}], ",", 
      RowBox[{"KmmschadC4AcetoacylCoAMAT", "\[Rule]", "16.9"}], ",", 
      RowBox[{"KmmschadNADHMAT", "\[Rule]", "5.4"}], ",", 
      RowBox[{"Keqmschad", "\[Rule]", 
       RowBox[{"2.17", "*", 
        SuperscriptBox["10", 
         RowBox[{"-", "4"}]]}]}], ",", "\[IndentingNewLine]", 
      RowBox[{"sfmckatC16", "\[Rule]", "0"}], ",", 
      RowBox[{"sfmckatC14", "\[Rule]", "0.2"}], ",", 
      RowBox[{"sfmckatC12", "\[Rule]", "0.38"}], ",", 
      RowBox[{"sfmckatC10", "\[Rule]", "0.65"}], ",", 
      RowBox[{"sfmckatC8", "\[Rule]", "0.81"}], ",", 
      RowBox[{"sfmckatC6", "\[Rule]", "1"}], ",", 
      RowBox[{"sfmckatC4", "\[Rule]", "0.49"}], ",", 
      RowBox[{"Vmckat", "\[Rule]", "0.377"}], ",", 
      RowBox[{"KmmckatC16KetoacylCoAMAT", "\[Rule]", "1.1"}], ",", 
      RowBox[{"KmmckatC14KetoacylCoAMAT", "\[Rule]", "1.2"}], ",", 
      RowBox[{"KmmckatC12KetoacylCoAMAT", "\[Rule]", "1.3"}], ",", 
      RowBox[{"KmmckatC10KetoacylCoAMAT", "\[Rule]", "2.1"}], ",", 
      RowBox[{"KmmckatC8KetoacylCoAMAT", "\[Rule]", "3.2"}], ",", 
      RowBox[{"KmmckatC6KetoacylCoAMAT", "\[Rule]", "6.7"}], ",", 
      RowBox[{"KmmckatC4AcetoacylCoAMAT", "\[Rule]", "12.4"}], ",", 
      RowBox[{"KmmckatCoAMAT", "\[Rule]", "26.6"}], ",", 
      RowBox[{"KmmckatC14AcylCoAMAT", "\[Rule]", "13.83"}], ",", 
      RowBox[{"KmmckatC16AcylCoAMAT", "\[Rule]", "13.83"}], ",", 
      RowBox[{"KmmckatC12AcylCoAMAT", "\[Rule]", "13.83"}], ",", 
      RowBox[{"KmmckatC10AcylCoAMAT", "\[Rule]", "13.83"}], ",", 
      RowBox[{"KmmckatC8AcylCoAMAT", "\[Rule]", "13.83"}], ",", 
      RowBox[{"KmmckatC6AcylCoAMAT", "\[Rule]", "13.83"}], ",", 
      RowBox[{"KmmckatC4AcylCoAMAT", "\[Rule]", "13.83"}], ",", 
      RowBox[{"KmmckatAcetylCoAMAT", "\[Rule]", "30"}], ",", 
      RowBox[{"Keqmckat", "\[Rule]", "1051"}], ",", "\[IndentingNewLine]", 
      RowBox[{"sfmtpC16", "\[Rule]", "1"}], ",", 
      RowBox[{"sfmtpC14", "\[Rule]", "0.9"}], ",", 
      RowBox[{"sfmtpC12", "\[Rule]", "0.81"}], ",", 
      RowBox[{"sfmtpC10", "\[Rule]", "0.73"}], ",", 
      RowBox[{"sfmtpC8", "\[Rule]", "0.34"}], ",", 
      RowBox[{"Vmtp", "\[Rule]", "2.84"}], ",", 
      RowBox[{"KmmtpC16EnoylCoAMAT", "\[Rule]", "25"}], ",", 
      RowBox[{"KmmtpC14EnoylCoAMAT", "\[Rule]", "25"}], ",", 
      RowBox[{"KmmtpC12EnoylCoAMAT", "\[Rule]", "25"}], ",", 
      RowBox[{"KmmtpC10EnoylCoAMAT", "\[Rule]", "25"}], ",", 
      RowBox[{"KmmtpC8EnoylCoAMAT", "\[Rule]", "25"}], ",", 
      RowBox[{"KmmtpNADMAT", "\[Rule]", "60"}], ",", 
      RowBox[{"KmmtpCoAMAT", "\[Rule]", "30"}], ",", 
      RowBox[{"KmmtpC14AcylCoAMAT", "\[Rule]", "13.83"}], ",", 
      RowBox[{"KmmtpC16AcylCoAMAT", "\[Rule]", "13.83"}], ",", 
      RowBox[{"KmmtpC12AcylCoAMAT", "\[Rule]", "13.83"}], ",", 
      RowBox[{"KmmtpC10AcylCoAMAT", "\[Rule]", "13.83"}], ",", 
      RowBox[{"KmmtpC8AcylCoAMAT", "\[Rule]", "13.83"}], ",", 
      RowBox[{"KmmtpC6AcylCoAMAT", "\[Rule]", "13.83"}], ",", 
      RowBox[{"KmmtpNADHMAT", "\[Rule]", "50"}], ",", 
      RowBox[{"KmmtpAcetylCoAMAT", "\[Rule]", "30"}], ",", 
      RowBox[{"Keqmtp", "\[Rule]", "0.71"}], ",", "\[IndentingNewLine]", 
      RowBox[{"Ksacesink", "\[Rule]", "6000000"}], ",", " ", 
      RowBox[{"K1acesink", "\[Rule]", "70"}], ",", 
      RowBox[{"Ksfadhsink", "\[Rule]", "6000000"}], ",", 
      RowBox[{"K1fadhsink", "\[Rule]", "0.46"}], ",", 
      RowBox[{"Ksnadhsink", "\[Rule]", "6000000"}], ",", 
      RowBox[{"K1nadhsink", "\[Rule]", "12"}], ",", "\[IndentingNewLine]", 
      RowBox[{"C16AcylCoACYT", "\[Rule]", "25"}], ",", 
      RowBox[{"CarCYT", "\[Rule]", "200"}], ",", 
      RowBox[{"CoACYT", "\[Rule]", "140"}], ",", 
      RowBox[{"MalCoACYT", "\[Rule]", "0"}], ",", 
      RowBox[{"CarMAT", "->", "950"}], ",", 
      RowBox[{"FADtMAT", "\[Rule]", "0.77"}], ",", 
      RowBox[{"NADtMAT", "\[Rule]", "250"}], ",", 
      RowBox[{"CoAMATt", "\[Rule]", "5000"}], ",", "\[IndentingNewLine]", 
      RowBox[{"VCYT", "\[Rule]", 
       RowBox[{"2.2", "*", 
        SuperscriptBox["10", 
         RowBox[{"-", "6"}]]}]}], ",", 
      RowBox[{"VMAT", "\[Rule]", 
       RowBox[{"1.8", "*", 
        SuperscriptBox["10", 
         RowBox[{"-", "6"}]]}]}], ",", "\[IndentingNewLine]", 
      RowBox[{"CE1", "\[Rule]", "50"}], ",", 
      RowBox[{"KmCE1", "\[Rule]", "50"}], ",", 
      RowBox[{"nE1", "\[Rule]", "1"}], ",", "\[IndentingNewLine]", 
      RowBox[{
       StyleBox["Vmaxoxph",
        Background->RGBColor[0.5843137254901961, 1., 0.5843137254901961]], 
       "\[Rule]", "0.155"}], 
      RowBox[{"(*", 
       RowBox[{"0.137", ",", "0.152", " ", ",", " ", "1.791"}], "*)"}], 
      StyleBox[",",
       Background->RGBColor[0.5843137254901961, 1., 0.5843137254901961]], 
      RowBox[{
       StyleBox["KmnadhOxPh",
        Background->RGBColor[0.5843137254901961, 1., 0.5843137254901961]], 
       "\[Rule]", "4.3"}], 
      StyleBox[",",
       Background->RGBColor[0.5843137254901961, 1., 0.5843137254901961]], 
      RowBox[{
       StyleBox["KmnadOxPh",
        Background->RGBColor[0.5843137254901961, 1., 0.5843137254901961]], 
       "\[Rule]", "780"}], ",", 
      RowBox[{
       StyleBox["VmaxPDH",
        Background->RGBColor[0.5843137254901961, 1., 0.5843137254901961]], 
       "\[Rule]", "0.127"}], 
      StyleBox[",",
       Background->RGBColor[0.5843137254901961, 1., 0.5843137254901961]], 
      RowBox[{
       StyleBox["KmnadPDH",
        Background->RGBColor[0.5843137254901961, 1., 0.5843137254901961]], 
       "\[Rule]", "60.7"}], 
      StyleBox[",",
       Background->RGBColor[0.5843137254901961, 1., 0.5843137254901961]], 
      RowBox[{
       StyleBox["KmnadhPDH",
        Background->RGBColor[0.5843137254901961, 1., 0.5843137254901961]], 
       "\[Rule]", "40"}], ",", "\[IndentingNewLine]", 
      RowBox[{"vmct1acet", "\[Rule]", "8.3"}], ",", 
      RowBox[{"kmct1acet", "\[Rule]", "1.5"}], ",", 
      RowBox[{"AcetateMAT", "\[Rule]", "0"}], ",", 
      RowBox[{"propacetcpt1", "\[Rule]", "0.12"}], " ", ",", 
      RowBox[{"propacetsink", "\[Rule]", "0.13"}], " ", ",", 
      RowBox[{"propacetcact", "\[Rule]", "0"}], ",", 
      RowBox[{"propacetcpt2", "\[Rule]", "0"}], ",", 
      RowBox[{"propacetmal", "\[Rule]", "0"}], ",", 
      RowBox[{"propacetmckat", "\[Rule]", " ", "0"}], " ", 
      RowBox[{"(*", "0.1", "*)"}], ",", " ", 
      RowBox[{"nc", "\[Rule]", "2"}]}], "}"}]}], ";"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"InitialConditions", "=", 
    RowBox[{"{", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{
       RowBox[{"C16AcylCarCYT", "[", "0", "]"}], "\[Equal]", "0"}], ",", 
      RowBox[{
       RowBox[{"C16AcylCarMAT", "[", "0", "]"}], "\[Equal]", "0"}], ",", 
      RowBox[{
       RowBox[{"C16AcylCoAMAT", "[", "0", "]"}], "\[Equal]", "0"}], ",", 
      RowBox[{
       RowBox[{"C16EnoylCoAMAT", "[", "0", "]"}], "\[Equal]", "0"}], ",", 
      RowBox[{
       RowBox[{"C16HydroxyacylCoAMAT", "[", "0", "]"}], "\[Equal]", "0"}], 
      ",", 
      RowBox[{
       RowBox[{"C16KetoacylCoAMAT", "[", "0", "]"}], "\[Equal]", "0"}], ",", 
      "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{"C14AcylCarCYT", "[", "0", "]"}], "\[Equal]", "0"}], ",", 
      RowBox[{
       RowBox[{"C14AcylCarMAT", "[", "0", "]"}], "\[Equal]", "0"}], ",", 
      RowBox[{
       RowBox[{"C14AcylCoAMAT", "[", "0", "]"}], "\[Equal]", "0"}], ",", 
      RowBox[{
       RowBox[{"C14EnoylCoAMAT", "[", "0", "]"}], "\[Equal]", "0"}], ",", 
      RowBox[{
       RowBox[{"C14HydroxyacylCoAMAT", "[", "0", "]"}], "\[Equal]", "0"}], 
      ",", 
      RowBox[{
       RowBox[{"C14KetoacylCoAMAT", "[", "0", "]"}], "\[Equal]", "0"}], ",", 
      "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{"C12AcylCarCYT", "[", "0", "]"}], "\[Equal]", "0"}], ",", 
      RowBox[{
       RowBox[{"C12AcylCarMAT", "[", "0", "]"}], "\[Equal]", "0"}], ",", 
      RowBox[{
       RowBox[{"C12AcylCoAMAT", "[", "0", "]"}], "\[Equal]", "0"}], ",", 
      RowBox[{
       RowBox[{"C12EnoylCoAMAT", "[", "0", "]"}], "\[Equal]", "0"}], ",", 
      RowBox[{
       RowBox[{"C12HydroxyacylCoAMAT", "[", "0", "]"}], "\[Equal]", "0"}], 
      ",", 
      RowBox[{
       RowBox[{"C12KetoacylCoAMAT", "[", "0", "]"}], "\[Equal]", "0"}], ",", 
      "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{"C10AcylCarCYT", "[", "0", "]"}], "\[Equal]", "0"}], ",", 
      RowBox[{
       RowBox[{"C10AcylCarMAT", "[", "0", "]"}], "\[Equal]", "0"}], ",", 
      RowBox[{
       RowBox[{"C10AcylCoAMAT", "[", "0", "]"}], "\[Equal]", "0"}], ",", 
      RowBox[{
       RowBox[{"C10EnoylCoAMAT", "[", "0", "]"}], "\[Equal]", "0"}], ",", 
      RowBox[{
       RowBox[{"C10HydroxyacylCoAMAT", "[", "0", "]"}], "\[Equal]", "0"}], 
      ",", 
      RowBox[{
       RowBox[{"C10KetoacylCoAMAT", "[", "0", "]"}], "\[Equal]", "0"}], ",", 
      "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{"C8AcylCarCYT", "[", "0", "]"}], "\[Equal]", "0"}], ",", 
      RowBox[{
       RowBox[{"C8AcylCarMAT", "[", "0", "]"}], "\[Equal]", "0"}], ",", 
      RowBox[{
       RowBox[{"C8AcylCoAMAT", "[", "0", "]"}], "\[Equal]", "0"}], ",", 
      RowBox[{
       RowBox[{"C8EnoylCoAMAT", "[", "0", "]"}], "\[Equal]", "0"}], ",", 
      RowBox[{
       RowBox[{"C8HydroxyacylCoAMAT", "[", "0", "]"}], "\[Equal]", "0"}], ",", 
      RowBox[{
       RowBox[{"C8KetoacylCoAMAT", "[", "0", "]"}], "\[Equal]", "0"}], ",", 
      "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{"C6AcylCarCYT", "[", "0", "]"}], "\[Equal]", "0"}], ",", 
      RowBox[{
       RowBox[{"C6AcylCarMAT", "[", "0", "]"}], "\[Equal]", "0"}], ",", 
      RowBox[{
       RowBox[{"C6AcylCoAMAT", "[", "0", "]"}], "\[Equal]", "0"}], ",", 
      RowBox[{
       RowBox[{"C6EnoylCoAMAT", "[", "0", "]"}], "\[Equal]", "0"}], ",", 
      RowBox[{
       RowBox[{"C6HydroxyacylCoAMAT", "[", "0", "]"}], "\[Equal]", "0"}], ",", 
      RowBox[{
       RowBox[{"C6KetoacylCoAMAT", "[", "0", "]"}], "\[Equal]", "0"}], ",", 
      "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{"C4AcylCarCYT", "[", "0", "]"}], "\[Equal]", "0"}], ",", 
      RowBox[{
       RowBox[{"C4AcylCarMAT", "[", "0", "]"}], "\[Equal]", "0"}], ",", 
      RowBox[{
       RowBox[{"C4AcylCoAMAT", "[", "0", "]"}], "\[Equal]", "0"}], ",", 
      RowBox[{
       RowBox[{"C4EnoylCoAMAT", "[", "0", "]"}], "\[Equal]", "0"}], ",", 
      RowBox[{
       RowBox[{"C4HydroxyacylCoAMAT", "[", "0", "]"}], "\[Equal]", "0"}], ",", 
      RowBox[{
       RowBox[{"C4AcetoacylCoAMAT", "[", "0", "]"}], "\[Equal]", "0"}], ",", 
      " ", "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{"AcetylCoAMAT", "[", "0", "]"}], "\[Equal]", "70"}], ",", 
      RowBox[{
       RowBox[{"FADHMAT", "[", "0", "]"}], "\[Equal]", "0.46"}], ",", 
      RowBox[{
       RowBox[{"NADHMAT", "[", "0", "]"}], "\[Equal]", "12"}]}], "}"}]}], 
   ";"}], " ", "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"Vars", "=", 
    RowBox[{"{", "\[IndentingNewLine]", 
     RowBox[{
     "C16AcylCarCYT", ",", "C16AcylCarMAT", ",", "C16AcylCoAMAT", ",", 
      "C16EnoylCoAMAT", ",", "C16HydroxyacylCoAMAT", ",", "C16KetoacylCoAMAT",
       ",", "\[IndentingNewLine]", "C14AcylCarCYT", ",", "C14AcylCarMAT", ",",
       "C14AcylCoAMAT", ",", "C14EnoylCoAMAT", ",", "C14HydroxyacylCoAMAT", 
      ",", "C14KetoacylCoAMAT", ",", "\[IndentingNewLine]", "C12AcylCarCYT", 
      ",", "C12AcylCarMAT", ",", "C12AcylCoAMAT", ",", "C12EnoylCoAMAT", ",", 
      "C12HydroxyacylCoAMAT", ",", "C12KetoacylCoAMAT", ",", 
      "\[IndentingNewLine]", "C10AcylCarCYT", ",", "C10AcylCarMAT", ",", 
      "C10AcylCoAMAT", ",", "C10EnoylCoAMAT", ",", "C10HydroxyacylCoAMAT", 
      ",", "C10KetoacylCoAMAT", ",", "\[IndentingNewLine]", "C8AcylCarCYT", 
      ",", "C8AcylCarMAT", ",", "C8AcylCoAMAT", ",", "C8EnoylCoAMAT", ",", 
      "C8HydroxyacylCoAMAT", ",", "C8KetoacylCoAMAT", ",", 
      "\[IndentingNewLine]", "C6AcylCarCYT", ",", "C6AcylCarMAT", ",", 
      "C6AcylCoAMAT", ",", "C6EnoylCoAMAT", ",", "C6HydroxyacylCoAMAT", ",", 
      "C6KetoacylCoAMAT", ",", "\[IndentingNewLine]", "C4AcylCarCYT", ",", 
      "C4AcylCarMAT", ",", "C4AcylCoAMAT", ",", "C4EnoylCoAMAT", ",", 
      "C4HydroxyacylCoAMAT", ",", "C4AcetoacylCoAMAT", ",", 
      "\[IndentingNewLine]", "AcetylCoAMAT", ",", "FADHMAT", ",", "NADHMAT"}],
      "}"}]}], ";"}], " "}]}], "Input",
 CellChangeTimes->{{3.49033632684375*^9, 3.490336330578125*^9}, {
   3.490336364078125*^9, 3.49033654615625*^9}, {3.490336671046875*^9, 
   3.4903368766875*^9}, {3.49033913559375*^9, 3.490339355640625*^9}, {
   3.490341195015625*^9, 3.490341806984375*^9}, {3.49034975878125*^9, 
   3.4903497934375*^9}, {3.49189429596875*^9, 3.491894555453125*^9}, {
   3.49189460015625*^9, 3.49189463259375*^9}, {3.4918946951875*^9, 
   3.49189482253125*^9}, {3.4918948665625*^9, 3.491894972140625*^9}, {
   3.491895068640625*^9, 3.49189525965625*^9}, {3.491895327015625*^9, 
   3.491895569703125*^9}, {3.491895645046875*^9, 3.491895810640625*^9}, {
   3.4918963691875*^9, 3.4918963805625*^9}, {3.49189688278125*^9, 
   3.49189694175*^9}, {3.491898080578125*^9, 3.491898081484375*^9}, {
   3.4918982166875*^9, 3.491898230140625*^9}, {3.491898271421875*^9, 
   3.491898513875*^9}, {3.491898614390625*^9, 3.491898663890625*^9}, {
   3.49189885528125*^9, 3.4918990861875*^9}, {3.4918994204375*^9, 
   3.49189951471875*^9}, {3.4918995453125*^9, 3.49189974634375*^9}, {
   3.49189984628125*^9, 3.491899850203125*^9}, {3.49352235571875*^9, 
   3.493522603703125*^9}, {3.4935243883125*^9, 3.493524752546875*^9}, {
   3.493525739578125*^9, 3.493525789765625*^9}, {3.49352647221875*^9, 
   3.49352651478125*^9}, {3.493526554625*^9, 3.493526566984375*^9}, {
   3.4935313500625*^9, 3.493531567078125*^9}, {3.493531613*^9, 
   3.493531800625*^9}, {3.493532209125*^9, 3.493532311109375*^9}, {
   3.493532378109375*^9, 3.4935324143125*^9}, {3.493532514640625*^9, 
   3.4935327125*^9}, {3.493535831828125*^9, 3.493535860453125*^9}, {
   3.493536501734375*^9, 3.4935365024375*^9}, {3.4935365513125*^9, 
   3.49353657553125*^9}, {3.493536613390625*^9, 3.4935366628125*^9}, {
   3.4935367173125*^9, 3.493536773046875*^9}, {3.493536942890625*^9, 
   3.493537219484375*^9}, {3.493538634140625*^9, 3.493538778703125*^9}, {
   3.493538860921875*^9, 3.493538874515625*^9}, {3.493538909*^9, 
   3.4935389535*^9}, {3.493539534015625*^9, 3.493539536703125*^9}, {
   3.49353958271875*^9, 3.4935396210625*^9}, {3.4935396769375*^9, 
   3.493539724703125*^9}, {3.49353995353125*^9, 3.4935400255625*^9}, {
   3.493540109796875*^9, 3.493540247046875*^9}, {3.49354028334375*^9, 
   3.4935403468125*^9}, {3.493540379609375*^9, 3.493540506265625*^9}, {
   3.493540567203125*^9, 3.493540618890625*^9}, {3.493541008546875*^9, 
   3.493541052875*^9}, {3.493541404921875*^9, 3.493541535984375*^9}, {
   3.493541566078125*^9, 3.493541711640625*^9}, {3.493541917765625*^9, 
   3.4935419811875*^9}, {3.49354201975*^9, 3.493542579703125*^9}, {
   3.49354261884375*^9, 3.493542827953125*^9}, {3.49354285884375*^9, 
   3.4935431838125*^9}, {3.494142151625*^9, 3.494142153328125*^9}, {
   3.49414314634375*^9, 3.494143263390625*^9}, {3.49414330640625*^9, 
   3.4941436175625*^9}, {3.4941510911875*^9, 3.49415143546875*^9}, {
   3.494151471375*^9, 3.494151525609375*^9}, {3.494152046796875*^9, 
   3.494152049703125*^9}, {3.494152157953125*^9, 3.494152206390625*^9}, {
   3.49415225903125*^9, 3.494152293640625*^9}, {3.494234214296875*^9, 
   3.49423422165625*^9}, {3.4942343816875*^9, 3.494235259390625*^9}, {
   3.494235473171875*^9, 3.49423574253125*^9}, {3.494236160421875*^9, 
   3.49423621784375*^9}, {3.49423633009375*^9, 3.4942363305625*^9}, {
   3.4942363938125*^9, 3.49423658134375*^9}, {3.494237287203125*^9, 
   3.494237288765625*^9}, {3.494302134984375*^9, 3.49430231984375*^9}, {
   3.494302369328125*^9, 3.49430240271875*^9}, {3.4943024814375*^9, 
   3.494302692890625*^9}, {3.494302725984375*^9, 3.49430307603125*^9}, {
   3.49430313359375*^9, 3.49430317346875*^9}, {3.4948184886875*^9, 
   3.494818542046875*^9}, {3.4948185813125*^9, 3.494818616921875*^9}, {
   3.49481864821875*^9, 3.4948186741875*^9}, {3.494819062578125*^9, 
   3.49481915596875*^9}, {3.494821013890625*^9, 3.49482106053125*^9}, {
   3.494821119828125*^9, 3.494821121578125*^9}, {3.494821263859375*^9, 
   3.494821275453125*^9}, {3.494821835640625*^9, 3.49482193259375*^9}, {
   3.49482211196875*^9, 3.494822641796875*^9}, {3.49482270328125*^9, 
   3.494822879625*^9}, {3.494822913359375*^9, 3.49482293525*^9}, {
   3.494822968484375*^9, 3.49482299378125*^9}, {3.49482309025*^9, 
   3.49482310034375*^9}, {3.494823137046875*^9, 3.494823137890625*^9}, {
   3.49482319403125*^9, 3.494823220890625*^9}, {3.494823305203125*^9, 
   3.4948233096875*^9}, {3.49482339259375*^9, 3.49482341990625*^9}, {
   3.49482345109375*^9, 3.494823453546875*^9}, {3.494823484921875*^9, 
   3.494823583078125*^9}, {3.494826867640625*^9, 3.494826869125*^9}, {
   3.49482743403125*^9, 3.4948274356875*^9}, {3.494827505953125*^9, 
   3.494827615703125*^9}, 3.494827665578125*^9, {3.494829267796875*^9, 
   3.4948292888125*^9}, {3.49482936053125*^9, 3.494829363203125*^9}, {
   3.49482956925*^9, 3.49482957703125*^9}, 3.494829627171875*^9, {
   3.494830438375*^9, 3.49483045453125*^9}, {3.494830601796875*^9, 
   3.494830614296875*^9}, {3.49483084778125*^9, 3.494830853109375*^9}, {
   3.494830893734375*^9, 3.494830903375*^9}, {3.494831908234375*^9, 
   3.494832247546875*^9}, {3.494832342953125*^9, 3.494832343765625*^9}, {
   3.494832381671875*^9, 3.494832386109375*^9}, {3.494832426875*^9, 
   3.494832439328125*^9}, {3.494832469734375*^9, 3.49483251459375*^9}, {
   3.49483257040625*^9, 3.49483257584375*^9}, {3.4948326649375*^9, 
   3.494832826859375*^9}, {3.494833067625*^9, 3.4948330684375*^9}, 
   3.494833101578125*^9, {3.49483315409375*^9, 3.49483316315625*^9}, {
   3.494833259640625*^9, 3.49483328353125*^9}, {3.494833406109375*^9, 
   3.494833510703125*^9}, {3.494833605515625*^9, 3.49483360603125*^9}, {
   3.49483428084375*^9, 3.494834451234375*^9}, {3.494834875375*^9, 
   3.49483487578125*^9}, 3.4948351131875*^9, {3.494835151765625*^9, 
   3.494835160375*^9}, {3.494838000484375*^9, 3.49483811496875*^9}, {
   3.494846938453125*^9, 3.494846938984375*^9}, {3.494847780296875*^9, 
   3.4948477815625*^9}, {3.49490621590625*^9, 3.494906216578125*^9}, 
   3.494914298328125*^9, {3.49491637040625*^9, 3.494916370765625*^9}, {
   3.494916424921875*^9, 3.494916425*^9}, 3.49491655740625*^9, {
   3.4949166096875*^9, 3.4949166103125*^9}, {3.49491748284375*^9, 
   3.49491748853125*^9}, {3.494922391203125*^9, 3.49492239290625*^9}, {
   3.494922448859375*^9, 3.49492245890625*^9}, {3.494922497203125*^9, 
   3.494922500453125*^9}, {3.495120879035725*^9, 3.4951208791985683`*^9}, {
   3.4951209501840687`*^9, 3.495120951694242*^9}, {3.495121005322798*^9, 
   3.495121006837408*^9}, {3.495121049927929*^9, 3.495121051280054*^9}, {
   3.495121123716422*^9, 3.495121125551434*^9}, {3.495121177662735*^9, 
   3.495121180130315*^9}, {3.495271887671875*^9, 3.495271934046875*^9}, {
   3.497168336578125*^9, 3.497168337625*^9}, {3.4973237874375*^9, 
   3.4973237906875*^9}, {3.4973458345*^9, 3.497345843015625*^9}, {
   3.49734783021875*^9, 3.49734783075*^9}, 3.497347862359375*^9, {
   3.49734861984375*^9, 3.49734863728125*^9}, 3.497348875140625*^9, {
   3.497350023921875*^9, 3.497350026890625*^9}, {3.49735079075*^9, 
   3.497350791328125*^9}, {3.497680258125*^9, 3.49768028565625*^9}, {
   3.4976804075625*^9, 3.497680429609375*^9}, 3.49768050284375*^9, {
   3.49768080459375*^9, 3.49768080478125*^9}, {3.49768090053125*^9, 
   3.497680901078125*^9}, {3.497681088890625*^9, 3.497681140609375*^9}, {
   3.49768174996875*^9, 3.497681756953125*^9}, {3.497681812671875*^9, 
   3.497681817671875*^9}, 3.49768221175*^9, {3.497682283171875*^9, 
   3.497682288109375*^9}, {3.49777757765625*^9, 3.497777626640625*^9}, {
   3.497777774640625*^9, 3.49777791696875*^9}, {3.497778006359375*^9, 
   3.497778040765625*^9}, {3.497778073890625*^9, 3.4977781805625*^9}, 
   3.497778225171875*^9, 3.497778442265625*^9, {3.497778534875*^9, 
   3.49777856259375*^9}, {3.49777873790625*^9, 3.497778738671875*^9}, {
   3.498970635984375*^9, 3.498970641796875*^9}, {3.49899047690625*^9, 
   3.498990534703125*^9}, {3.498990893625*^9, 3.4989908961875*^9}, {
   3.506414681765625*^9, 3.506414688390625*^9}, {3.50676570646875*^9, 
   3.506765712296875*^9}, {3.506767935328125*^9, 3.5067679390625*^9}, {
   3.50676798903125*^9, 3.506767992828125*^9}, {3.5067680466875*^9, 
   3.506768050859375*^9}, {3.506768211484375*^9, 3.50676821690625*^9}, {
   3.50676826534375*^9, 3.506768268*^9}, {3.506768340140625*^9, 
   3.5067683439375*^9}, {3.5067683989375*^9, 3.50676840409375*^9}, {
   3.506768463828125*^9, 3.506768465*^9}, {3.506768523078125*^9, 
   3.50676852478125*^9}, {3.506768591328125*^9, 3.50676859275*^9}, {
   3.506769390359375*^9, 3.506769394484375*^9}, 3.506846770625*^9, 
   3.50684683015625*^9, 3.506846875203125*^9, {3.506847641078125*^9, 
   3.50684764603125*^9}, 3.506847703265625*^9, {3.506847743890625*^9, 
   3.5068477675*^9}, {3.506847799546875*^9, 3.50684782315625*^9}, {
   3.50684787434375*^9, 3.5068479043125*^9}, 3.50684794728125*^9, {
   3.50684799459375*^9, 3.50684799475*^9}, {3.506848040859375*^9, 
   3.506848059765625*^9}, 3.506848094703125*^9, {3.50684814190625*^9, 
   3.50684819378125*^9}, {3.5068482406875*^9, 3.506848240828125*^9}, 
   3.50684829146875*^9, 3.506848331734375*^9, {3.506848387765625*^9, 
   3.50684839353125*^9}, {3.506848438296875*^9, 3.50684843859375*^9}, {
   3.506848500796875*^9, 3.5068485009375*^9}, {3.506848559765625*^9, 
   3.506848559921875*^9}, {3.506848603125*^9, 3.50684860325*^9}, {
   3.5068486650625*^9, 3.506848667359375*^9}, {3.506848709890625*^9, 
   3.506848710015625*^9}, {3.506848753578125*^9, 3.506848753859375*^9}, {
   3.50684880240625*^9, 3.5068488025625*^9}, {3.50684884515625*^9, 
   3.506848845703125*^9}, 3.506848883859375*^9, {3.506848922421875*^9, 
   3.506848923515625*^9}, {3.506848977546875*^9, 3.506848977703125*^9}, {
   3.506849023375*^9, 3.5068490235*^9}, {3.5068490605625*^9, 
   3.506849060703125*^9}, {3.5068491060625*^9, 3.506849106859375*^9}, {
   3.506849149109375*^9, 3.506849150578125*^9}, 3.50684919859375*^9, 
   3.5068493254375*^9, {3.5068505126875*^9, 3.506850513078125*^9}, {
   3.50685055525*^9, 3.506850558109375*^9}, 3.506850601765625*^9, 
   3.506850671296875*^9, {3.5068507105625*^9, 3.5068507109375*^9}, {
   3.506850758234375*^9, 3.5068507816875*^9}, {3.508055074609375*^9, 
   3.5080550773125*^9}, {3.508055123578125*^9, 3.508055123890625*^9}, {
   3.508055267828125*^9, 3.508055268203125*^9}, {3.5080554336875*^9, 
   3.508055433921875*^9}, {3.508055562609375*^9, 3.508055566140625*^9}, {
   3.508055626765625*^9, 3.50805562690625*^9}, {3.508062599953125*^9, 
   3.508062630078125*^9}, {3.50856361628125*^9, 3.508563747484375*^9}, {
   3.508564154*^9, 3.50856431196875*^9}, {3.508564349828125*^9, 
   3.50856463484375*^9}, {3.508565008296875*^9, 3.50856517746875*^9}, {
   3.508565222609375*^9, 3.508565361515625*^9}, {3.50856572925*^9, 
   3.50856572940625*^9}, {3.50856583003125*^9, 3.50856583334375*^9}, {
   3.508566542171875*^9, 3.50856654234375*^9}, {3.508566679640625*^9, 
   3.508566679796875*^9}, {3.50857331575*^9, 3.50857346409375*^9}, {
   3.508573554609375*^9, 3.508573595734375*^9}, {3.508573721578125*^9, 
   3.5085740005*^9}, {3.508574060375*^9, 3.5085741295625*^9}, {
   3.508574200375*^9, 3.508574220484375*^9}, {3.5085742994375*^9, 
   3.50857432378125*^9}, 3.508574557578125*^9, {3.50857462571875*^9, 
   3.5085750135625*^9}, {3.508575086828125*^9, 3.508575144671875*^9}, {
   3.508575742328125*^9, 3.5085757425*^9}, {3.508576186765625*^9, 
   3.50857618709375*^9}, {3.508576260671875*^9, 3.508576260828125*^9}, 
   3.50857631334375*^9, {3.508577516515625*^9, 3.5085775846875*^9}, {
   3.508577645859375*^9, 3.50857769590625*^9}, {3.50857776290625*^9, 
   3.50857778309375*^9}, {3.508577846984375*^9, 3.508578486734375*^9}, {
   3.508578527265625*^9, 3.50857867196875*^9}, {3.50857873309375*^9, 
   3.50857885428125*^9}, {3.50857894471875*^9, 3.508579013890625*^9}, {
   3.50857904859375*^9, 3.508579070984375*^9}, {3.50857910521875*^9, 
   3.50857910540625*^9}, {3.508579159765625*^9, 3.508579160140625*^9}, 
   3.508579351671875*^9, {3.50858116684375*^9, 3.508581256140625*^9}, {
   3.5085812975*^9, 3.508581297671875*^9}, {3.508581605203125*^9, 
   3.508581606546875*^9}, {3.5085836325625*^9, 3.508583632921875*^9}, {
   3.50858377378125*^9, 3.508583774140625*^9}, 3.508583822140625*^9, {
   3.508583874421875*^9, 3.508583876140625*^9}, {3.508583921625*^9, 
   3.508583959671875*^9}, {3.508584127140625*^9, 3.508584165828125*^9}, {
   3.5085854924375*^9, 3.50858549325*^9}, {3.508585780546875*^9, 
   3.508585780921875*^9}, {3.51340978603125*^9, 3.513409859890625*^9}, {
   3.5134099006875*^9, 3.513410003515625*^9}, {3.5134100644375*^9, 
   3.513410151875*^9}, {3.513410426703125*^9, 3.513410465046875*^9}, {
   3.513410618453125*^9, 3.51341062034375*^9}, {3.51341072134375*^9, 
   3.51341072365625*^9}, 3.5134108025625*^9, {3.51341088775*^9, 
   3.513410889734375*^9}, {3.513411429875*^9, 3.513411439953125*^9}, {
   3.51341184678125*^9, 3.513411847234375*^9}, {3.513481825984375*^9, 
   3.5134819233125*^9}, 3.513482057421875*^9, {3.51348497865625*^9, 
   3.51348497890625*^9}, {3.513485029046875*^9, 3.5134850321875*^9}, {
   3.5146958456875*^9, 3.514695847*^9}, 3.51469988259375*^9, {
   3.514700054734375*^9, 3.514700133765625*^9}, {3.514700241046875*^9, 
   3.514700241546875*^9}, {3.514700417*^9, 3.514700420578125*^9}, {
   3.5188477059375*^9, 3.518847724171875*^9}, {3.518847813984375*^9, 
   3.51884781428125*^9}, {3.51884787571875*^9, 3.51884787609375*^9}, 
   3.518847928671875*^9, 3.5188479888125*^9, 3.518848052015625*^9, {
   3.5188480941875*^9, 3.518848094375*^9}, {3.5188481549375*^9, 
   3.518848155015625*^9}, {3.51884821984375*^9, 3.51884822553125*^9}, {
   3.51884829128125*^9, 3.518848291390625*^9}, {3.518848346234375*^9, 
   3.5188483463125*^9}, {3.518848393421875*^9, 3.518848393484375*^9}, {
   3.5188484475*^9, 3.518848447734375*^9}, {3.51884850475*^9, 
   3.518848504796875*^9}, {3.5188487274375*^9, 3.518848727515625*^9}, {
   3.518849030359375*^9, 3.5188490305625*^9}, {3.51884910553125*^9, 
   3.518849105859375*^9}, {3.518849165140625*^9, 3.518849186609375*^9}, {
   3.518849277140625*^9, 3.51884927728125*^9}, {3.52030976371875*^9, 
   3.520309778546875*^9}, 3.52031473028125*^9, {3.52031497396875*^9, 
   3.5203149743125*^9}, 3.520315535625*^9, 3.5203155963125*^9, 
   3.520315721984375*^9, {3.520316075375*^9, 3.520316094234375*^9}, {
   3.52031614446875*^9, 3.520316144546875*^9}, {3.52031619471875*^9, 
   3.52031619521875*^9}, 3.52031624165625*^9, 3.5203163064375*^9, {
   3.520316377046875*^9, 3.520316377703125*^9}, {3.520316434625*^9, 
   3.5203164346875*^9}, {3.5203165164375*^9, 3.52031651815625*^9}, {
   3.52031659109375*^9, 3.520316591265625*^9}, {3.520316652140625*^9, 
   3.520316652265625*^9}, {3.52031669290625*^9, 3.52031669303125*^9}, {
   3.520316738109375*^9, 3.520316738171875*^9}, {3.520316792828125*^9, 
   3.520316792890625*^9}, {3.52031686*^9, 3.520316860125*^9}, {
   3.52031693921875*^9, 3.52031693934375*^9}, {3.520318236046875*^9, 
   3.52031823621875*^9}, {3.520742868015625*^9, 3.52074293175*^9}, {
   3.520743005296875*^9, 3.520743008265625*^9}, {3.520743056921875*^9, 
   3.520743100296875*^9}, {3.520743131765625*^9, 3.520743141078125*^9}, {
   3.520743202609375*^9, 3.520743202796875*^9}, {3.52074333346875*^9, 
   3.52074333378125*^9}, 3.52074405278125*^9, {3.52074410409375*^9, 
   3.520744104625*^9}, 3.520744151140625*^9, 3.520746034953125*^9, 
   3.520746084125*^9, 3.5207461761875*^9, {3.5211719026886797`*^9, 
   3.5211719226467657`*^9}, {3.521171961570594*^9, 3.5211719795495033`*^9}, {
   3.521172177393194*^9, 3.521172178191263*^9}, {3.5211725655334063`*^9, 
   3.521172595583372*^9}, {3.5211727773413687`*^9, 3.521172778664266*^9}, {
   3.521172933390122*^9, 3.52117293362492*^9}, {3.521172976294199*^9, 
   3.5211729764406757`*^9}, {3.5211730618405647`*^9, 3.521173062012541*^9}, {
   3.521866279875*^9, 3.5218663398125*^9}, {3.52186649834375*^9, 
   3.521866498453125*^9}, {3.52186668421875*^9, 3.5218667244375*^9}, {
   3.521866791765625*^9, 3.521866791984375*^9}, {3.52186706984375*^9, 
   3.5218670704375*^9}, {3.52186712225*^9, 3.521867122390625*^9}, {
   3.521867190015625*^9, 3.52186719025*^9}, 3.52186730096875*^9, {
   3.5218673504375*^9, 3.52186735059375*^9}, {3.521868816484375*^9, 
   3.5218688576875*^9}, {3.52186894678125*^9, 3.521868984140625*^9}, 
   3.521869117625*^9, {3.521869236265625*^9, 3.521869256515625*^9}, {
   3.52187152540625*^9, 3.5218715259375*^9}, {3.521871609171875*^9, 
   3.52187160934375*^9}, {3.521871697359375*^9, 3.521871697453125*^9}, {
   3.521871753765625*^9, 3.52187175396875*^9}, {3.52187181075*^9, 
   3.521871811171875*^9}, {3.521871872859375*^9, 3.521871873203125*^9}, {
   3.521871933828125*^9, 3.52187193421875*^9}, {3.52187200490625*^9, 
   3.5218720051875*^9}, 3.52187304071875*^9, {3.52187563278125*^9, 
   3.521875633109375*^9}, {3.5218756810625*^9, 3.521875681359375*^9}, {
   3.52187574075*^9, 3.52187574109375*^9}, {3.521875783625*^9, 
   3.5218757838125*^9}, {3.521875839015625*^9, 3.521875839171875*^9}, {
   3.52187590225*^9, 3.5218759024375*^9}, 3.521875956296875*^9, {
   3.521878034921875*^9, 3.521878048078125*^9}, {3.521878146*^9, 
   3.521878146390625*^9}, {3.52187818909375*^9, 3.521878189390625*^9}, {
   3.521878260546875*^9, 3.52187826090625*^9}, {3.521878340375*^9, 
   3.52187834059375*^9}, {3.5218783833125*^9, 3.5218783835*^9}, {
   3.521878494703125*^9, 3.52187849484375*^9}, 3.52187854415625*^9, {
   3.5218790058125*^9, 3.52187900903125*^9}, {3.52187907875*^9, 
   3.521879079078125*^9}, {3.52187913625*^9, 3.521879136546875*^9}, {
   3.521879191484375*^9, 3.5218791918125*^9}, {3.52187924665625*^9, 
   3.521879246796875*^9}, {3.521879288703125*^9, 3.52187928890625*^9}, {
   3.52187934496875*^9, 3.521879345140625*^9}, 3.521879385984375*^9, {
   3.5230101386875*^9, 3.52301014559375*^9}, {3.523010175625*^9, 
   3.52301020240625*^9}, 3.52301026840625*^9, {3.523010428453125*^9, 
   3.52301043096875*^9}, {3.523010532109375*^9, 3.523010533875*^9}, {
   3.523010572125*^9, 3.523010602328125*^9}, 3.523010645671875*^9, {
   3.523010680484375*^9, 3.523010704234375*^9}, 3.523010741359375*^9, {
   3.523010773671875*^9, 3.523010773828125*^9}, 3.523010809640625*^9, {
   3.5230108795*^9, 3.523010884265625*^9}, {3.523010925625*^9, 
   3.523010926109375*^9}, {3.523010958203125*^9, 3.5230109844375*^9}, 
   3.523011042328125*^9, {3.525087520375*^9, 3.525087520609375*^9}, {
   3.525144243796875*^9, 3.525144247296875*^9}, {3.525144656890625*^9, 
   3.52514466121875*^9}, {3.526977427890625*^9, 3.526977428046875*^9}, {
   3.5269775045*^9, 3.526977512296875*^9}, {3.526977592515625*^9, 
   3.52697759271875*^9}, {3.526978779140625*^9, 3.526978779328125*^9}, {
   3.52697927959375*^9, 3.526979280125*^9}, {3.526979748453125*^9, 
   3.52697974921875*^9}, {3.52698399753125*^9, 3.526983998203125*^9}, {
   3.527321586390625*^9, 3.52732160171875*^9}, 3.527321644578125*^9, {
   3.52732169728125*^9, 3.52732171984375*^9}, {3.5273217529375*^9, 
   3.527321840328125*^9}, 3.527321875234375*^9, {3.527321945640625*^9, 
   3.52732195265625*^9}, {3.52732199603125*^9, 3.527322000671875*^9}, {
   3.527322050140625*^9, 3.5273220503125*^9}, {3.527325161328125*^9, 
   3.527325170234375*^9}, {3.52733124984375*^9, 3.5273312580625*^9}, 
   3.531550610921875*^9, 3.531550721578125*^9, {3.531550786484375*^9, 
   3.531550786609375*^9}, {3.5315508281875*^9, 3.53155082871875*^9}, {
   3.53155088459375*^9, 3.53155088478125*^9}, {3.53155092496875*^9, 
   3.531550925140625*^9}, {3.53155100840625*^9, 3.53155100859375*^9}, {
   3.531551080265625*^9, 3.531551080796875*^9}, {3.531551118515625*^9, 
   3.531551118734375*^9}, {3.531551155359375*^9, 3.531551184859375*^9}, {
   3.53155121578125*^9, 3.531551216*^9}, {3.531551257546875*^9, 
   3.531551257671875*^9}, {3.53155130265625*^9, 3.531551302765625*^9}, {
   3.53155137053125*^9, 3.531551370640625*^9}, {3.531551415015625*^9, 
   3.53155141528125*^9}, {3.53155145190625*^9, 3.53155147203125*^9}, {
   3.53155150878125*^9, 3.53155150909375*^9}, {3.531551657484375*^9, 
   3.5315517006875*^9}, {3.531551734375*^9, 3.53155175746875*^9}, {
   3.53155180034375*^9, 3.5315518004375*^9}, {3.531551831109375*^9, 
   3.53155183121875*^9}, {3.531551864640625*^9, 3.531551864953125*^9}, {
   3.5315519135625*^9, 3.531551913953125*^9}, {3.53155195571875*^9, 
   3.531551956125*^9}, {3.531552015125*^9, 3.53155201540625*^9}, {
   3.531552047578125*^9, 3.53155205515625*^9}, {3.5315520886875*^9, 
   3.531552089078125*^9}, {3.53155212615625*^9, 3.53155214940625*^9}, {
   3.53155225090625*^9, 3.531552256078125*^9}, {3.531552291703125*^9, 
   3.531552291859375*^9}, {3.531552332640625*^9, 3.531552332828125*^9}, {
   3.531552364421875*^9, 3.531552364609375*^9}, {3.531552406078125*^9, 
   3.53155240671875*^9}, {3.5315524499375*^9, 3.531552490015625*^9}, {
   3.531552559453125*^9, 3.531552562828125*^9}, {3.53155261534375*^9, 
   3.53155263571875*^9}, {3.53155269465625*^9, 3.531552694875*^9}, {
   3.531552755671875*^9, 3.5315527560625*^9}, {3.53155279934375*^9, 
   3.5315528231875*^9}, {3.53155287384375*^9, 3.53155289825*^9}, {
   3.531552978828125*^9, 3.53155298034375*^9}, {3.531554077859375*^9, 
   3.531554078140625*^9}, 3.537273043859375*^9, 3.543203510109375*^9, 
   3.54320394403125*^9, {3.546245249875*^9, 3.54624525059375*^9}, {
   3.546322002109375*^9, 3.5463220045625*^9}, {3.546322127078125*^9, 
   3.546322147015625*^9}, {3.546322222453125*^9, 3.546322222546875*^9}, {
   3.546322538171875*^9, 3.5463225383125*^9}, {3.546677326484375*^9, 
   3.546677331703125*^9}, {3.546677431078125*^9, 3.546677449234375*^9}, {
   3.54667814609375*^9, 3.546678154359375*^9}, {3.54667831484375*^9, 
   3.546678315*^9}, {3.5466784059375*^9, 3.5466784061875*^9}, {
   3.54667857815625*^9, 3.54667858178125*^9}, {3.546679115546875*^9, 
   3.54667912625*^9}, {3.552653048207703*^9, 3.552653048722538*^9}, {
   3.552653087266768*^9, 3.552653087438129*^9}, 3.552796496302702*^9, 
   3.7326155728018856`*^9, 3.7351935015238204`*^9, {3.7352808321543293`*^9, 
   3.7352809078565025`*^9}, {3.735280970835636*^9, 3.735281010725717*^9}, {
   3.7352810452937903`*^9, 3.7352810860588703`*^9}, {3.7352811504830217`*^9, 
   3.735281153346031*^9}, {3.735281222749199*^9, 3.735281232299222*^9}, {
   3.7352813325105*^9, 3.7352813675505753`*^9}, {3.7352814584327593`*^9, 
   3.735281499161838*^9}, {3.7352815646399827`*^9, 3.73528171107137*^9}, {
   3.7352820046171465`*^9, 3.7352820151421824`*^9}, {3.73528467649341*^9, 
   3.7352846766964216`*^9}, {3.7370455976452875`*^9, 
   3.7370456284502687`*^9}, {3.737045749708659*^9, 3.737045760125321*^9}, {
   3.7463585587587357`*^9, 3.7463585653231115`*^9}, {3.7475657868702464`*^9, 
   3.7475657871510468`*^9}, {3.7483300616641235`*^9, 
   3.7483300831463523`*^9}, {3.7483301199134555`*^9, 
   3.7483301629049144`*^9}, {3.7485896050931387`*^9, 3.748589827459857*^9}, {
   3.748589877417714*^9, 3.7485899597474236`*^9}, {3.7485900453663206`*^9, 
   3.7485901844192743`*^9}, {3.7485902343441296`*^9, 
   3.7485902354431925`*^9}, {3.748593307194886*^9, 3.7485933481972313`*^9}, {
   3.7485933878545*^9, 3.7485933900756273`*^9}, {3.7485934356462336`*^9, 
   3.7485935556981*^9}, {3.74859360517693*^9, 3.748593612528351*^9}, {
   3.7485937993540363`*^9, 3.7485938177120867`*^9}, {3.7486041099967713`*^9, 
   3.7486041533752527`*^9}, {3.748604300959694*^9, 3.748604324761055*^9}, {
   3.7486043582719717`*^9, 3.7486044052346582`*^9}, {3.7486044994090443`*^9, 
   3.7486045121657743`*^9}, {3.748604544097601*^9, 3.748604684010603*^9}, 
   3.748604735782564*^9, {3.7486047928398275`*^9, 3.74860486788412*^9}, {
   3.7486049638576097`*^9, 3.748605142237812*^9}, {3.748605205030404*^9, 
   3.748605255110268*^9}, {3.7486052864290595`*^9, 3.7486053745941024`*^9}, {
   3.7486054244269524`*^9, 3.7486054261810527`*^9}, 3.7486054572278285`*^9, {
   3.7486054941179385`*^9, 3.748605547066967*^9}, {3.748605747386425*^9, 
   3.7486059510640745`*^9}, {3.748605990694341*^9, 3.748606044997447*^9}, {
   3.7486060752291765`*^9, 3.7486061197277217`*^9}, {3.748606170900648*^9, 
   3.7486062607237864`*^9}, {3.748606315032892*^9, 3.7486065077859173`*^9}, {
   3.748606617484192*^9, 3.748606647743922*^9}, {3.7486618645241413`*^9, 
   3.748662041229248*^9}, 3.7486756531718073`*^9, 3.748675683927566*^9, 
   3.7486757792320175`*^9, {3.7486758099277725`*^9, 3.748675945012499*^9}, {
   3.748678265238209*^9, 3.748678507367058*^9}, {3.748678544837201*^9, 
   3.7486785462502813`*^9}, {3.7486790669210625`*^9, 3.748679067523097*^9}, {
   3.748679703600478*^9, 3.7486798588023553`*^9}, {3.7486799894248266`*^9, 
   3.7486800061617837`*^9}, {3.748680995575375*^9, 3.7486810098191895`*^9}, {
   3.7486810853175077`*^9, 3.748681095902113*^9}, {3.748681158732707*^9, 
   3.7486811606088142`*^9}, {3.74868123693718*^9, 3.7486813340547347`*^9}, {
   3.7486815267897587`*^9, 3.7486815292358985`*^9}, {3.748681572731386*^9, 
   3.74868174588029*^9}, {3.748681851043305*^9, 3.748681870944443*^9}, 
   3.748681912770836*^9, {3.748682127112095*^9, 3.7486822048485413`*^9}, {
   3.7486822834130354`*^9, 3.7486822912704844`*^9}, 3.74868267460841*^9, {
   3.748683916071418*^9, 3.748683951111422*^9}, {3.748684032286065*^9, 
   3.7486840998709307`*^9}, {3.7486854854891834`*^9, 3.748685505464326*^9}, {
   3.7486855706880565`*^9, 3.7486856123354387`*^9}, {3.748685661099228*^9, 
   3.7486857127271805`*^9}, {3.7486857726346073`*^9, 
   3.7486857796340075`*^9}, {3.7486858260976653`*^9, 3.748685850451058*^9}, {
   3.7486859182799377`*^9, 3.74868592916156*^9}, {3.748686076566991*^9, 
   3.7486860969551573`*^9}, {3.7486868205385437`*^9, 
   3.7486868306871243`*^9}, {3.748686989161188*^9, 3.748686992373372*^9}, 
   3.748688516686558*^9, {3.74868854854138*^9, 3.7486886024504633`*^9}, {
   3.7486886341862783`*^9, 3.7486886468600035`*^9}, {3.7486887038002605`*^9, 
   3.748688728001644*^9}, {3.748835320798273*^9, 3.7488353339940276`*^9}, {
   3.748835480286395*^9, 3.7488356264917574`*^9}, {3.7488358790842047`*^9, 
   3.748835989197503*^9}, {3.7488360449556923`*^9, 3.74883622237484*^9}, {
   3.7488391989170885`*^9, 3.748839201309225*^9}, {3.7488392456787634`*^9, 
   3.748839304128106*^9}, {3.7488404229020967`*^9, 3.7488404809194145`*^9}, {
   3.748840530462249*^9, 3.748840574342758*^9}, {3.7488409373685226`*^9, 
   3.748841032046938*^9}, {3.748853572001182*^9, 3.7488535738442874`*^9}, {
   3.7488536104913836`*^9, 3.748853697346351*^9}, {3.7488537494493313`*^9, 
   3.748853765700261*^9}, {3.748853904416195*^9, 3.74885390817741*^9}, {
   3.74892537293089*^9, 3.748925381883505*^9}, {3.748925432983711*^9, 
   3.748925448053899*^9}, {3.748930540536174*^9, 3.7489305532419004`*^9}, {
   3.7489306390998116`*^9, 3.748930669698561*^9}, {3.74893076513902*^9, 
   3.7489308230723333`*^9}, {3.748930915778636*^9, 3.7489309303784714`*^9}, {
   3.748930989522854*^9, 3.748930993016054*^9}, {3.748931068075347*^9, 
   3.748931097811048*^9}, {3.7489311652029023`*^9, 3.7489311662479625`*^9}, 
   3.7498114954786015`*^9, {3.749811549059058*^9, 3.7498115746377883`*^9}, {
   3.749811631835684*^9, 3.7498116338210945`*^9}, {3.7498116739278946`*^9, 
   3.7498116943267994`*^9}, {3.7498117398140182`*^9, 
   3.7498117495314646`*^9}, {3.749811847674967*^9, 3.749811857773017*^9}, 
   3.749811970164771*^9, {3.749812050171773*^9, 3.7498120595916204`*^9}, {
   3.74981250271124*^9, 3.7498125405018263`*^9}, 3.7498125866848516`*^9, {
   3.7498126169612036`*^9, 3.7498126268352537`*^9}, {3.749812665634449*^9, 
   3.749812666382453*^9}, {3.751953276551998*^9, 3.7519532773007994`*^9}, {
   3.751953326832512*^9, 3.751953378782422*^9}, {3.7519534091130867`*^9, 
   3.7519534348145523`*^9}, 3.7519534708126307`*^9, {3.75195352220954*^9, 
   3.7519535607942314`*^9}, {3.7519536189957743`*^9, 
   3.7519536793217134`*^9}, {3.7519537516806755`*^9, 3.751953786489152*^9}, {
   3.7519538252616386`*^9, 3.7519538360972605`*^9}, {3.751953887498782*^9, 
   3.7519539606411467`*^9}, {3.7519539928450174`*^9, 
   3.7519540276538944`*^9}, {3.751954175842219*^9, 3.751954200876073*^9}, 
   3.751954288259676*^9, {3.7519544839147243`*^9, 3.7519544850439267`*^9}, {
   3.7519548835468426`*^9, 3.7519549117179103`*^9}, 3.75195525911871*^9, 
   3.7519553855005884`*^9, {3.7519574254321365`*^9, 3.7519574361387606`*^9}, {
   3.751957844696707*^9, 3.7519578496921167`*^9}, {3.7519611071986456`*^9, 
   3.7519611106396523`*^9}, {3.7519611697791753`*^9, 3.751961182475623*^9}, 
   3.751969613402439*^9, {3.7519739120771217`*^9, 3.751973918878337*^9}, {
   3.751974573990423*^9, 3.751974599220483*^9}, {3.7519746503796024`*^9, 
   3.7519746693042417`*^9}, {3.751974790528313*^9, 3.7519748779793124`*^9}, {
   3.7519754564047613`*^9, 3.751975470560392*^9}, {3.751976093940816*^9, 
   3.7519761080622463`*^9}, 3.7519763256211424`*^9, {3.752304748752944*^9, 
   3.7523047590555334`*^9}, 3.752319173351431*^9, 3.752319219114584*^9, {
   3.752842695008597*^9, 3.7528426982707834`*^9}, {3.752842735731926*^9, 
   3.7528427436223774`*^9}, {3.7528428231159244`*^9, 3.752842840801936*^9}, {
   3.752842918217364*^9, 3.752842923696677*^9}, {3.753437817521174*^9, 
   3.753437908923153*^9}, {3.753438081192695*^9, 3.753438097242326*^9}, {
   3.753438174362473*^9, 3.7534381936881094`*^9}, {3.753438239954997*^9, 
   3.7534382404541984`*^9}, {3.7534382712952585`*^9, 
   3.7534383274875703`*^9}, {3.7534383592532306`*^9, 3.753438407375923*^9}, {
   3.753438593797681*^9, 3.753438596845687*^9}, 3.753438643441982*^9, 
   3.753438676202643*^9, {3.753591005478794*^9, 3.7535910364357576`*^9}, {
   3.7535911506655693`*^9, 3.7535913739369965`*^9}, {3.753591475063134*^9, 
   3.753591608575632*^9}, {3.7540357118957415`*^9, 3.7540357121457415`*^9}, {
   3.754036075830985*^9, 3.7540360826570244`*^9}, {3.7540361319143505`*^9, 
   3.7540361321243515`*^9}, {3.754036510940915*^9, 3.75403651538795*^9}, {
   3.75403657215444*^9, 3.754036572589445*^9}, {3.754036610316752*^9, 
   3.7540366370769567`*^9}, {3.754039755780181*^9, 3.7540397601552134`*^9}, {
   3.7540398315467625`*^9, 3.7540398626089907`*^9}, {3.754039916867425*^9, 
   3.754039930055519*^9}, {3.754040019157198*^9, 3.7540400411563683`*^9}, {
   3.754040081851718*^9, 3.7540400924207945`*^9}, {3.754040136252135*^9, 
   3.754040139548162*^9}, {3.7540401995126305`*^9, 3.7540402043556623`*^9}, {
   3.754048309792762*^9, 3.7540483395891857`*^9}, {3.7540498861624937`*^9, 
   3.754049925902362*^9}, {3.754049989394498*^9, 3.7540500183757267`*^9}, 
   3.7540501287499804`*^9, {3.754051551839069*^9, 3.7540515532471495`*^9}, {
   3.754051643788508*^9, 3.7540516450375595`*^9}, {3.754051748121381*^9, 
   3.7540517994307775`*^9}, {3.754052023424331*^9, 3.754052078262906*^9}, {
   3.754052221384384*^9, 3.754052225101595*^9}, {3.754052308449371*^9, 
   3.7540523090473957`*^9}, {3.754052452555103*^9, 3.7540524614525247`*^9}, {
   3.7540525051536245`*^9, 3.7540525198233395`*^9}, {3.7567213371897726`*^9, 
   3.7567213960224905`*^9}, {3.7567214583312387`*^9, 3.756721476042395*^9}, {
   3.756722021574581*^9, 3.756722077806672*^9}, {3.7567221437352343`*^9, 
   3.756722214184882*^9}, {3.756722484884323*^9, 3.756722624051779*^9}, {
   3.7567227272534885`*^9, 3.7567227685624485`*^9}, {3.7567228296731796`*^9, 
   3.7567228344378223`*^9}, {3.7567228903983116`*^9, 
   3.7567229230213966`*^9}, {3.7567229787902975`*^9, 
   3.7567230194802713`*^9}, {3.7567230786958046`*^9, 
   3.7567231590601254`*^9}, {3.7567232851120653`*^9, 3.756723355163087*^9}, {
   3.756723390966793*^9, 3.756723394910221*^9}, {3.756723431626147*^9, 
   3.7567234322811537`*^9}, {3.7567297662842307`*^9, 
   3.7567297733110886`*^9}, {3.756730152219279*^9, 3.7567301536424932`*^9}, 
   3.7567303121280985`*^9, 3.7567303567499065`*^9, 3.756730526109249*^9, 
   3.756730741871746*^9, 3.756730824339088*^9, 3.7567320780556955`*^9, {
   3.7567326395204787`*^9, 3.7567326440455613`*^9}, {3.7567331033856535`*^9, 
   3.756733104022457*^9}, {3.7567903554949813`*^9, 3.7567904494505515`*^9}, {
   3.7567907503106127`*^9, 3.756790821766197*^9}, {3.756790884713921*^9, 
   3.7567909028446665`*^9}, 3.7567910794870996`*^9, {3.75679114755765*^9, 
   3.756791148188057*^9}, 3.7567911857107615`*^9, 3.75679121982985*^9, {
   3.7567913232206955`*^9, 3.7567914190536785`*^9}, 3.7570672241784625`*^9, 
   3.757067451706476*^9, {3.7572312722274323`*^9, 3.7572312776437426`*^9}, 
   3.757231325833499*^9, {3.757231364240695*^9, 3.7572313657317805`*^9}, {
   3.7572314133305035`*^9, 3.7572314951211815`*^9}, {3.7572317425173316`*^9, 
   3.757231743051362*^9}, {3.7572318210448227`*^9, 3.7572318217858653`*^9}, {
   3.7572336721467*^9, 3.7572337027684517`*^9}, 3.7572368707346487`*^9, {
   3.7572369133130836`*^9, 3.7572369705783596`*^9}, {3.7572370744332995`*^9, 
   3.7572370904272146`*^9}, 3.757237207341902*^9, {3.7572372417008667`*^9, 
   3.757237456024125*^9}, 3.7572375045389004`*^9, {3.757237572391781*^9, 
   3.757237583456414*^9}, {3.757237621779606*^9, 3.757237732432935*^9}, {
   3.757237829773503*^9, 3.7572378517267585`*^9}, {3.7572379163534546`*^9, 
   3.7572379435200086`*^9}, {3.7572381025011015`*^9, 
   3.7572382739079056`*^9}, {3.7572383400276875`*^9, 
   3.7572384077635617`*^9}, {3.7572384600455523`*^9, 
   3.7572384634787483`*^9}, {3.757238545368432*^9, 3.75723864778229*^9}, 
   3.75723877279644*^9, {3.7572389240936418`*^9, 3.757238951360977*^9}, 
   3.757243907289536*^9, {3.7572442840425825`*^9, 3.757244326177992*^9}, {
   3.757244380142079*^9, 3.7572443813131456`*^9}, {3.7572444667680335`*^9, 
   3.7572444675210767`*^9}, {3.7572445066953173`*^9, 3.757244520173088*^9}, {
   3.7572445559811363`*^9, 3.757244556832185*^9}, {3.7572446392939014`*^9, 
   3.7572446923579364`*^9}, {3.757244787900401*^9, 3.757244788151416*^9}, 
   3.757244836693192*^9, 3.7573180458124495`*^9, 3.7573203784337893`*^9, {
   3.7573227217708483`*^9, 3.757322746913192*^9}, 3.757322802727314*^9, {
   3.757322859513445*^9, 3.757322890153817*^9}, {3.7573229730170994`*^9, 
   3.7573229736101027`*^9}, {3.75732301201672*^9, 3.757323014439733*^9}, 
   3.7573230954911957`*^9, {3.7573231817598963`*^9, 3.7573231840247107`*^9}, {
   3.757323230453966*^9, 3.7573232955821543`*^9}, {3.7573233743033943`*^9, 
   3.757323376602607*^9}, {3.757323446855997*^9, 3.757323448367402*^9}, 
   3.7573236390607*^9, {3.757325331305261*^9, 3.7573253422285223`*^9}, {
   3.7574050062595005`*^9, 3.7574050127995753`*^9}, {3.757405050330985*^9, 
   3.757405078117279*^9}, {3.7574051906425037`*^9, 3.757405191903515*^9}, {
   3.757405225048874*^9, 3.7574052295489273`*^9}, {3.757405678046651*^9, 
   3.757405705793268*^9}, {3.757405932037224*^9, 3.757405981899417*^9}, {
   3.757406031666803*^9, 3.757406130138583*^9}, {3.757406162640239*^9, 
   3.757406196519503*^9}, {3.7574062607877936`*^9, 3.7574063332899675`*^9}, {
   3.7574063674612403`*^9, 3.757406380885545*^9}, {3.757406433673551*^9, 
   3.7574064660637994`*^9}, 3.7574065856154723`*^9, {3.757410582100648*^9, 
   3.7574106850293636`*^9}, {3.7574110074056087`*^9, 3.7574110197771072`*^9}, 
   3.7574110543277674`*^9, 3.7574110992247076`*^9, 3.757411354652625*^9, {
   3.7574114794237504`*^9, 3.7574114798779573`*^9}, 3.757414623578413*^9, 
   3.7574202174693375`*^9, 3.757420247890383*^9, {3.7574202786594305`*^9, 
   3.7574203069722652`*^9}, {3.7574203520840282`*^9, 3.757420399477016*^9}, {
   3.757751284654821*^9, 3.75775128533886*^9}, {3.75775143832061*^9, 
   3.7577514524294167`*^9}, {3.7578405241960306`*^9, 3.7578405958771305`*^9}, 
   3.7578406334182777`*^9, 3.7578410767236333`*^9, {3.7578411405092816`*^9, 
   3.7578411424843946`*^9}, {3.7582712765086536`*^9, 3.7582712799368496`*^9}, 
   3.7582713353480186`*^9, 3.758271373737215*^9, {3.7582715280430403`*^9, 
   3.7582715310402117`*^9}, 3.7582764326795692`*^9, {3.758276466575508*^9, 
   3.7582764991453714`*^9}, {3.7582765301351438`*^9, 
   3.7582765376285725`*^9}, {3.7584485951843133`*^9, 
   3.7584486149334483`*^9}, {3.7584487043488197`*^9, 
   3.7584487230681324`*^9}, {3.7584489147024317`*^9, 
   3.7584489158752356`*^9}, {3.758458511082653*^9, 3.7584585707776003`*^9}, {
   3.758458628761385*^9, 3.758458634706202*^9}, {3.7584587839357843`*^9, 
   3.758458816650469*^9}, {3.758458878696433*^9, 3.7584589077125063`*^9}, {
   3.7584590815312366`*^9, 3.758459135105373*^9}, {3.758459172922473*^9, 
   3.758459182388302*^9}, {3.7584592476494756`*^9, 3.758459253773691*^9}, {
   3.7584593557809563`*^9, 3.75845943357337*^9}, 3.7584597797030935`*^9, 
   3.758518952206587*^9, 3.7585189855252805`*^9, {3.7585218912964454`*^9, 
   3.7585219084453325`*^9}, {3.75852194849244*^9, 3.75852196038833*^9}, {
   3.75853036738608*^9, 3.7585305001712656`*^9}, {3.7585305916854305`*^9, 
   3.758530591997431*^9}, {3.758531372762107*^9, 3.7585313995195255`*^9}, {
   3.758532445972551*^9, 3.758532479892305*^9}, {3.7585325118498044`*^9, 
   3.758532514855243*^9}, {3.7586212284162135`*^9, 3.758621229291617*^9}, 
   3.758621312124099*^9, {3.7586214012195973`*^9, 3.758621466633028*^9}, {
   3.75862154913253*^9, 3.758621568992201*^9}, {3.759133327618171*^9, 
   3.759133356991851*^9}, {3.7591333876616054`*^9, 3.759133388003625*^9}, 
   3.7591334291369777`*^9, {3.759133494249702*^9, 3.759133494431712*^9}, {
   3.759142141076272*^9, 3.759142175150221*^9}, {3.759142211378293*^9, 
   3.7591422423980675`*^9}, 3.759144481997165*^9, 3.760784170455598*^9, 
   3.760784257857995*^9, {3.7607842879550643`*^9, 3.7607843835240827`*^9}, {
   3.760785149234686*^9, 3.76078517746758*^9}, {3.779086886625803*^9, 
   3.7790869013636465`*^9}, {3.779086987586578*^9, 3.7790870428217373`*^9}, 
   3.779087118118044*^9, {3.779093692409072*^9, 3.7790937001885166`*^9}, {
   3.7790945932385964`*^9, 3.7790945977138524`*^9}, 3.788862246400072*^9, {
   3.788862790936121*^9, 3.7888627939143963`*^9}, {3.7889737177507477`*^9, 
   3.7889737185073137`*^9}, {3.8134682994048605`*^9, 3.813468453627655*^9}, {
   3.8134688734615307`*^9, 3.8134689181251564`*^9}, {3.813470908620163*^9, 
   3.813470911291023*^9}, {3.8134713068767085`*^9, 3.813471377293535*^9}, {
   3.8134715048356075`*^9, 3.8134715612119536`*^9}, {3.8134716702245893`*^9, 
   3.8134716713186364`*^9}, {3.8134770314059477`*^9, 
   3.8134770315934253`*^9}, {3.813477115684685*^9, 3.813477143620991*^9}, {
   3.8134779407941866`*^9, 3.813477962150106*^9}, {3.813478010989571*^9, 
   3.813478051637925*^9}, {3.813480519441016*^9, 3.813480524334973*^9}, 
   3.8134806144121795`*^9, {3.8134807541516857`*^9, 3.813480754346202*^9}, {
   3.8134857334120855`*^9, 3.813485756844454*^9}, {3.813489051245248*^9, 
   3.813489055347277*^9}, {3.81348931549094*^9, 3.8134893159716883`*^9}, 
   3.813489492351261*^9, 3.8134895818321037`*^9, {3.813514914747302*^9, 
   3.813514918396538*^9}, {3.813514956154592*^9, 3.813514985261825*^9}, {
   3.8135150534495726`*^9, 3.813515074701742*^9}, 3.8135151191639414`*^9, 
   3.813515158443947*^9, {3.813519333598151*^9, 3.8135194353302774`*^9}, 
   3.8135194751936984`*^9, 3.8135195322013397`*^9, 3.8135195631157503`*^9, {
   3.8135195995942097`*^9, 3.813519601186957*^9}, {3.8135196724046326`*^9, 
   3.8135197084742002`*^9}, {3.8135197456777954`*^9, 3.813519771286316*^9}, {
   3.8135198233411884`*^9, 3.8135198755855503`*^9}, 3.8171149256929936`*^9, {
   3.81711497457753*^9, 3.8171150036318254`*^9}, 3.817115056564254*^9, 
   3.8171151177775373`*^9, {3.819205957301816*^9, 3.819205957999953*^9}, 
   3.819206042315423*^9, 3.8192060891413164`*^9, {3.819206137244731*^9, 
   3.8192061989558396`*^9}, {3.8192265572474756`*^9, 3.819226557491847*^9}, {
   3.8192275904935503`*^9, 3.819227593887509*^9}, 3.819227661558629*^9, 
   3.819227747334175*^9, {3.8192278200378695`*^9, 3.8192278442591066`*^9}, 
   3.8192281533441076`*^9, {3.832311409155529*^9, 3.8323115352271757`*^9}, {
   3.8323115873432384`*^9, 
   3.832311618480345*^9}},ExpressionUUID->"bb39335b-4973-40e2-8a87-\
741dcdc582c9"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"TableForm", "[", "Odes", "]"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"TableForm", "[", "RateEqs", "]"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"TableForm", "[", 
   RowBox[{
    RowBox[{
     RowBox[{"Odes", "/.", "RateEqs"}], "/.", "CoAMATX"}], "/.", "Parm"}], 
   " ", "]"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"TableForm", "[", 
   RowBox[{"RateEqs", "/.", "Parm"}], " ", "]"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"TableForm", "[", "InitialConditions", "]"}], ";"}]}], "Input",
 CellChangeTimes->{{3.435336399795178*^9, 3.43533641247787*^9}, {
   3.435336518643903*^9, 3.4353365319207983`*^9}, {3.48033246359375*^9, 
   3.48033246871875*^9}, {3.48039422753125*^9, 3.480394227765625*^9}, {
   3.480396229359375*^9, 3.480396231390625*^9}, {3.480398695671875*^9, 
   3.480398699140625*^9}, {3.480398994484375*^9, 3.4803990056875*^9}, {
   3.480401260046875*^9, 3.480401273046875*^9}, {3.480831779671875*^9, 
   3.480831783125*^9}, {3.4808357340625*^9, 3.48083574534375*^9}, 
   3.480835969046875*^9, {3.48083627384375*^9, 3.480836277015625*^9}, {
   3.480998199671875*^9, 3.48099824115625*^9}, 3.481001610171875*^9, 
   3.48100328728125*^9, 3.481511154015625*^9, 3.481511932234375*^9, 
   3.483417014640625*^9, 3.483417122625*^9, {3.4838654465*^9, 
   3.4838654619375*^9}, {3.4838656718125*^9, 3.48386567359375*^9}, 
   3.483869203421875*^9, 3.48506539771875*^9, 3.485065838578125*^9, {
   3.494832939109375*^9, 3.49483294709375*^9}, {3.494836651078125*^9, 
   3.494836675953125*^9}, {3.4948367168125*^9, 3.494836719203125*^9}, {
   3.49483688540625*^9, 3.494836894515625*^9}, {3.4948369285625*^9, 
   3.494836932375*^9}, {3.494847695921875*^9, 3.494847724640625*^9}, {
   3.494905623578125*^9, 3.4949056270625*^9}, {3.494916289203125*^9, 
   3.494916312140625*^9}, {3.497778299359375*^9, 3.497778308421875*^9}, {
   3.4977783571875*^9, 3.497778360328125*^9}, {3.49777860078125*^9, 
   3.497778602109375*^9}, 3.497778762359375*^9, {3.7352817465964518`*^9, 
   3.7352817556234837`*^9}, {3.735281788159586*^9, 3.7352817912915926`*^9}, {
   3.7352820237232037`*^9, 3.7352820330042286`*^9}, 3.7486792769580755`*^9, {
   3.748681198608988*^9, 3.7486812005410986`*^9}},
 CellLabel->
  "In[409]:=",ExpressionUUID->"22429411-4fbc-4beb-a65d-a8e8f6400bbe"],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{"tsol", "=", 
    RowBox[{"NDSolve", "[", 
     RowBox[{
      RowBox[{"Join", "[", 
       RowBox[{
        RowBox[{
         RowBox[{
          RowBox[{"Odes", "/.", "RateEqs"}], "/.", "CoAMATX"}], "/.", 
         "Parm"}], " ", ",", "InitialConditions"}], "]"}], ",", "Vars", ",", 
      RowBox[{"{", 
       RowBox[{"t", ",", "0", ",", "1000000000"}], "}"}]}], "]"}]}], 
   ";"}]}]], "Input",
 CellChangeTimes->{{3.4804004046875*^9, 3.480400456921875*^9}, 
   3.480831767984375*^9, 3.480831801578125*^9, 3.480832835*^9, {
   3.480832958421875*^9, 3.48083295865625*^9}, {3.480839412578125*^9, 
   3.480839412828125*^9}, {3.48084034171875*^9, 3.4808403635625*^9}, {
   3.48093278165625*^9, 3.48093278334375*^9}, 3.481001731375*^9, 
   3.481012604734375*^9, 3.481014341421875*^9, 3.48101521896875*^9, {
   3.48151212553125*^9, 3.4815121256875*^9}, {3.481515289625*^9, 
   3.48151529265625*^9}, 3.4833442416875*^9, 3.483344526796875*^9, 
   3.483344556859375*^9, 3.483344606328125*^9, 3.48335114178125*^9, {
   3.48335147803125*^9, 3.483351479734375*^9}, 3.483351583328125*^9, {
   3.4838672103125*^9, 3.48386721046875*^9}, 3.483867341671875*^9, 
   3.483867408671875*^9, 3.48386827475*^9, 3.483868332953125*^9, 
   3.49491435640625*^9, 3.49491510525*^9, {3.49491744134375*^9, 
   3.494917441859375*^9}, {3.497778192546875*^9, 3.497778198203125*^9}, 
   3.497778338828125*^9, 3.49777859275*^9, {3.506414612453125*^9, 
   3.506414612734375*^9}, 3.5085792629375*^9, {3.508581426265625*^9, 
   3.508581426609375*^9}, {3.508581535328125*^9, 3.50858153596875*^9}, {
   3.508583535140625*^9, 3.508583535546875*^9}, {3.508585658171875*^9, 
   3.50858565859375*^9}, {3.50858584078125*^9, 3.508585842109375*^9}, {
   3.508740866671875*^9, 3.508740868515625*^9}, {3.513410998484375*^9, 
   3.513410999578125*^9}, {3.513411543375*^9, 3.513411544421875*^9}, {
   3.7352817959766035`*^9, 3.735281807193638*^9}, {3.7352820416682577`*^9, 
   3.735282066463318*^9}, 3.736761499478813*^9, {3.7486861264698453`*^9, 
   3.748686127409899*^9}, {3.819227624800896*^9, 3.819227626825454*^9}},
 CellLabel->
  "In[414]:=",ExpressionUUID->"88e9e9e0-bdd0-4f01-ba8c-a8d210f0ff5a"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Table", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{"Vars", "[", 
       RowBox[{"[", "i", "]"}], "]"}], "[", "t", "]"}], ",", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         RowBox[{"Vars", "[", 
          RowBox[{"[", "i", "]"}], "]"}], "[", "900000000", "]"}], "/.", 
        "tsol"}], ")"}], "[", 
      RowBox[{"[", "1", "]"}], "]"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"i", ",", "1", ",", 
     RowBox[{"Length", "[", "Vars", "]"}]}], "}"}]}], "]"}]], "Input",
 CellLabel->
  "In[415]:=",ExpressionUUID->"1d982bc7-c127-4a22-a28e-2f8658319885"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{"C16AcylCarCYT", "[", "t", "]"}], ",", "0.1662819734188629`"}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"C16AcylCarMAT", "[", "t", "]"}], ",", "0.34782983058893613`"}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"C16AcylCoAMAT", "[", "t", "]"}], ",", "0.8518609960541257`"}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"C16EnoylCoAMAT", "[", "t", "]"}], ",", 
     "0.046238413152177936`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"C16HydroxyacylCoAMAT", "[", "t", "]"}], ",", 
     "0.14472623316631694`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"C16KetoacylCoAMAT", "[", "t", "]"}], ",", 
     "0.0006566668433757953`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"C14AcylCarCYT", "[", "t", "]"}], ",", "0.03634123696963567`"}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"C14AcylCarMAT", "[", "t", "]"}], ",", "0.1726208756057694`"}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"C14AcylCoAMAT", "[", "t", "]"}], ",", "1.8894005339997606`"}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"C14EnoylCoAMAT", "[", "t", "]"}], ",", 
     "0.051585091257993744`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"C14HydroxyacylCoAMAT", "[", "t", "]"}], ",", 
     "0.1462276994889119`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"C14KetoacylCoAMAT", "[", "t", "]"}], ",", 
     "0.0006627917634259156`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"C12AcylCarCYT", "[", "t", "]"}], ",", "0.04902861363435726`"}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"C12AcylCarMAT", "[", "t", "]"}], ",", "0.232885914763197`"}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"C12AcylCoAMAT", "[", "t", "]"}], ",", "2.5490240978704706`"}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"C12EnoylCoAMAT", "[", "t", "]"}], ",", 
     "0.058639296829485626`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"C12HydroxyacylCoAMAT", "[", "t", "]"}], ",", 
     "0.17724860521638786`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"C12KetoacylCoAMAT", "[", "t", "]"}], ",", 
     "0.0008008359894900873`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"C10AcylCarCYT", "[", "t", "]"}], ",", "0.0852545016883814`"}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"C10AcylCarMAT", "[", "t", "]"}], ",", "0.40495888301981164`"}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"C10AcylCoAMAT", "[", "t", "]"}], ",", "4.432427579460189`"}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"C10EnoylCoAMAT", "[", "t", "]"}], ",", "0.06448933207132054`"}],
     "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"C10HydroxyacylCoAMAT", "[", "t", "]"}], ",", 
     "0.19623715762445312`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"C10KetoacylCoAMAT", "[", "t", "]"}], ",", 
     "0.0008839984425753052`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"C8AcylCarCYT", "[", "t", "]"}], ",", "0.08569578774425576`"}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"C8AcylCarMAT", "[", "t", "]"}], ",", "0.40705499178521487`"}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"C8AcylCoAMAT", "[", "t", "]"}], ",", "4.4553702797956865`"}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"C8EnoylCoAMAT", "[", "t", "]"}], ",", "0.13949397699216223`"}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"C8HydroxyacylCoAMAT", "[", "t", "]"}], ",", 
     "0.4309726592518413`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"C8KetoacylCoAMAT", "[", "t", "]"}], ",", 
     "0.0019404192579735079`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"C6AcylCarCYT", "[", "t", "]"}], ",", "0.22668194422359023`"}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"C6AcylCarMAT", "[", "t", "]"}], ",", "1.0767392350620537`"}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"C6AcylCoAMAT", "[", "t", "]"}], ",", "11.785316686441044`"}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"C6EnoylCoAMAT", "[", "t", "]"}], ",", "10.118167146898019`"}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"C6HydroxyacylCoAMAT", "[", "t", "]"}], ",", 
     "31.4843015404395`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"C6KetoacylCoAMAT", "[", "t", "]"}], ",", 
     "0.14174912240532608`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"C4AcylCarCYT", "[", "t", "]"}], ",", "0.3756876420403907`"}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"C4AcylCarMAT", "[", "t", "]"}], ",", "1.784516299691856`"}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"C4AcylCoAMAT", "[", "t", "]"}], ",", "19.53220337770306`"}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"C4EnoylCoAMAT", "[", "t", "]"}], ",", "38.05763491148834`"}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"C4HydroxyacylCoAMAT", "[", "t", "]"}], ",", 
     "118.87397142917999`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"C4AcetoacylCoAMAT", "[", "t", "]"}], ",", 
     "0.5353374791195428`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"AcetylCoAMAT", "[", "t", "]"}], ",", "70.00000000155703`"}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"FADHMAT", "[", "t", "]"}], ",", "0.4600000013624033`"}], "}"}], 
   ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"NADHMAT", "[", "t", "]"}], ",", "11.41071453933679`"}], "}"}]}],
   "}"}]], "Output",
 CellChangeTimes->{
  3.8192276338466864`*^9, 3.819227757993686*^9, {3.819227829353941*^9, 
   3.819227858180902*^9}, 3.8192281610893774`*^9, 3.8295858399214225`*^9},
 CellLabel->
  "Out[415]=",ExpressionUUID->"d39dba12-0f7e-4753-8ae8-2455e22b2995"]
}, Open  ]],

Cell[TextData[StyleBox["Steady state computation with varying palmitoyl-CoA \
(X) and acetate levels (Z)",
 FontSize->20,
 FontWeight->"Bold",
 FontColor->RGBColor[0.5, 0, 0.5]]], "Text",
 CellChangeTimes->{{3.788696573683874*^9, 3.788696581504981*^9}, {
  3.8192062913887815`*^9, 3.8192063472863913`*^9}, {3.819227202255724*^9, 
  3.819227207478731*^9}},ExpressionUUID->"06a5e6a9-cf9a-4bff-80a4-\
19a9af448635"],

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"ParmScan", "[", 
    RowBox[{"X_", ",", "Z_"}], "]"}], ":=", 
   RowBox[{"{", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"sfcpt1C16", "\[Rule]", "1"}], ",", 
     RowBox[{"Vcpt1", "\[Rule]", "0.012"}], ",", 
     RowBox[{"Kmcpt1C16AcylCoACYT", "\[Rule]", "13.8"}], ",", 
     RowBox[{"Kmcpt1CarCYT", "\[Rule]", "250"}], ",", 
     RowBox[{"Kmcpt1C16AcylCarCYT", "\[Rule]", "136"}], ",", 
     RowBox[{"Kmcpt1CoACYT", "\[Rule]", "40.7"}], ",", 
     RowBox[{"Kicpt1MalCoACYT", "\[Rule]", "9.1"}], ",", 
     RowBox[{"Keqcpt1", "\[Rule]", "0.45"}], ",", " ", 
     RowBox[{"ncpt1", "\[Rule]", "2.4799"}], ",", "\[IndentingNewLine]", 
     RowBox[{"Vfcact", "\[Rule]", "0.42"}], ",", 
     RowBox[{"Vrcact", "\[Rule]", "0.42"}], ",", 
     RowBox[{"KmcactC16AcylCarCYT", "\[Rule]", "15"}], ",", 
     RowBox[{"KmcactC14AcylCarCYT", "\[Rule]", "15"}], ",", 
     RowBox[{"KmcactC12AcylCarCYT", "\[Rule]", "15"}], ",", 
     RowBox[{"KmcactC10AcylCarCYT", "\[Rule]", "15"}], ",", 
     RowBox[{"KmcactC8AcylCarCYT", "\[Rule]", "15"}], ",", 
     RowBox[{"KmcactC6AcylCarCYT", "\[Rule]", "15"}], ",", 
     RowBox[{"KmcactC4AcylCarCYT", "\[Rule]", "15"}], ",", 
     RowBox[{"KmcactCarMAT", "\[Rule]", "130"}], ",", 
     RowBox[{"KmcactC16AcylCarMAT", "\[Rule]", "15"}], ",", 
     RowBox[{"KmcactC14AcylCarMAT", "\[Rule]", "15"}], ",", 
     RowBox[{"KmcactC12AcylCarMAT", "\[Rule]", "15"}], ",", 
     RowBox[{"KmcactC10AcylCarMAT", "\[Rule]", "15"}], ",", 
     RowBox[{"KmcactC8AcylCarMAT", "\[Rule]", "15"}], ",", 
     RowBox[{"KmcactC6AcylCarMAT", "\[Rule]", "15"}], ",", 
     RowBox[{"KmcactC4AcylCarMAT", "\[Rule]", "15"}], ",", 
     RowBox[{"KmcactCarCYT", "\[Rule]", "130"}], ",", 
     RowBox[{"KicactC16AcylCarCYT", "\[Rule]", "56"}], ",", 
     RowBox[{"KicactC14AcylCarCYT", "\[Rule]", "56"}], ",", 
     RowBox[{"KicactC12AcylCarCYT", "\[Rule]", "56"}], ",", 
     RowBox[{"KicactC10AcylCarCYT", "\[Rule]", "56"}], ",", 
     RowBox[{"KicactC8AcylCarCYT", "\[Rule]", "56"}], ",", 
     RowBox[{"KicactC6AcylCarCYT", "\[Rule]", "56"}], ",", 
     RowBox[{"KicactC4AcylCarCYT", "\[Rule]", "56"}], ",", 
     RowBox[{"KicactCarCYT", "\[Rule]", "200"}], ",", 
     RowBox[{"Keqcact", "\[Rule]", "1"}], ",", "\[IndentingNewLine]", 
     RowBox[{"sfcpt2C16", "\[Rule]", "0.85"}], ",", 
     RowBox[{"sfcpt2C14", "\[Rule]", "1"}], ",", 
     RowBox[{"sfcpt2C12", "\[Rule]", "0.95"}], ",", 
     RowBox[{"sfcpt2C10", "\[Rule]", "0.95"}], ",", 
     RowBox[{"sfcpt2C8", "\[Rule]", "0.35"}], ",", 
     RowBox[{"sfcpt2C6", "\[Rule]", "0.15"}], ",", 
     RowBox[{"sfcpt2C4", "\[Rule]", "0.01"}], ",", 
     RowBox[{"Vcpt2", "\[Rule]", "0.391"}], ",", 
     RowBox[{"Kmcpt2C16AcylCarMAT", "\[Rule]", "51"}], ",", 
     RowBox[{"Kmcpt2C14AcylCarMAT", "\[Rule]", "51"}], ",", 
     RowBox[{"Kmcpt2C12AcylCarMAT", "\[Rule]", "51"}], ",", 
     RowBox[{"Kmcpt2C10AcylCarMAT", "\[Rule]", "51"}], ",", 
     RowBox[{"Kmcpt2C8AcylCarMAT", "\[Rule]", "51"}], ",", 
     RowBox[{"Kmcpt2C6AcylCarMAT", "\[Rule]", "51"}], ",", 
     RowBox[{"Kmcpt2C4AcylCarMAT", "\[Rule]", "51"}], ",", 
     RowBox[{"Kmcpt2CoAMAT", "\[Rule]", "30"}], ",", 
     RowBox[{"Kmcpt2C16AcylCoAMAT", "\[Rule]", "38"}], ",", 
     RowBox[{"Kmcpt2C14AcylCoAMAT", "\[Rule]", "38"}], ",", 
     RowBox[{"Kmcpt2C12AcylCoAMAT", "\[Rule]", "38"}], ",", 
     RowBox[{"Kmcpt2C10AcylCoAMAT", "\[Rule]", "38"}], ",", 
     RowBox[{"Kmcpt2C8AcylCoAMAT", "\[Rule]", "38"}], ",", 
     RowBox[{"Kmcpt2C6AcylCoAMAT", "\[Rule]", "1000"}], ",", 
     RowBox[{"Kmcpt2C4AcylCoAMAT", "\[Rule]", "1000000"}], ",", 
     RowBox[{"Kmcpt2CarMAT", "\[Rule]", "350"}], ",", 
     RowBox[{"Keqcpt2", "\[Rule]", "2.22"}], ",", "\[IndentingNewLine]", 
     RowBox[{"sfvlcadC16", "\[Rule]", "1"}], ",", 
     RowBox[{"sfvlcadC14", "\[Rule]", "0.42"}], ",", 
     RowBox[{"sfvlcadC12", "\[Rule]", "0.11"}], ",", 
     RowBox[{"Vvlcad", "\[Rule]", "0.008"}], ",", 
     RowBox[{"KmvlcadC16AcylCoAMAT", "\[Rule]", "6.5"}], ",", 
     RowBox[{"KmvlcadC14AcylCoAMAT", "\[Rule]", "4"}], ",", 
     RowBox[{"KmvlcadC12AcylCoAMAT", "\[Rule]", "2.7"}], ",", 
     RowBox[{"KmvlcadFAD", "\[Rule]", "0.12"}], ",", 
     RowBox[{"KmvlcadC16EnoylCoAMAT", "\[Rule]", "1.08"}], ",", 
     RowBox[{"KmvlcadC14EnoylCoAMAT", "\[Rule]", "1.08"}], ",", 
     RowBox[{"KmvlcadC12EnoylCoAMAT", "\[Rule]", "1.08"}], ",", 
     RowBox[{"KmvlcadFADH", "\[Rule]", "24.2"}], ",", 
     RowBox[{"Keqvlcad", "\[Rule]", "6"}], ",", "\[IndentingNewLine]", 
     RowBox[{"sflcadC16", "\[Rule]", "0.9"}], ",", 
     RowBox[{"sflcadC14", "\[Rule]", "1"}], ",", 
     RowBox[{"sflcadC12", "\[Rule]", "0.9"}], ",", 
     RowBox[{"sflcadC10", "\[Rule]", "0.75"}], ",", 
     RowBox[{"sflcadC8", "\[Rule]", "0.4"}], ",", 
     RowBox[{"Vlcad", "\[Rule]", "0.01"}], ",", 
     RowBox[{"KmlcadC16AcylCoAMAT", "\[Rule]", "2.5"}], ",", 
     RowBox[{"KmlcadC14AcylCoAMAT", "\[Rule]", "7.4"}], ",", 
     RowBox[{"KmlcadC12AcylCoAMAT", "\[Rule]", "9"}], ",", 
     RowBox[{"KmlcadC10AcylCoAMAT", "\[Rule]", "24.3"}], ",", 
     RowBox[{"KmlcadC8AcylCoAMAT", "\[Rule]", "123"}], ",", 
     RowBox[{"KmlcadFAD", "\[Rule]", "0.12"}], ",", 
     RowBox[{"KmlcadC16EnoylCoAMAT", "\[Rule]", "1.08"}], ",", 
     RowBox[{"KmlcadC14EnoylCoAMAT", "\[Rule]", "1.08"}], ",", 
     RowBox[{"KmlcadC12EnoylCoAMAT", "\[Rule]", "1.08"}], ",", 
     RowBox[{"KmlcadC10EnoylCoAMAT", "\[Rule]", "1.08"}], ",", 
     RowBox[{"KmlcadC8EnoylCoAMAT", "\[Rule]", "1.08"}], ",", 
     RowBox[{"KmlcadFADH", "\[Rule]", "24.2"}], ",", 
     RowBox[{"Keqlcad", "\[Rule]", "6"}], ",", "\[IndentingNewLine]", 
     RowBox[{"sfmcadC12", "\[Rule]", "0.38"}], ",", 
     RowBox[{"sfmcadC10", "\[Rule]", "0.8"}], ",", 
     RowBox[{"sfmcadC8", "\[Rule]", "0.87"}], ",", 
     RowBox[{"sfmcadC6", "\[Rule]", "1"}], ",", 
     RowBox[{"sfmcadC4", "\[Rule]", "0.12"}], ",", 
     RowBox[{"Vmcad", "\[Rule]", " ", "0.081"}], ",", 
     RowBox[{"KmmcadC12AcylCoAMAT", "\[Rule]", "5.7"}], ",", 
     RowBox[{"KmmcadC10AcylCoAMAT", "\[Rule]", "5.4"}], ",", 
     RowBox[{"KmmcadC8AcylCoAMAT", "\[Rule]", "4"}], ",", 
     RowBox[{"KmmcadC6AcylCoAMAT", "\[Rule]", "9.4"}], ",", 
     RowBox[{"KmmcadC4AcylCoAMAT", "\[Rule]", "135"}], ",", 
     RowBox[{"KmmcadFAD", "\[Rule]", "0.12"}], ",", 
     RowBox[{"KmmcadC12EnoylCoAMAT", "\[Rule]", "1.08"}], ",", 
     RowBox[{"KmmcadC10EnoylCoAMAT", "\[Rule]", "1.08"}], ",", 
     RowBox[{"KmmcadC8EnoylCoAMAT", "\[Rule]", "1.08"}], ",", 
     RowBox[{"KmmcadC6EnoylCoAMAT", "\[Rule]", "1.08"}], ",", 
     RowBox[{"KmmcadC4EnoylCoAMAT", "\[Rule]", "1.08"}], ",", 
     RowBox[{"KmmcadFADH", "\[Rule]", "24.2"}], ",", 
     RowBox[{"Keqmcad", "\[Rule]", "6"}], ",", "\[IndentingNewLine]", 
     RowBox[{"sfscadC6", "\[Rule]", "0.3"}], ",", 
     RowBox[{"sfscadC4", "\[Rule]", "1"}], ",", 
     RowBox[{"Vscad", "\[Rule]", "0.081"}], ",", 
     RowBox[{"KmscadC6AcylCoAMAT", "\[Rule]", "285"}], ",", 
     RowBox[{"KmscadC4AcylCoAMAT", "\[Rule]", "10.7"}], ",", 
     RowBox[{"KmscadFAD", "\[Rule]", "0.12"}], ",", 
     RowBox[{"KmscadC6EnoylCoAMAT", "\[Rule]", "1.08"}], ",", 
     RowBox[{"KmscadC4EnoylCoAMAT", "\[Rule]", "1.08"}], ",", 
     RowBox[{"KmscadFADH", "\[Rule]", "24.2"}], ",", 
     RowBox[{"Keqscad", "->", "6"}], ",", "\[IndentingNewLine]", 
     RowBox[{"sfcrotC16", "\[Rule]", "0.13"}], ",", 
     RowBox[{"sfcrotC14", "\[Rule]", "0.2"}], ",", 
     RowBox[{"sfcrotC12", "\[Rule]", "0.25"}], ",", 
     RowBox[{"sfcrotC10", "\[Rule]", "0.33"}], ",", 
     RowBox[{"sfcrotC8", "\[Rule]", "0.58"}], ",", 
     RowBox[{"sfcrotC6", "\[Rule]", "0.83"}], ",", 
     RowBox[{"sfcrotC4", "\[Rule]", "1"}], ",", 
     RowBox[{"Vcrot", "\[Rule]", "3.6"}], ",", 
     RowBox[{"KmcrotC16EnoylCoAMAT", "\[Rule]", "150"}], ",", 
     RowBox[{"KmcrotC14EnoylCoAMAT", "\[Rule]", "100"}], ",", 
     RowBox[{"KmcrotC12EnoylCoAMAT", "\[Rule]", "25"}], ",", 
     RowBox[{"KmcrotC10EnoylCoAMAT", "\[Rule]", "25"}], ",", 
     RowBox[{"KmcrotC8EnoylCoAMAT", "\[Rule]", "25"}], ",", 
     RowBox[{"KmcrotC6EnoylCoAMAT", "\[Rule]", "25"}], ",", 
     RowBox[{"KmcrotC4EnoylCoAMAT", "\[Rule]", "40"}], ",", 
     RowBox[{"KmcrotC16HydroxyacylCoAMAT", "\[Rule]", "45"}], ",", 
     RowBox[{"KmcrotC14HydroxyacylCoAMAT", "\[Rule]", "45"}], ",", 
     RowBox[{"KmcrotC12HydroxyacylCoAMAT", "\[Rule]", "45"}], ",", 
     RowBox[{"KmcrotC10HydroxyacylCoAMAT", "\[Rule]", "45"}], ",", 
     RowBox[{"KmcrotC8HydroxyacylCoAMAT", "\[Rule]", "45"}], ",", 
     RowBox[{"KmcrotC6HydroxyacylCoAMAT", "\[Rule]", "45"}], ",", 
     RowBox[{"KmcrotC4HydroxyacylCoAMAT", "\[Rule]", "45"}], ",", 
     RowBox[{"KicrotC4AcetoacylCoA", "\[Rule]", "1.6"}], ",", 
     RowBox[{"Keqcrot", "\[Rule]", "3.13"}], ",", "\[IndentingNewLine]", 
     RowBox[{"sfmschadC16", "\[Rule]", "0.6"}], ",", 
     RowBox[{"sfmschadC14", "\[Rule]", "0.5"}], ",", 
     RowBox[{"sfmschadC12", "\[Rule]", "0.43"}], ",", 
     RowBox[{"sfmschadC10", "\[Rule]", "0.64"}], ",", 
     RowBox[{"sfmschadC8", "\[Rule]", "0.89"}], ",", 
     RowBox[{"sfmschadC6", "\[Rule]", "1"}], ",", 
     RowBox[{"sfmschadC4", "\[Rule]", "0.67"}], ",", 
     RowBox[{"Vmschad", "\[Rule]", "1"}], ",", 
     RowBox[{"KmmschadC16HydroxyacylCoAMAT", "\[Rule]", "1.5"}], ",", 
     RowBox[{"KmmschadC14HydroxyacylCoAMAT", "\[Rule]", "1.8"}], ",", 
     RowBox[{"KmmschadC12HydroxyacylCoAMAT", "\[Rule]", "3.7"}], ",", 
     RowBox[{"KmmschadC10HydroxyacylCoAMAT", "\[Rule]", "8.8"}], ",", 
     RowBox[{"KmmschadC8HydroxyacylCoAMAT", "\[Rule]", "16.3"}], ",", 
     RowBox[{"KmmschadC6HydroxyacylCoAMAT", "\[Rule]", "28.6"}], ",", 
     RowBox[{"KmmschadC4HydroxyacylCoAMAT", "\[Rule]", "69.9"}], ",", 
     RowBox[{"KmmschadNADMAT", "\[Rule]", "58.5"}], ",", 
     RowBox[{"KmmschadC16KetoacylCoAMAT", "\[Rule]", "1.4"}], ",", 
     RowBox[{"KmmschadC14KetoacylCoAMAT", "\[Rule]", "1.4"}], ",", 
     RowBox[{"KmmschadC12KetoacylCoAMAT", "\[Rule]", "1.6"}], ",", 
     RowBox[{"KmmschadC10KetoacylCoAMAT", "\[Rule]", "2.3"}], ",", 
     RowBox[{"KmmschadC8KetoacylCoAMAT", "\[Rule]", "4.1"}], ",", 
     RowBox[{"KmmschadC6KetoacylCoAMAT", "\[Rule]", "5.8"}], ",", 
     RowBox[{"KmmschadC4AcetoacylCoAMAT", "\[Rule]", "16.9"}], ",", 
     RowBox[{"KmmschadNADHMAT", "\[Rule]", "5.4"}], ",", 
     RowBox[{"Keqmschad", "\[Rule]", 
      RowBox[{"2.17", "*", 
       SuperscriptBox["10", 
        RowBox[{"-", "4"}]]}]}], ",", "\[IndentingNewLine]", 
     RowBox[{"sfmckatC16", "\[Rule]", "0"}], ",", 
     RowBox[{"sfmckatC14", "\[Rule]", "0.2"}], ",", 
     RowBox[{"sfmckatC12", "\[Rule]", "0.38"}], ",", 
     RowBox[{"sfmckatC10", "\[Rule]", "0.65"}], ",", 
     RowBox[{"sfmckatC8", "\[Rule]", "0.81"}], ",", 
     RowBox[{"sfmckatC6", "\[Rule]", "1"}], ",", 
     RowBox[{"sfmckatC4", "\[Rule]", "0.49"}], ",", 
     RowBox[{"Vmckat", "\[Rule]", "0.377"}], ",", 
     RowBox[{"KmmckatC16KetoacylCoAMAT", "\[Rule]", "1.1"}], ",", 
     RowBox[{"KmmckatC14KetoacylCoAMAT", "\[Rule]", "1.2"}], ",", 
     RowBox[{"KmmckatC12KetoacylCoAMAT", "\[Rule]", "1.3"}], ",", 
     RowBox[{"KmmckatC10KetoacylCoAMAT", "\[Rule]", "2.1"}], ",", 
     RowBox[{"KmmckatC8KetoacylCoAMAT", "\[Rule]", "3.2"}], ",", 
     RowBox[{"KmmckatC6KetoacylCoAMAT", "\[Rule]", "6.7"}], ",", 
     RowBox[{"KmmckatC4AcetoacylCoAMAT", "\[Rule]", "12.4"}], ",", 
     RowBox[{"KmmckatCoAMAT", "\[Rule]", "26.6"}], ",", 
     RowBox[{"KmmckatC14AcylCoAMAT", "\[Rule]", "13.83"}], ",", 
     RowBox[{"KmmckatC16AcylCoAMAT", "\[Rule]", "13.83"}], ",", 
     RowBox[{"KmmckatC12AcylCoAMAT", "\[Rule]", "13.83"}], ",", 
     RowBox[{"KmmckatC10AcylCoAMAT", "\[Rule]", "13.83"}], ",", 
     RowBox[{"KmmckatC8AcylCoAMAT", "\[Rule]", "13.83"}], ",", 
     RowBox[{"KmmckatC6AcylCoAMAT", "\[Rule]", "13.83"}], ",", 
     RowBox[{"KmmckatC4AcylCoAMAT", "\[Rule]", "13.83"}], ",", 
     RowBox[{"KmmckatAcetylCoAMAT", "\[Rule]", "30"}], ",", 
     RowBox[{"Keqmckat", "\[Rule]", "1051"}], ",", "\[IndentingNewLine]", 
     RowBox[{"sfmtpC16", "\[Rule]", "1"}], ",", 
     RowBox[{"sfmtpC14", "\[Rule]", "0.9"}], ",", 
     RowBox[{"sfmtpC12", "\[Rule]", "0.81"}], ",", 
     RowBox[{"sfmtpC10", "\[Rule]", "0.73"}], ",", 
     RowBox[{"sfmtpC8", "\[Rule]", "0.34"}], ",", 
     RowBox[{"Vmtp", "\[Rule]", "2.84"}], ",", 
     RowBox[{"KmmtpC16EnoylCoAMAT", "\[Rule]", "25"}], ",", 
     RowBox[{"KmmtpC14EnoylCoAMAT", "\[Rule]", "25"}], ",", 
     RowBox[{"KmmtpC12EnoylCoAMAT", "\[Rule]", "25"}], ",", 
     RowBox[{"KmmtpC10EnoylCoAMAT", "\[Rule]", "25"}], ",", 
     RowBox[{"KmmtpC8EnoylCoAMAT", "\[Rule]", "25"}], ",", 
     RowBox[{"KmmtpNADMAT", "\[Rule]", "60"}], ",", 
     RowBox[{"KmmtpCoAMAT", "\[Rule]", "30"}], ",", 
     RowBox[{"KmmtpC14AcylCoAMAT", "\[Rule]", "13.83"}], ",", 
     RowBox[{"KmmtpC16AcylCoAMAT", "\[Rule]", "13.83"}], ",", 
     RowBox[{"KmmtpC12AcylCoAMAT", "\[Rule]", "13.83"}], ",", 
     RowBox[{"KmmtpC10AcylCoAMAT", "\[Rule]", "13.83"}], ",", 
     RowBox[{"KmmtpC8AcylCoAMAT", "\[Rule]", "13.83"}], ",", 
     RowBox[{"KmmtpC6AcylCoAMAT", "\[Rule]", "13.83"}], ",", 
     RowBox[{"KmmtpNADHMAT", "\[Rule]", "50"}], ",", 
     RowBox[{"KmmtpAcetylCoAMAT", "\[Rule]", "30"}], ",", 
     RowBox[{"Keqmtp", "\[Rule]", "0.71"}], ",", "\[IndentingNewLine]", 
     RowBox[{"Ksacesink", "\[Rule]", "6000000"}], ",", " ", 
     RowBox[{"K1acesink", "\[Rule]", "70"}], ",", 
     RowBox[{"Ksfadhsink", "\[Rule]", "6000000"}], ",", 
     RowBox[{"K1fadhsink", "\[Rule]", "0.46"}], ",", 
     RowBox[{"Ksnadhsink", "\[Rule]", "6000000"}], ",", 
     RowBox[{"K1nadhsink", "\[Rule]", "12"}], ",", "\[IndentingNewLine]", 
     RowBox[{"C16AcylCoACYT", "\[Rule]", "X"}], ",", 
     RowBox[{"CarCYT", "\[Rule]", "200"}], ",", 
     RowBox[{"CoACYT", "\[Rule]", "140"}], ",", 
     RowBox[{"MalCoACYT", "\[Rule]", "0"}], ",", 
     RowBox[{"CarMAT", "->", "950"}], ",", 
     RowBox[{"FADtMAT", "\[Rule]", "0.77"}], ",", 
     RowBox[{"NADtMAT", "\[Rule]", "250"}], ",", 
     RowBox[{"CoAMATt", "\[Rule]", "5000"}], ",", "\[IndentingNewLine]", 
     RowBox[{"VCYT", "\[Rule]", 
      RowBox[{"2.2", "*", 
       SuperscriptBox["10", 
        RowBox[{"-", "6"}]]}]}], ",", 
     RowBox[{"VMAT", "\[Rule]", 
      RowBox[{"1.8", "*", 
       SuperscriptBox["10", 
        RowBox[{"-", "6"}]]}]}], ",", "\[IndentingNewLine]", 
     RowBox[{"CE1", "\[Rule]", "50"}], ",", 
     RowBox[{"KmCE1", "\[Rule]", "50"}], ",", 
     RowBox[{"nE1", "\[Rule]", "1"}], ",", "\[IndentingNewLine]", 
     RowBox[{
      StyleBox["Vnadqo",
       Background->RGBColor[0.5843137254901961, 1., 0.5843137254901961]], 
      "\[Rule]", "0.155"}], 
     RowBox[{"(*", 
      RowBox[{"0.137", ",", "0.152", " ", ",", " ", "1.791"}], "*)"}], 
     StyleBox[",",
      Background->RGBColor[0.5843137254901961, 1., 0.5843137254901961]], 
     RowBox[{
      StyleBox["KmnadhETC",
       Background->RGBColor[0.5843137254901961, 1., 0.5843137254901961]], 
      "\[Rule]", "4.3"}], 
     StyleBox[",",
      Background->RGBColor[0.5843137254901961, 1., 0.5843137254901961]], 
     RowBox[{
      StyleBox["KmnadETC",
       Background->RGBColor[0.5843137254901961, 1., 0.5843137254901961]], 
      "\[Rule]", "780"}], ",", 
     RowBox[{
      StyleBox["VnadPDHo",
       Background->RGBColor[0.5843137254901961, 1., 0.5843137254901961]], 
      "\[Rule]", "0.127"}], 
     StyleBox[",",
      Background->RGBColor[0.5843137254901961, 1., 0.5843137254901961]], 
     RowBox[{
      StyleBox["KmnadPDH",
       Background->RGBColor[0.5843137254901961, 1., 0.5843137254901961]], 
      "\[Rule]", "60.7"}], 
     StyleBox[",",
      Background->RGBColor[0.5843137254901961, 1., 0.5843137254901961]], 
     RowBox[{
      StyleBox["KmnadhPDH",
       Background->RGBColor[0.5843137254901961, 1., 0.5843137254901961]], 
      "\[Rule]", "40"}], ",", "\[IndentingNewLine]", 
     RowBox[{"vmct1acet", "\[Rule]", "8.3"}], ",", 
     RowBox[{"kmct1acet", "\[Rule]", "1.5"}], ",", 
     RowBox[{"AcetateMAT", "\[Rule]", "Z"}], ",", 
     RowBox[{"propacetcpt1", "\[Rule]", "0.12"}], " ", ",", 
     RowBox[{"propacetsink", "\[Rule]", "0.13"}], " ", ",", 
     RowBox[{"propacetcact", "\[Rule]", "0"}], ",", 
     RowBox[{"propacetcpt2", "\[Rule]", "0"}], ",", 
     RowBox[{"propacetmal", "\[Rule]", "0"}], ",", 
     RowBox[{"propacetmckat", "\[Rule]", " ", "0"}], " ", 
     RowBox[{"(*", "0.1", "*)"}], ",", " ", 
     RowBox[{"nc", "\[Rule]", "2"}]}], "}"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"tsolScan", "[", 
     RowBox[{"X_", ",", "Z_"}], "]"}], ":=", 
    RowBox[{"NDSolve", "[", 
     RowBox[{
      RowBox[{"Join", "[", 
       RowBox[{
        RowBox[{
         RowBox[{
          RowBox[{"Odes", "/.", "RateEqs"}], "/.", "CoAMATX"}], "/.", 
         RowBox[{"ParmScan", "[", 
          RowBox[{"X", ",", "Z"}], "]"}]}], ",", "InitialConditions"}], "]"}],
       ",", "Vars", ",", 
      RowBox[{"{", 
       RowBox[{"t", ",", "0", ",", "1000000000"}], "}"}]}], "]"}]}], ";"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"SsScan", "[", 
   RowBox[{"X_", ",", "Z_"}], "]"}], ":=", 
  RowBox[{"Module", "[", 
   RowBox[{
    RowBox[{"{", "SSGuess", "}"}], ",", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"SSGuess", ":=", 
      RowBox[{"Table", "[", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{
           RowBox[{"Vars", "[", 
            RowBox[{"[", "i", "]"}], "]"}], "[", "t", "]"}], ",", 
          RowBox[{
           RowBox[{"(", 
            RowBox[{
             RowBox[{
              RowBox[{"Vars", "[", 
               RowBox[{"[", "i", "]"}], "]"}], "[", "900000000", "]"}], "/.", 
             RowBox[{"tsolScan", "[", 
              RowBox[{"X", ",", " ", "Z"}], "]"}]}], ")"}], "[", 
           RowBox[{"[", "1", "]"}], "]"}]}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"i", ",", "1", ",", 
          RowBox[{"Length", "[", "Vars", "]"}]}], "}"}]}], "]"}]}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{"FindRoot", "[", 
      RowBox[{
       RowBox[{
        RowBox[{
         RowBox[{
          RowBox[{"Table", "[", 
           RowBox[{
            RowBox[{
             RowBox[{"Odes", "[", 
              RowBox[{"[", 
               RowBox[{"i", ",", "2"}], "]"}], "]"}], "\[Equal]", "0"}], ",", 
            RowBox[{"{", 
             RowBox[{"i", ",", "1", ",", 
              RowBox[{"Length", "[", "Odes", "]"}]}], "}"}]}], "]"}], "/.", 
          "RateEqs"}], "/.", "CoAMATX"}], "/.", 
        RowBox[{"ParmScan", "[", 
         RowBox[{"X", ",", "Z"}], "]"}]}], ",", "SSGuess"}], "]"}]}]}], 
   "]"}]}]}], "Input",
 CellChangeTimes->{
  3.7372582568183627`*^9, {3.737264266656106*^9, 3.7372642670271273`*^9}, {
   3.7373558871635156`*^9, 3.7373558887286053`*^9}, {3.737356697579869*^9, 
   3.737356698143901*^9}, {3.7397895087099967`*^9, 3.739789515619392*^9}, {
   3.7397909164975176`*^9, 3.739790924024948*^9}, {3.7397920161604147`*^9, 
   3.7397920232218184`*^9}, {3.7397944232284994`*^9, 
   3.7397944280420732`*^9}, {3.739801379235865*^9, 3.7398014010071106`*^9}, {
   3.739802909410386*^9, 3.7398029201890025`*^9}, {3.739805236274475*^9, 
   3.7398052445869503`*^9}, {3.739856266375005*^9, 3.7398562742634563`*^9}, {
   3.7398574335137615`*^9, 3.7398574376189957`*^9}, {3.7398596517246356`*^9, 
   3.7398596626562605`*^9}, {3.739860264285672*^9, 3.7398602726671515`*^9}, {
   3.739862615489153*^9, 3.739862620643448*^9}, {3.745727985832075*^9, 
   3.7457279904933414`*^9}, {3.7457439978629103`*^9, 3.745744000559065*^9}, {
   3.745745884998849*^9, 3.7457458871029687`*^9}, {3.7459049717567034`*^9, 
   3.745904973208786*^9}, {3.7459070944411135`*^9, 3.7459070954511714`*^9}, {
   3.7459111140920243`*^9, 3.7459111146990595`*^9}, {3.7459132852662086`*^9, 
   3.745913285834241*^9}, {3.7459203602288733`*^9, 3.7459203616139526`*^9}, {
   3.7463586145299253`*^9, 3.7463586221153593`*^9}, {3.746375580264052*^9, 
   3.746375580721078*^9}, 3.7463776489423733`*^9, 3.746379568688177*^9, 
   3.746380210768902*^9, {3.7463816512342916`*^9, 3.7463816696963477`*^9}, {
   3.7463822311394606`*^9, 3.746382251786641*^9}, {3.7475594545049353`*^9, 
   3.747559465068555*^9}, 3.7475596115208364`*^9, 3.7475627625576477`*^9, 
   3.7475644474596653`*^9, {3.747565801320674*^9, 3.7475658015878744`*^9}, {
   3.747566770243825*^9, 3.747566798895079*^9}, 3.7483302322088785`*^9, {
   3.7483303802393456`*^9, 3.748330381325407*^9}, 3.748330439647743*^9, 
   3.7483305115108533`*^9, 3.7483308633329763`*^9, 3.748332520431757*^9, 
   3.7483338093234777`*^9, {3.7488364413823667`*^9, 3.748836483328766*^9}, {
   3.7488365181267557`*^9, 3.7488365283663416`*^9}, {3.7488366197315674`*^9, 
   3.7488366256249046`*^9}, {3.748840654124322*^9, 3.748840655451398*^9}, 
   3.7488411164537654`*^9, {3.7488412001315517`*^9, 3.7488412092070704`*^9}, {
   3.7488426181886597`*^9, 3.7488426207648067`*^9}, {3.748843677818267*^9, 
   3.7488436803814135`*^9}, {3.748847482944908*^9, 3.7488474857950706`*^9}, {
   3.7488523648471365`*^9, 3.748852367984316*^9}, 3.748852525514326*^9, {
   3.748854077008067*^9, 3.748854086670619*^9}, {3.748855026258361*^9, 
   3.748855030560607*^9}, {3.7489255703298416`*^9, 3.748925571503064*^9}, {
   3.748928238363497*^9, 3.7489282386245117`*^9}, {3.748929553073694*^9, 
   3.748929554495775*^9}, {3.7489313035408154`*^9, 3.7489313311213923`*^9}, 
   3.751955628240524*^9, 3.751955839430027*^9, {3.7519559287124324`*^9, 
   3.7519559406542597`*^9}, 3.7519756820059657`*^9, 3.7519763781542892`*^9, {
   3.7519769603568354`*^9, 3.751976967633251*^9}, {3.7523048242592626`*^9, 
   3.752304831451674*^9}, {3.752305101298108*^9, 3.752305109248563*^9}, {
   3.752305208065215*^9, 3.7523052279593525`*^9}, {3.7523052622723155`*^9, 
   3.752305275615079*^9}, {3.752305462766783*^9, 3.752305482205895*^9}, {
   3.752305701406432*^9, 3.752305702156475*^9}, {3.7523057587327113`*^9, 
   3.752305759395749*^9}, {3.752306274930236*^9, 3.75230627534426*^9}, {
   3.7523119799265146`*^9, 3.7523119842687635`*^9}, 3.7523131610669394`*^9, {
   3.752315967075471*^9, 3.7523160036359997`*^9}, {3.7523175560665894`*^9, 
   3.7523175564731903`*^9}, {3.7523180757852583`*^9, 
   3.7523180772520657`*^9}, {3.7523181678975925`*^9, 3.752318168204395*^9}, 
   3.7523183283351727`*^9, 3.7523184961127872`*^9, {3.7523192791215763`*^9, 
   3.752319279530177*^9}, {3.752319388932952*^9, 3.7523194024199967`*^9}, {
   3.752836092779971*^9, 3.752836105922723*^9}, {3.752836246372756*^9, 
   3.752836253809181*^9}, {3.752836439596808*^9, 3.7528364403448505`*^9}, {
   3.7528366928372927`*^9, 3.752836693287318*^9}, {3.752836761627227*^9, 
   3.752836766800523*^9}, {3.7528372863822412`*^9, 3.752837297290865*^9}, {
   3.7528373764923954`*^9, 3.752837384112831*^9}, 3.7528374849425983`*^9, {
   3.7528424062340803`*^9, 3.7528424292863984`*^9}, {3.7528425389206696`*^9, 
   3.7528425413678093`*^9}, {3.7528426201823173`*^9, 3.7528426206853456`*^9}, 
   3.752842984046129*^9, {3.752843042261459*^9, 3.7528430641277094`*^9}, {
   3.752907298365698*^9, 3.7529074899086533`*^9}, {3.7534385008549037`*^9, 
   3.753438524025548*^9}, {3.7540402555210457`*^9, 3.7540402695571537`*^9}, {
   3.7796905958035307`*^9, 3.7796905998899755`*^9}, {3.7796906414498997`*^9, 
   3.779690660613785*^9}, {3.779691463139037*^9, 3.7796914989491096`*^9}, {
   3.779699441460617*^9, 3.7796994433046875`*^9}, {3.7796995713646297`*^9, 
   3.779699572492614*^9}, {3.7796996840590973`*^9, 3.779699858394001*^9}, {
   3.7796999917593136`*^9, 3.7797000203446417`*^9}, {3.779701516730239*^9, 
   3.779701522651184*^9}, {3.7797726703163047`*^9, 3.7797726730867276`*^9}, {
   3.7797730211621933`*^9, 3.7797730249141636`*^9}, 3.779779012793228*^9, 
   3.7797790833975105`*^9, {3.7797938312441244`*^9, 3.7797938496658983`*^9}, {
   3.779794326847669*^9, 3.779794335993246*^9}, {3.779794374165867*^9, 
   3.7797943788163967`*^9}, {3.7797944261687403`*^9, 3.779794436264786*^9}, 
   3.7797945815817633`*^9, {3.779794936003411*^9, 3.7797949363413615`*^9}, {
   3.7798973663120375`*^9, 3.779897373207486*^9}, {3.7799877889778175`*^9, 
   3.7799878163047967`*^9}, {3.7807434146362886`*^9, 
   3.7807434391826334`*^9}, {3.7808088136100616`*^9, 
   3.7808088761637926`*^9}, {3.780827968757489*^9, 3.7808280039823465`*^9}, {
   3.7886968039122667`*^9, 3.7886968046014233`*^9}, {3.788696938226677*^9, 
   3.7886969452030115`*^9}, {3.7887635468412523`*^9, 
   3.7887635663351946`*^9}, {3.7888527540600877`*^9, 
   3.7888527542839575`*^9}, {3.7888547431429825`*^9, 3.788854745310706*^9}, 
   3.7888567563834596`*^9, {3.788862443584944*^9, 3.788862459307933*^9}, {
   3.788862492276462*^9, 3.788862523196604*^9}, 3.7888628966542387`*^9, 
   3.7888634038160577`*^9, {3.7888634854387913`*^9, 3.7888634974726915`*^9}, {
   3.7888636638120413`*^9, 3.788863699900817*^9}, 3.788864578024123*^9, {
   3.7888647708323464`*^9, 3.788864780366164*^9}, {3.7888657289169316`*^9, 
   3.788865731686945*^9}, {3.7888679369201965`*^9, 3.78886799515291*^9}, {
   3.7889386084668565`*^9, 3.788938609381317*^9}, 3.788942987962512*^9, {
   3.7889452232308226`*^9, 3.788945229486232*^9}, {3.788949702884001*^9, 
   3.78894970459999*^9}, {3.7889499025344753`*^9, 3.78894990331202*^9}, {
   3.78895033684451*^9, 3.7889503473623295`*^9}, {3.788951838952982*^9, 
   3.7889518424549265`*^9}, {3.788957932763137*^9, 3.788957934543106*^9}, {
   3.7889704036893206`*^9, 3.788970405958*^9}, {3.788972651962983*^9, 
   3.7889726529824038`*^9}, {3.7889737578036976`*^9, 
   3.7889737738984394`*^9}, {3.788974447426985*^9, 3.7889744491729803`*^9}, {
   3.7889749470225983`*^9, 3.788974948016028*^9}, {3.7889772093235016`*^9, 
   3.7889772356743474`*^9}, 3.7891026766995745`*^9, 3.7891050635395384`*^9, 
   3.789105374104636*^9, 3.7891057192836647`*^9, 3.789105760946686*^9, {
   3.789105818648796*^9, 3.7891059158965707`*^9}, {3.8126897043570137`*^9, 
   3.812689712930311*^9}, 3.813469111785546*^9, {3.813470847564352*^9, 
   3.813470850606222*^9}, {3.8134717488324575`*^9, 3.8134717527529783`*^9}, {
   3.813480787576349*^9, 3.8134807877937684`*^9}, {3.8134857887441597`*^9, 
   3.8134857902860827`*^9}, {3.813489011975174*^9, 3.8134890169239736`*^9}, 
   3.8135147638027296`*^9, 3.8135199384485345`*^9, {3.813564275471738*^9, 
   3.813564299874477*^9}, 3.8135643599957886`*^9, {3.8192063636586676`*^9, 
   3.8192063691789117`*^9}, {3.819207609300418*^9, 3.81920761087418*^9}, 
   3.819218656117777*^9, {3.8192206601751924`*^9, 3.819220676185437*^9}, {
   3.8192265438423243`*^9, 3.8192265442462187`*^9}, {3.819227776828345*^9, 
   3.8192277772731304`*^9}, {3.8192278747576003`*^9, 3.8192278756781416`*^9}, 
   3.8192281115517707`*^9},
 CellLabel->
  "In[416]:=",ExpressionUUID->"f697131a-fa4b-4a5d-9381-8be1421b406c"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"ScanDownNDSm", "[", 
    RowBox[{"Ystart_", ",", "dY_", ",", "Yend_"}], "]"}], ":=", 
   RowBox[{"Monitor", "[", 
    RowBox[{
     RowBox[{"Module", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"SS", ",", "SSGuess"}], "}"}], ",", "\[IndentingNewLine]", 
       RowBox[{
        RowBox[{"DataDownNDSfluxm", "=", 
         RowBox[{"{", "}"}]}], ";", "\[IndentingNewLine]", 
        RowBox[{"Xstart", "=", "250"}], ";", "\[IndentingNewLine]", 
        RowBox[{"Xend", "=", "0"}], ";", "\[IndentingNewLine]", 
        RowBox[{"YY", "=", 
         RowBox[{"{", 
          RowBox[{"0.0", ",", "0.9"}], "}"}]}], ";", "\[IndentingNewLine]", 
        RowBox[{"For", "[", 
         RowBox[{
          RowBox[{"Y", "=", "Ystart"}], ",", 
          RowBox[{"Y", "\[LessEqual]", " ", "Yend"}], ",", 
          "\[IndentingNewLine]", 
          RowBox[{
           RowBox[{"Z", "=", 
            RowBox[{"YY", "[", 
             RowBox[{"[", "Y", "]"}], "]"}]}], ";", "\[IndentingNewLine]", 
           RowBox[{"tsolStart", "=", 
            RowBox[{"tsolScan", "[", 
             RowBox[{"Xend", ",", "Z"}], "]"}]}], ";", "\[IndentingNewLine]", 
           RowBox[{"SSGuess", "=", 
            RowBox[{"Table", "[", 
             RowBox[{
              RowBox[{"{", 
               RowBox[{
                RowBox[{
                 RowBox[{"Vars", "[", 
                  RowBox[{"[", "i", "]"}], "]"}], "[", "t", "]"}], ",", 
                RowBox[{
                 RowBox[{"(", 
                  RowBox[{
                   RowBox[{
                    RowBox[{"Vars", "[", 
                    RowBox[{"[", "i", "]"}], "]"}], "[", "900000000", "]"}], "/.",
                    "tsolStart"}], ")"}], "[", 
                 RowBox[{"[", "1", "]"}], "]"}]}], "}"}], ",", 
              RowBox[{"{", 
               RowBox[{"i", ",", "1", ",", 
                RowBox[{"Length", "[", "Vars", "]"}]}], "}"}]}], "]"}]}], ";",
            "\[IndentingNewLine]", 
           RowBox[{"SSGuess1", "=", 
            RowBox[{"SSGuess", "[", 
             RowBox[{"[", 
              RowBox[{"All", ",", "1"}], "]"}], "]"}]}], ";", 
           "\[IndentingNewLine]", 
           RowBox[{"SSGuess2", "=", 
            RowBox[{"SSGuess", "[", 
             RowBox[{"[", 
              RowBox[{"All", ",", "2"}], "]"}], "]"}]}], ";", 
           "\[IndentingNewLine]", 
           RowBox[{"SSGuess1int", "=", 
            RowBox[{"SSGuess1", " ", "/.", " ", 
             RowBox[{"t", "\[Rule]", " ", "0"}]}]}], ";", 
           "\[IndentingNewLine]", 
           RowBox[{"InitialConditionsUD", "=", 
            RowBox[{"Thread", "[", 
             RowBox[{"SSGuess1int", "\[Equal]", "SSGuess2"}], "]"}]}], ";", 
           "\[IndentingNewLine]", 
           RowBox[{"dX", "=", "1"}], ";", "\[IndentingNewLine]", 
           RowBox[{"For", "[", 
            RowBox[{
             RowBox[{"X", "=", "250"}], ",", 
             RowBox[{"X", "\[GreaterEqual]", " ", "0"}], ",", 
             "\[IndentingNewLine]", 
             RowBox[{
              RowBox[{"tsolScanNDS", "=", 
               RowBox[{"NDSolve", "[", 
                RowBox[{
                 RowBox[{"Join", "[", 
                  RowBox[{
                   RowBox[{
                    RowBox[{
                    RowBox[{"Odes", "/.", "RateEqs"}], "/.", "CoAMATX"}], "/.", 
                    RowBox[{"ParmScan", "[", 
                    RowBox[{"X", ",", "Z"}], "]"}]}], ",", 
                   "InitialConditionsUD"}], "]"}], ",", "Vars", ",", 
                 RowBox[{"{", 
                  RowBox[{"t", ",", "0", ",", "1000000000"}], "}"}]}], 
                "]"}]}], ";", "\[IndentingNewLine]", 
              RowBox[{"SSGuess", "=", 
               RowBox[{"Table", "[", 
                RowBox[{
                 RowBox[{"{", 
                  RowBox[{
                   RowBox[{
                    RowBox[{"Vars", "[", 
                    RowBox[{"[", "i", "]"}], "]"}], "[", "t", "]"}], ",", 
                   RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"Vars", "[", 
                    RowBox[{"[", "i", "]"}], "]"}], "[", "900000000", "]"}], "/.",
                     "tsolScanNDS"}], ")"}], "[", 
                    RowBox[{"[", "1", "]"}], "]"}]}], "}"}], ",", 
                 RowBox[{"{", 
                  RowBox[{"i", ",", "1", ",", 
                   RowBox[{"Length", "[", "Vars", "]"}]}], "}"}]}], "]"}]}], 
              ";", "\[IndentingNewLine]", 
              RowBox[{"SSGuess1", "=", 
               RowBox[{"SSGuess", "[", 
                RowBox[{"[", 
                 RowBox[{"All", ",", "1"}], "]"}], "]"}]}], ";", 
              "\[IndentingNewLine]", 
              RowBox[{"SSGuess2", "=", 
               RowBox[{"SSGuess", "[", 
                RowBox[{"[", 
                 RowBox[{"All", ",", "2"}], "]"}], "]"}]}], ";", 
              "\[IndentingNewLine]", 
              RowBox[{"SSGuess1int", "=", 
               RowBox[{"SSGuess1", " ", "/.", " ", 
                RowBox[{"t", "\[Rule]", " ", "0"}]}]}], ";", 
              "\[IndentingNewLine]", 
              RowBox[{"InitialConditionsUD", "=", 
               RowBox[{"Thread", "[", 
                RowBox[{"SSGuess1int", "\[Equal]", "SSGuess2"}], "]"}]}], ";",
               "\[IndentingNewLine]", 
              RowBox[{"SS", "=", 
               RowBox[{"Thread", "[", 
                RowBox[{"SSGuess1", " ", "\[Rule]", " ", "SSGuess2"}], 
                "]"}]}], ";", "\[IndentingNewLine]", "\[IndentingNewLine]", 
              RowBox[{"AppendTo", "[", 
               RowBox[{"DataDownNDSfluxm", ",", 
                RowBox[{"{", 
                 RowBox[{"X", ",", "Z", ",", 
                  RowBox[{
                   RowBox[{
                    RowBox[{
                    RowBox[{
                    RowBox[{
                    SuperscriptBox["10", "3"], "vcpt1C16"}], "/.", " ", 
                    "RateEqs"}], "/.", "CoAMATX"}], "/.", 
                    RowBox[{"ParmScan", "[", 
                    RowBox[{"X", ",", "Z"}], "]"}]}], "/.", "SS"}]}], "}"}]}],
                "]"}], ";", "\[IndentingNewLine]", 
              RowBox[{"X", "=", 
               RowBox[{"X", "-", "dX"}]}], ";"}]}], "]"}], ";", 
           "\[IndentingNewLine]", 
           RowBox[{"Y", "=", 
            RowBox[{"Y", "+", "dY"}]}], ";"}]}], "]"}]}]}], 
      "\[IndentingNewLine]", "]"}], ",", 
     RowBox[{"ProgressIndicator", "[", 
      RowBox[{"X", ",", 
       RowBox[{"{", 
        RowBox[{"Xstart", ",", "Xend"}], "}"}]}], "]"}]}], "]"}]}], 
  "\[IndentingNewLine]"}]], "Input",
 CellChangeTimes->{{3.736788141679014*^9, 3.7367881781095824`*^9}, {
   3.756710197702388*^9, 3.7567102417969246`*^9}, {3.756710276099786*^9, 
   3.756710281073022*^9}, {3.7567105675207567`*^9, 3.7567105684997644`*^9}, {
   3.7567107977365036`*^9, 3.756710816338642*^9}, 3.756710885180159*^9, {
   3.7567145374314423`*^9, 3.756714725623253*^9}, 3.756714815941732*^9, {
   3.7567154862807584`*^9, 3.756715488212774*^9}, {3.7790265002789497`*^9, 
   3.77902653824148*^9}, 3.779082314077749*^9, {3.779082459375189*^9, 
   3.77908250737881*^9}, 3.779082547106538*^9, {3.779082587515475*^9, 
   3.779082862002206*^9}, {3.7790829122129316`*^9, 3.779082928100442*^9}, {
   3.779082970493074*^9, 3.779082999032755*^9}, {3.77908304071229*^9, 
   3.7790830547138467`*^9}, {3.77908490207189*^9, 3.779084924708357*^9}, 
   3.779085031896676*^9, {3.779085277937004*^9, 3.7790852997705774`*^9}, {
   3.779181746558349*^9, 3.779181865231035*^9}, {3.7791819671282434`*^9, 
   3.7791819778804483`*^9}, {3.779690839577142*^9, 3.7796908490623007`*^9}, {
   3.7797017068518686`*^9, 3.779701786546398*^9}, {3.7797030867715063`*^9, 
   3.7797032476498756`*^9}, {3.7797038385883207`*^9, 
   3.7797038527291594`*^9}, {3.779703902288409*^9, 3.779703902596377*^9}, {
   3.7797051309417095`*^9, 3.779705227474506*^9}, {3.779705259275175*^9, 
   3.779705286309229*^9}, {3.779706328282076*^9, 3.779706446447033*^9}, {
   3.7797064978091054`*^9, 3.779706527634452*^9}, {3.7797077049949303`*^9, 
   3.779707790494956*^9}, {3.7797078336071453`*^9, 3.7797078479400425`*^9}, {
   3.779707893988445*^9, 3.7797078980785065`*^9}, {3.780742518818121*^9, 
   3.780742532995227*^9}, {3.7807429185713573`*^9, 3.7807429295869064`*^9}, {
   3.7807638454395456`*^9, 3.7807638588230915`*^9}, {3.7808155941218543`*^9, 
   3.7808156339154963`*^9}, {3.7808157220987096`*^9, 
   3.7808158293859024`*^9}, {3.7808158818007708`*^9, 3.780815901035349*^9}, {
   3.780815953480113*^9, 3.780815953937888*^9}, {3.780816026446037*^9, 
   3.7808160381976204`*^9}, {3.780818671846259*^9, 3.7808186896556454`*^9}, {
   3.7808239588941107`*^9, 3.780823976826192*^9}, {3.78082511294524*^9, 
   3.780825125660267*^9}, {3.7808280210716286`*^9, 3.780828037129696*^9}, {
   3.7808280910246077`*^9, 3.780828104019896*^9}, {3.780830494510923*^9, 
   3.780830495705702*^9}, {3.7887635962474585`*^9, 3.788763622086873*^9}, {
   3.7888527825505147`*^9, 3.788852815250448*^9}, {3.7888625482664995`*^9, 
   3.7888625674070845`*^9}, {3.7888647235383363`*^9, 
   3.7888647275839853`*^9}, {3.8171151555774436`*^9, 3.817115160609984*^9}, {
   3.8192063763188324`*^9, 3.819206388242936*^9}, {3.8192281170640373`*^9, 
   3.819228121831329*^9}},
 CellLabel->
  "In[419]:=",ExpressionUUID->"ff18a486-2099-4d1c-8bdc-ac68431e18c9"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"ScanDownNDSm", "[", 
  RowBox[{"1", ",", "1", ",", "2"}], "]"}]], "Input",
 CellChangeTimes->{{3.7567147840758843`*^9, 3.7567147897219305`*^9}, 
   3.756715091325594*^9, 3.756715521277625*^9, 3.7567155528344593`*^9, {
   3.779181872835677*^9, 3.779181885735156*^9}, {3.7791839190857873`*^9, 
   3.7791839196153765`*^9}, {3.779184942322152*^9, 3.779184942609393*^9}, 
   3.779530834901044*^9, {3.7796908955797176`*^9, 3.7796909030662937`*^9}, {
   3.779729728221681*^9, 3.7797297323126407`*^9}, {3.7797935453353724`*^9, 
   3.779793548248839*^9}, {3.779794402792818*^9, 3.779794407393481*^9}, {
   3.7797945076212*^9, 3.7797945085956383`*^9}, {3.7808091434512005`*^9, 
   3.780809168218983*^9}, {3.780815966987998*^9, 3.7808159970765576`*^9}, 
   3.7808281069290905`*^9, 3.7887636521789284`*^9, 3.7888528234252014`*^9, 
   3.8171151659995675`*^9, {3.819206393921762*^9, 3.8192064016740413`*^9}},
 CellLabel->
  "In[420]:=",ExpressionUUID->"3565d482-20aa-466e-886c-fe66a4af1ced"],

Cell[BoxData[""], "PrintTemporary",
 GeneratedCell->False,
 CellAutoOverwrite->False,
 CellChangeTimes->{
  3.817115229904653*^9, {3.8192063924925833`*^9, 
   3.8192063953250113`*^9}},ExpressionUUID->"55efad7e-81b0-46ad-bcd0-\
fc82317914c8"]
}, Open  ]],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"ScanUpNDSm", "[", 
    RowBox[{"Ystart_", ",", "dY_", ",", "Yend_"}], "]"}], ":=", 
   RowBox[{"Monitor", "[", 
    RowBox[{
     RowBox[{"Module", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"SS", ",", "SSGuess"}], "}"}], ",", "\[IndentingNewLine]", 
       RowBox[{
        RowBox[{"DataUpNDSfluxm", "=", 
         RowBox[{"{", "}"}]}], ";", "\[IndentingNewLine]", 
        RowBox[{"Xstart", "=", "0"}], ";", "\[IndentingNewLine]", 
        RowBox[{"Xend", "=", "250"}], ";", "\[IndentingNewLine]", 
        RowBox[{"YY", "=", 
         RowBox[{"{", 
          RowBox[{"0.0", ",", "0.9"}], "}"}]}], ";", "\[IndentingNewLine]", 
        RowBox[{"For", "[", 
         RowBox[{
          RowBox[{"Y", "=", "Ystart"}], ",", 
          RowBox[{"Y", "\[LessEqual]", " ", "Yend"}], ",", 
          "\[IndentingNewLine]", 
          RowBox[{
           RowBox[{"Z", "=", 
            RowBox[{"YY", "[", 
             RowBox[{"[", "Y", "]"}], "]"}]}], ";", "\[IndentingNewLine]", 
           RowBox[{"tsolStart", "=", 
            RowBox[{"tsolScan", "[", 
             RowBox[{"Xstart", ",", "Z"}], " ", "]"}]}], ";", 
           "\[IndentingNewLine]", 
           RowBox[{"SSGuess", "=", 
            RowBox[{"Table", "[", 
             RowBox[{
              RowBox[{"{", 
               RowBox[{
                RowBox[{
                 RowBox[{"Vars", "[", 
                  RowBox[{"[", "i", "]"}], "]"}], "[", "t", "]"}], ",", 
                RowBox[{
                 RowBox[{"(", 
                  RowBox[{
                   RowBox[{
                    RowBox[{"Vars", "[", 
                    RowBox[{"[", "i", "]"}], "]"}], "[", "900000000", "]"}], "/.",
                    "tsolStart"}], ")"}], "[", 
                 RowBox[{"[", "1", "]"}], "]"}]}], "}"}], ",", 
              RowBox[{"{", 
               RowBox[{"i", ",", "1", ",", 
                RowBox[{"Length", "[", "Vars", "]"}]}], "}"}]}], "]"}]}], ";",
            "\[IndentingNewLine]", 
           RowBox[{"SSGuess1", "=", 
            RowBox[{"SSGuess", "[", 
             RowBox[{"[", 
              RowBox[{"All", ",", "1"}], "]"}], "]"}]}], ";", 
           "\[IndentingNewLine]", 
           RowBox[{"SSGuess2", "=", 
            RowBox[{"SSGuess", "[", 
             RowBox[{"[", 
              RowBox[{"All", ",", "2"}], "]"}], "]"}]}], ";", 
           "\[IndentingNewLine]", 
           RowBox[{"SSGuess1int", "=", 
            RowBox[{"SSGuess1", " ", "/.", " ", 
             RowBox[{"t", "\[Rule]", " ", "0"}]}]}], ";", 
           "\[IndentingNewLine]", 
           RowBox[{"InitialConditionsUD", "=", 
            RowBox[{"Thread", "[", 
             RowBox[{"SSGuess1int", "\[Equal]", "SSGuess2"}], "]"}]}], ";", 
           "\[IndentingNewLine]", "\[IndentingNewLine]", 
           RowBox[{"dX", "=", "1"}], ";", "\[IndentingNewLine]", 
           RowBox[{"For", "[", 
            RowBox[{
             RowBox[{"X", "=", "0"}], ",", 
             RowBox[{"X", "\[LessEqual]", " ", "250"}], ",", 
             "\[IndentingNewLine]", "\[IndentingNewLine]", 
             RowBox[{
              RowBox[{"tsolScanNDS", "=", 
               RowBox[{"NDSolve", "[", 
                RowBox[{
                 RowBox[{"Join", "[", 
                  RowBox[{
                   RowBox[{
                    RowBox[{
                    RowBox[{"Odes", "/.", "RateEqs"}], "/.", "CoAMATX"}], "/.", 
                    RowBox[{"ParmScan", "[", 
                    RowBox[{"X", ",", "Z"}], "]"}]}], ",", 
                   "InitialConditionsUD"}], "]"}], ",", "Vars", ",", 
                 RowBox[{"{", 
                  RowBox[{"t", ",", "0", ",", "1000000000"}], "}"}]}], 
                "]"}]}], ";", "\[IndentingNewLine]", 
              RowBox[{"SSGuess", "=", 
               RowBox[{"Table", "[", 
                RowBox[{
                 RowBox[{"{", 
                  RowBox[{
                   RowBox[{
                    RowBox[{"Vars", "[", 
                    RowBox[{"[", "i", "]"}], "]"}], "[", "t", "]"}], ",", 
                   RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"Vars", "[", 
                    RowBox[{"[", "i", "]"}], "]"}], "[", "900000000", "]"}], "/.",
                     "tsolScanNDS"}], ")"}], "[", 
                    RowBox[{"[", "1", "]"}], "]"}]}], "}"}], ",", 
                 RowBox[{"{", 
                  RowBox[{"i", ",", "1", ",", 
                   RowBox[{"Length", "[", "Vars", "]"}]}], "}"}]}], "]"}]}], 
              ";", "\[IndentingNewLine]", 
              RowBox[{"SSGuess1", "=", 
               RowBox[{"SSGuess", "[", 
                RowBox[{"[", 
                 RowBox[{"All", ",", "1"}], "]"}], "]"}]}], ";", 
              "\[IndentingNewLine]", 
              RowBox[{"SSGuess2", "=", 
               RowBox[{"SSGuess", "[", 
                RowBox[{"[", 
                 RowBox[{"All", ",", "2"}], "]"}], "]"}]}], ";", 
              "\[IndentingNewLine]", 
              RowBox[{"SSGuess1int", "=", 
               RowBox[{"SSGuess1", " ", "/.", " ", 
                RowBox[{"t", "\[Rule]", " ", "0"}]}]}], ";", 
              "\[IndentingNewLine]", 
              RowBox[{"InitialConditionsUD", "=", 
               RowBox[{"Thread", "[", 
                RowBox[{"SSGuess1int", "\[Equal]", "SSGuess2"}], "]"}]}], ";",
               "\[IndentingNewLine]", 
              RowBox[{"SS", "=", 
               RowBox[{"Thread", "[", 
                RowBox[{"SSGuess1", " ", "\[Rule]", " ", "SSGuess2"}], 
                "]"}]}], ";", "\[IndentingNewLine]", "\[IndentingNewLine]", 
              RowBox[{"AppendTo", "[", 
               RowBox[{"DataUpNDSfluxm", ",", 
                RowBox[{"{", 
                 RowBox[{"X", ",", "Z", ",", 
                  RowBox[{
                   RowBox[{
                    RowBox[{
                    RowBox[{
                    RowBox[{
                    SuperscriptBox["10", "3"], "vcpt1C16"}], "/.", " ", 
                    "RateEqs"}], "/.", "CoAMATX"}], "/.", 
                    RowBox[{"ParmScan", "[", 
                    RowBox[{"X", ",", "Z"}], "]"}]}], "/.", "SS"}]}], "}"}]}],
                "]"}], ";", "\[IndentingNewLine]", "\[IndentingNewLine]", 
              RowBox[{"X", "=", 
               RowBox[{"X", "+", "dX"}]}], ";"}]}], "]"}], ";", 
           "\[IndentingNewLine]", 
           RowBox[{"Y", "=", 
            RowBox[{"Y", "+", "dY"}]}], ";"}]}], "]"}]}]}], 
      "\[IndentingNewLine]", "]"}], ",", 
     RowBox[{"ProgressIndicator", "[", 
      RowBox[{"X", ",", 
       RowBox[{"{", 
        RowBox[{"Xstart", ",", "Xend"}], "}"}]}], "]"}]}], "]"}]}], 
  "\[IndentingNewLine]"}]], "Input",
 CellChangeTimes->{{3.756710311624054*^9, 3.756710323761345*^9}, {
   3.7567103873456182`*^9, 3.7567104017251234`*^9}, {3.756710505508892*^9, 
   3.7567105077645073`*^9}, {3.756710552129038*^9, 3.7567105543026533`*^9}, {
   3.756710707117408*^9, 3.7567107101804323`*^9}, {3.756714829563828*^9, 
   3.756714846822959*^9}, {3.756714880197802*^9, 3.7567148985335417`*^9}, {
   3.75671496699405*^9, 3.756715010360778*^9}, {3.756715041577416*^9, 
   3.756715042417619*^9}, {3.779085447523437*^9, 3.77908546469452*^9}, {
   3.7790855006543517`*^9, 3.7790855043365407`*^9}, {3.7791820194163694`*^9, 
   3.7791820901392374`*^9}, {3.7791823389997244`*^9, 
   3.7791823402104845`*^9}, {3.7796908605098476`*^9, 
   3.7796908706781855`*^9}, {3.7797015617533073`*^9, 3.7797015634957*^9}, {
   3.779701648971982*^9, 3.779701692278592*^9}, {3.779702607055682*^9, 
   3.7797026603071823`*^9}, {3.779702973839229*^9, 3.779703062709359*^9}, {
   3.779703266038515*^9, 3.779703321264701*^9}, {3.779703868874722*^9, 
   3.779703910815192*^9}, {3.779730613608507*^9, 3.7797306453648906`*^9}, {
   3.779730704222104*^9, 3.7797307616780963`*^9}, {3.779730868473937*^9, 
   3.779730881885948*^9}, {3.7807424458521957`*^9, 3.780742461815523*^9}, {
   3.780745381961809*^9, 3.780745390990668*^9}, {3.780808224360385*^9, 
   3.7808083402794743`*^9}, {3.780808376191495*^9, 3.7808083871162577`*^9}, {
   3.7808084694840474`*^9, 3.7808085308410397`*^9}, {3.780808575561449*^9, 
   3.780808590377838*^9}, {3.7808086534243145`*^9, 3.780808714027263*^9}, {
   3.780808763698467*^9, 3.78080879380797*^9}, {3.7808089290115037`*^9, 
   3.780808952998375*^9}, {3.7808089865736094`*^9, 3.780809035004158*^9}, {
   3.7808092903085756`*^9, 3.7808092982713194`*^9}, 3.7808094357876387`*^9, {
   3.7808094811613407`*^9, 3.780809535088162*^9}, {3.7808095919112434`*^9, 
   3.780809625227174*^9}, {3.7808131445571356`*^9, 3.7808131651870112`*^9}, {
   3.7808158584451866`*^9, 3.780815859231086*^9}, 3.7808187132595716`*^9, {
   3.780823927575838*^9, 3.780823928603092*^9}, {3.7808239860126085`*^9, 
   3.7808239969224663`*^9}, {3.780825132476022*^9, 3.780825135307455*^9}, 
   3.780828053288497*^9, {3.7808281089467173`*^9, 3.78082812145924*^9}, {
   3.7808304847031174`*^9, 3.780830485878976*^9}, 3.788763643738006*^9, 
   3.788852838883829*^9, 3.788862579082961*^9, {3.7888708988871293`*^9, 
   3.788870925567243*^9}, {3.817115171593607*^9, 3.8171151765683002`*^9}, {
   3.819206409024428*^9, 3.819206412994788*^9}, {3.8192281296015635`*^9, 
   3.8192281303016615`*^9}},
 CellLabel->
  "In[421]:=",ExpressionUUID->"b090c50a-1367-4a86-bdf0-fe9d597d794c"],

Cell[BoxData[
 RowBox[{"ScanUpNDSm", "[", 
  RowBox[{"1", ",", "1", ",", "2"}], "]"}]], "Input",
 CellChangeTimes->{{3.7567149252665405`*^9, 3.7567149256097455`*^9}, 
   3.7567150986600513`*^9, {3.7791820948227205`*^9, 3.779182103405769*^9}, {
   3.779183906553274*^9, 3.779183907030001*^9}, {3.7791849530704517`*^9, 
   3.77918495352124*^9}, 3.7795308422763104`*^9, {3.779690876955104*^9, 
   3.7796908846492715`*^9}, {3.7797309020784383`*^9, 3.779730905434429*^9}, {
   3.779897575745681*^9, 3.779897577879895*^9}, {3.7808093343219094`*^9, 
   3.7808093512436666`*^9}, {3.7808131900335555`*^9, 3.780813190881318*^9}, 
   3.7808281291157727`*^9, 3.788763656795013*^9, 3.788852864028026*^9, 
   3.817115181765401*^9, {3.8192171819528413`*^9, 3.819217184239738*^9}},
 CellLabel->
  "In[422]:=",ExpressionUUID->"2b141ae5-1563-4829-9d26-38a9e0d15195"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"p5new", "=", 
  RowBox[{"ListLinePlot", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
      RowBox[{"DataUpNDSfluxm", "[", 
       RowBox[{"[", 
        RowBox[{
         RowBox[{"1", ";;", "251"}], ",", " ", 
         RowBox[{"{", 
          RowBox[{"1", ",", "3"}], "}"}]}], "]"}], "]"}], ",", 
      RowBox[{"DataUpNDSfluxm", "[", 
       RowBox[{"[", 
        RowBox[{
         RowBox[{"252", ";;", "502"}], ",", " ", 
         RowBox[{"{", 
          RowBox[{"1", ",", "3"}], "}"}]}], "]"}], "]"}], ",", 
      RowBox[{"DataDownNDSfluxm", "[", 
       RowBox[{"[", 
        RowBox[{
         RowBox[{"1", ";;", "251"}], ",", " ", 
         RowBox[{"{", 
          RowBox[{"1", ",", "3"}], "}"}]}], "]"}], "]"}], ",", 
      RowBox[{"DataDownNDSfluxm", "[", 
       RowBox[{"[", 
        RowBox[{
         RowBox[{"252", ";;", "502"}], ",", " ", 
         RowBox[{"{", 
          RowBox[{"1", ",", "3"}], "}"}]}], "]"}], "]"}]}], "}"}], ",", 
    RowBox[{"PlotRange", "\[Rule]", "All"}], ",", " ", 
    RowBox[{"PlotStyle", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{"Red", ",", " ", "Blue", ",", "Red", ",", " ", "Blue"}], 
      "}"}]}], ",", " ", 
    RowBox[{"AxesStyle", "\[Rule]", 
     RowBox[{"Directive", "[", 
      RowBox[{"Black", ",", "16"}], "]"}]}], ",", 
    RowBox[{"LabelStyle", "\[Rule]", 
     RowBox[{"Directive", "[", "Black", "]"}]}], ",", 
    RowBox[{"PlotLegends", "\[Rule]", 
     RowBox[{"Placed", "[", 
      RowBox[{
       RowBox[{"LineLegend", "[", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{"\"\<0 mM\>\"", ",", " ", "\"\<3 mM\>\""}], "}"}], ",", 
         RowBox[{"LabelStyle", "\[Rule]", 
          RowBox[{"{", 
           RowBox[{"FontSize", "\[Rule]", "16"}], "}"}]}]}], "]"}], ",", 
       RowBox[{"{", 
        RowBox[{"Center", ",", "Bottom"}], "}"}]}], "]"}]}], ",", " ", 
    RowBox[{"PlotLabel", "\[Rule]", "\"\<Acetate levels\>\""}], ",", 
    "\[IndentingNewLine]", 
    RowBox[{"Frame", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"True", ",", "False"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"True", ",", "False"}], "}"}]}], "}"}]}], ",", 
    RowBox[{"FrameLabel", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "\"\<Uptake Flux(\[Mu]mol.\!\(\*SuperscriptBox[\(min\), \
\(-1\)]\).\!\(\*SuperscriptBox[\(gProtein\), \(-1\)]\))\>\"", ",", "None"}], 
        "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"\"\<Palmitoyl-CoA(\[Mu]M)\>\"", ",", "None"}], "}"}]}], 
      "}"}]}], ",", " ", 
    RowBox[{"BaseStyle", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"FontSize", "\[Rule]", " ", "18"}], ",", "  ", 
       RowBox[{"FontWeight", "\[Rule]", " ", "\"\<3\>\""}], ",", 
       RowBox[{"AbsoluteThickness", "[", "2", "]"}]}], "}"}]}], ",", " ", 
    RowBox[{"FrameStyle", "\[Rule]", 
     RowBox[{"Thickness", "[", "0.00005", "]"}]}], ",", " ", 
    RowBox[{"ImageSize", "\[Rule]", 
     RowBox[{"Scaled", "[", "0.30", "]"}]}], ",", " ", 
    RowBox[{"AspectRatio", "\[Rule]", "0.75"}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.8192288748664317`*^9, 3.819228915845967*^9}, {
  3.829585176277979*^9, 3.829585203837554*^9}},
 CellLabel->
  "In[423]:=",ExpressionUUID->"17267328-372c-4e07-938f-f976dd0dd588"],

Cell[BoxData[
 TagBox[
  GraphicsBox[{{{}, {{}, {}, 
      {RGBColor[1, 0, 0], PointSize[
        NCache[
         Rational[1, 120], 0.008333333333333333]], AbsoluteThickness[2], 
       StyleBox[LineBox[CompressedData["
1:eJw913s01Pkfx/HRVmTpSim3sSgpLWlbyeUVJbfkNq5hxjAzGJeVUlEGu2y1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         "]],
        FontSize->18,
        FontWeight->"3"]}, 
      {RGBColor[0, 0, 1], PointSize[
        NCache[
         Rational[1, 120], 0.008333333333333333]], AbsoluteThickness[2], 
       StyleBox[LineBox[CompressedData["
1:eJw913k81Ikfx/FJpS2rH5UcKUeSY9xnFG9XRJFz3GaMOcwYstrSYcu21ZK0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         "]],
        FontSize->18,
        FontWeight->"3"]}, 
      {RGBColor[1, 0, 0], PointSize[
        NCache[
         Rational[1, 120], 0.008333333333333333]], AbsoluteThickness[2], 
       StyleBox[LineBox[CompressedData["
1:eJw113tUzHkfB/Afiy6Ua5Ruk2pro7YLNineRLpJ96tqpqlmmqaLtGRLTbUr
WVmXbVPo9uwmZcNi3dsJmUKucaRlJyFUKKHWlsezz+c753TmvM573uf9V9/f
92cUleQbM5rjuA+f/v73/e8HSdgv/CulevjR4n/NS4Ku28DN05M7/28uCftc
fY68NiUrEzHTdGaquwNZnojJ/7zNbPIilyfCZs4M+3ghWZaIhhRnFbs0Mj8R
oiV/BvAKyEhEmlfXNrtKMi8RRYIZhgkn2H4iPCPvpLZcZfsJ2FXoxgU8YvsJ
eOcRYzdmkO0nIK+4J7td4zHtf/p9rkzQbkzmJ2C/6IDbGAcyEtB3tONooDeZ
lwDzvnLd27FkLgH5PNHIho1kpRSJKU3tHj+S5VLIgzbMc6sll0vR2R/6Q8p5
ti9FX3deUlMb25fCq1YQ4dHH9qV4xZU+/aD6hPalaHcIKLzPI3NSNBye9HeX
PVkZD0VzW5WJD1keD4tsN+sdceTyeFxM3m1plUOWxWMk+pD9PyVkfjyScu1f
fjhKRjwuqB7ptWxh+/H46pf0tp1P2X48RLI3gbO5p7QvQdyLLM1BHbJcAvHF
6tohO3K5BPnVsx9Ye5FlEpy/PzmgVEzmS8BpKJqW5pIhQTdn02dQSuZJsG1K
0xa7U2ROgpsnDwdkt7L9ONwad1dL7TXbj0Od09hdV8Z30X4ctmeoFzebkWVx
0Cu99v6zZWR+HCr91+Wm88mIg/SnnGk2G8m8OMxK6M8zLSFzcUhziv0j5ARZ
KcbTkmUV11rJcjEyG5Ta3/WzfTG8rlZOz5z0jPbF2NNos/20FZkvRl5tmWzh
SjLEcN1S9GyUlMwTY+LVgmua35M5MbjO/kXCGrJShNxUsSd3mSwXYfeXQxO7
npPLRRiT7ndAW/057YsQZKmy+CcLMl+ExzmXRvgeZIjQ+H2N/jdSMk+EK6vS
7z0qIHMiBPZ8WLv3EFkZC7O3Dk7VN8nyWFSKu/JVBsjlsXDcVnPyzPQXtP/p
9wZ5NpcWkPmxyNdZFGseTkYstjaeutUpI/NiUe+cNTz0M5mLhdTbLE3aTFbG
4NiZh385viTLY/AErx5Ip3bTfgx0kn3MR+zJshjEJ7nm9EeQ+TFITlI95/Ed
GTHgXxCfHH+QzIvBL9WVwrm3yVwMjB/r1yv+JiujMSPL855iVg/tR0NvYlHr
fA9yeTTSDcOeTU8ly6JRnD28WrKPzI/G44wpO+wUZEQjb3rpUGofmReN7S8S
jW30emk/Gh2Cn45JVpCVQswSj0o0WUuWCzHPap6loIxcLsTHIbuXxlfJMiFS
d25rSRoi84XwTt6v7mr2kvaFKCmyVD8cQOYJoXbnTnDtt2ROiDVTQuucjpGV
UagoVbyWPCbLo9BY/Ln9V1qvaD8Kd3033apyIcuiYIYM1/o0Mj8K1zeaRuXU
khEFk+hzcwYfknlR0MxMku1Ue037UeBvaFymYkJWCrDbXDX2wSKyXIAbbzZq
a4eSywV4XqGnOP01WSbATGdPneYdZL4AHSnpQy51ZAhgFFGz1/4KmSdAH2/m
95XP2L4AvYHBNfnj+mifD8fz3a5vTMhyPjL3vp/9xJlczkdFDcpihGQZH0es
dTen55L5fMQc6023+pkMPmQi0/ZNjWQeH/YNp/sKusgcH7lG9QZe6v20F4kT
sX+NuW1JlkXCQvDDpS98yYhERLiXj2A9mYtEyzi9c1v2sX4EFqqMVZy6yPoR
mHy2LXlsL+tHoL3wRuvm6W+oHwG58yrn6CVkeTgUJe4t9QlkWTgOrgxMadpD
Rjj0bHtXnrvC+uHoOPI86sUw669G3tZQ8+O2A9RfjcKG3knVEjJWIzyy4uLm
KjK3GgaaVVa5XWR5GEKOD8jzvnxL/TDoxD/41TmHjDDs1Gv3r35G5sKwzzsj
2X/HO+qH4vDldD+N40PUD0X9ua0NA3VkhMJ/+MFvNdVkLhQqC8b5WleS5SEw
rdZct2kP64cgpUP7yK8/sn4IlnRnh1UVsH4IkgLX7k3exPrBCI3ekjwhi/WD
MXP7hEMb1rN+MCZVfdQ4mcT6wbDNjzZViFg/CN2ZF9ZURbJ+EBZbWgYGBLF+
ED4OXta/7cX6QbhpNXXYwIX1A1Fz/PAUeyfWD8TbbAux/lzWD8QjL//+FgvW
D0SJ5vYdrkasHwDtR08mb53B+gEQGL23KNJg/QBUvrueJf6M9QPQ6VBSOjI4
SH1/FBTaccEvyTJ/vF5VrbK2kwx/7GndNcrrHpnzR2icyLjrKuv7ITC4aItj
A+v7wV5St9DzOOv7IdVthdG0A6zvBzWjbvWde1nfFxc3tdZe+IH1fWEiKyyu
ymF9XzRbl7nbf836vijKOjBtnYj1fRBwdtAiPIT1fdClmrX3hTvr+8Bh5K6P
riPr+6D52LTxPXNY3xsaoyXhIfqs741fw0sOR2qwvjc8v3Fw/PDPe+p7o2f2
iTHmPWTZKpSdNLjXcZ/lqzBgst/dpJnlXtiQ0v3bi99Z7gWPmW2m1j+zfCVq
PVxSXm1n+Up4lJrrGW9kuSdGDUQFNYpZ7ol3trzRN/xY7oHnHodKHRex3APS
itueY8xZ7g6z4PTzhpNZ7o6ggCvOeUP0/ydzQ+ehxBLbDjLnhgcTtSboNLHc
FdI/Vb1t6ljuilrdC7lrdrF8BdakRxpcX8/yFahSu/5oURjLXXCj+D83jjmx
3AXKItepJoYsX46Fg+tfZX5k58NyjOr+re73h+w8WQan5o2bz5xl+TL8aaqV
n1HMcmccbXD5uiuV5c5wV5tQ+8yL5UuRFpY6IjFj+VIkzgnbGTTCzrsl2F3k
fbDwNjvflkBfOipXfT/LgZ7AleOK01gOdKdqlRu5Mi/GveGKnmwt5kXYN98t
7kclO2+dMENwfob1AWZHWPgunWaexLwQmWIjPQ9bZgcoioJGC/vZ82IBJp4s
0Jx7iNkeWt6tSzPEzF+BVzE/t1+feT7uq/kUL7/OnlfzcDfh7ATdDOa5mHsm
WaHBnpecHYQVuukHL7Hnqy2C1x84tV7IbIMuS1HkH2/oPsBZ42rD/Ts5U5it
oHVqmZHCiN1P5iDXslH+2JDdlyyw4Nwf1W/V6T7FmWOqy7rlzUp2n/wcQfqL
y+6UsvutCYSxty6bLGX37VmYxH2xyUnB3j94+PzSkm/GWrD3IT1sK9o1dk8M
ez/VhuGqN3uMUzvI0zCU56Ojte8heRJuxWp4+d9rI6vC8Iuyawe/bSVzyGiL
Gnyl2UJ+vbjsy5aW4Q/1LOd6vuXSx3Mxp/8LHGLvQg==
         "]],
        FontSize->18,
        FontWeight->"3"]}, 
      {RGBColor[0, 0, 1], PointSize[
        NCache[
         Rational[1, 120], 0.008333333333333333]], AbsoluteThickness[2], 
       StyleBox[LineBox[CompressedData["
1:eJw913s01Akfx/FJpS2rh0oyKZIkxv2Skvq4RRS5jrsZYy5mMFlddFFs2xZJ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         "]],
        FontSize->18,
        FontWeight->"3"]}}, {{}, {}}}, InsetBox[
     TemplateBox[{"\"0 mM\"", "\"3 mM\""},
      "LineLegend",
      DisplayFunction->(FormBox[
        StyleBox[
         StyleBox[
          PaneBox[
           TagBox[
            GridBox[{{
               TagBox[
                GridBox[{{
                   GraphicsBox[{{
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], FontSize -> 18, FontWeight -> "3", 
                    AbsoluteThickness[2], 
                    RGBColor[1, 0, 0]], {
                    LineBox[{{0, 10}, {20, 10}}]}}, {
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], FontSize -> 18, FontWeight -> "3", 
                    AbsoluteThickness[2], 
                    RGBColor[1, 0, 0]], {}}}, AspectRatio -> Full, 
                    ImageSize -> {20, 10}, PlotRangePadding -> None, 
                    ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[-0.086] -> Baseline)], #}, {
                   GraphicsBox[{{
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], FontSize -> 18, FontWeight -> "3", 
                    AbsoluteThickness[2], 
                    RGBColor[0, 0, 1]], {
                    LineBox[{{0, 10}, {20, 10}}]}}, {
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], FontSize -> 18, FontWeight -> "3", 
                    AbsoluteThickness[2], 
                    RGBColor[0, 0, 1]], {}}}, AspectRatio -> Full, 
                    ImageSize -> {20, 10}, PlotRangePadding -> None, 
                    ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[-0.086] -> Baseline)], #2}}, 
                 GridBoxAlignment -> {
                  "Columns" -> {Center, Left}, "Rows" -> {{Baseline}}}, 
                 AutoDelete -> False, 
                 GridBoxDividers -> {
                  "Columns" -> {{False}}, "Rows" -> {{False}}}, 
                 GridBoxItemSize -> {"Columns" -> {{All}}, "Rows" -> {{All}}},
                  GridBoxSpacings -> {
                  "Columns" -> {{0.5}}, "Rows" -> {{0.8}}}], "Grid"]}}, 
             GridBoxAlignment -> {"Columns" -> {{Left}}, "Rows" -> {{Top}}}, 
             AutoDelete -> False, 
             GridBoxItemSize -> {
              "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
             GridBoxSpacings -> {"Columns" -> {{1}}, "Rows" -> {{0}}}], 
            "Grid"], Alignment -> Left, AppearanceElements -> None, 
           ImageMargins -> {{5, 5}, {5, 5}}, ImageSizeAction -> 
           "ResizeToFit"], LineIndent -> 0, StripOnInput -> False], {
         FontSize -> 16, FontFamily -> "Arial"}, Background -> Automatic, 
         StripOnInput -> False], TraditionalForm]& ),
      Editable->True,
      InterpretationFunction:>(RowBox[{"LineLegend", "[", 
         RowBox[{
           RowBox[{"{", 
             RowBox[{
               RowBox[{"Directive", "[", 
                 RowBox[{
                   RowBox[{"PointSize", "[", 
                    FractionBox["1", "120"], "]"}], ",", 
                   RowBox[{"FontSize", "\[Rule]", "18"}], ",", 
                   RowBox[{"FontWeight", "\[Rule]", "\"3\""}], ",", 
                   RowBox[{"AbsoluteThickness", "[", "2", "]"}], ",", 
                   InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, DefaultBaseStyle -> 
                    "ColorSwatchGraphics", AspectRatio -> 1, Frame -> True, 
                    FrameStyle -> RGBColor[0.6666666666666666, 0., 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{
                    Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], 
                    StyleBox[
                    RowBox[{"RGBColor", "[", 
                    RowBox[{"1", ",", "0", ",", "0"}], "]"}], NumberMarks -> 
                    False]], Appearance -> None, BaseStyle -> {}, 
                    BaselinePosition -> Baseline, DefaultBaseStyle -> {}, 
                    ButtonFunction :> With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0, 0], Editable -> False, Selectable -> 
                    False]}], "]"}], ",", 
               RowBox[{"Directive", "[", 
                 RowBox[{
                   RowBox[{"PointSize", "[", 
                    FractionBox["1", "120"], "]"}], ",", 
                   RowBox[{"FontSize", "\[Rule]", "18"}], ",", 
                   RowBox[{"FontWeight", "\[Rule]", "\"3\""}], ",", 
                   RowBox[{"AbsoluteThickness", "[", "2", "]"}], ",", 
                   InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[0, 0, 1], 
                    RectangleBox[{0, -1}, {2, 1}]}}, DefaultBaseStyle -> 
                    "ColorSwatchGraphics", AspectRatio -> 1, Frame -> True, 
                    FrameStyle -> RGBColor[0., 0., 0.6666666666666666], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{
                    Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], 
                    StyleBox[
                    RowBox[{"RGBColor", "[", 
                    RowBox[{"0", ",", "0", ",", "1"}], "]"}], NumberMarks -> 
                    False]], Appearance -> None, BaseStyle -> {}, 
                    BaselinePosition -> Baseline, DefaultBaseStyle -> {}, 
                    ButtonFunction :> With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[0, 0, 1]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[0, 0, 1], Editable -> False, Selectable -> 
                    False]}], "]"}], ",", 
               RowBox[{"Directive", "[", 
                 RowBox[{
                   RowBox[{"PointSize", "[", 
                    FractionBox["1", "120"], "]"}], ",", 
                   RowBox[{"FontSize", "\[Rule]", "18"}], ",", 
                   RowBox[{"FontWeight", "\[Rule]", "\"3\""}], ",", 
                   RowBox[{"AbsoluteThickness", "[", "2", "]"}], ",", 
                   InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, DefaultBaseStyle -> 
                    "ColorSwatchGraphics", AspectRatio -> 1, Frame -> True, 
                    FrameStyle -> RGBColor[0.6666666666666666, 0., 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{
                    Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], 
                    StyleBox[
                    RowBox[{"RGBColor", "[", 
                    RowBox[{"1", ",", "0", ",", "0"}], "]"}], NumberMarks -> 
                    False]], Appearance -> None, BaseStyle -> {}, 
                    BaselinePosition -> Baseline, DefaultBaseStyle -> {}, 
                    ButtonFunction :> With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0, 0], Editable -> False, Selectable -> 
                    False]}], "]"}], ",", 
               RowBox[{"Directive", "[", 
                 RowBox[{
                   RowBox[{"PointSize", "[", 
                    FractionBox["1", "120"], "]"}], ",", 
                   RowBox[{"FontSize", "\[Rule]", "18"}], ",", 
                   RowBox[{"FontWeight", "\[Rule]", "\"3\""}], ",", 
                   RowBox[{"AbsoluteThickness", "[", "2", "]"}], ",", 
                   InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[0, 0, 1], 
                    RectangleBox[{0, -1}, {2, 1}]}}, DefaultBaseStyle -> 
                    "ColorSwatchGraphics", AspectRatio -> 1, Frame -> True, 
                    FrameStyle -> RGBColor[0., 0., 0.6666666666666666], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{
                    Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], 
                    StyleBox[
                    RowBox[{"RGBColor", "[", 
                    RowBox[{"0", ",", "0", ",", "1"}], "]"}], NumberMarks -> 
                    False]], Appearance -> None, BaseStyle -> {}, 
                    BaselinePosition -> Baseline, DefaultBaseStyle -> {}, 
                    ButtonFunction :> With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[0, 0, 1]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[0, 0, 1], Editable -> False, Selectable -> 
                    False]}], "]"}]}], "}"}], ",", 
           RowBox[{"{", 
             RowBox[{#, ",", #2}], "}"}], ",", 
           RowBox[{"LegendMarkers", "\[Rule]", 
             RowBox[{"{", 
               RowBox[{
                 RowBox[{"{", 
                   RowBox[{"False", ",", "Automatic"}], "}"}], ",", 
                 RowBox[{"{", 
                   RowBox[{"False", ",", "Automatic"}], "}"}]}], "}"}]}], ",", 
           RowBox[{"Joined", "\[Rule]", 
             RowBox[{"{", 
               RowBox[{"True", ",", "True", ",", "True", ",", "True"}], 
               "}"}]}], ",", 
           RowBox[{"LabelStyle", "\[Rule]", 
             RowBox[{"{", 
               RowBox[{"FontSize", "\[Rule]", "16"}], "}"}]}], ",", 
           RowBox[{"LegendLayout", "\[Rule]", "\"Column\""}]}], "]"}]& )], 
     Scaled[{0.5, 0.01}], ImageScaled[{0.5, 0}],
     BaseStyle->{FontSize -> Larger},
     FormatType->StandardForm]},
   AspectRatio->0.75,
   Axes->{True, True},
   AxesLabel->{None, None},
   AxesOrigin->{0, 0},
   AxesStyle->Directive[
     GrayLevel[0], 16],
   BaseStyle->{FontSize -> 18, FontWeight -> "3", 
     AbsoluteThickness[2]},
   DisplayFunction->Identity,
   Frame->{{True, False}, {True, False}},
   FrameLabel->{{
      FormBox[
      "\"Uptake Flux(\[Mu]mol.\\!\\(\\*SuperscriptBox[\\(min\\), \
\\(-1\\)]\\).\\!\\(\\*SuperscriptBox[\\(gProtein\\), \\(-1\\)]\\))\"", 
       TraditionalForm], None}, {
      FormBox["\"Palmitoyl-CoA(\[Mu]M)\"", TraditionalForm], None}},
   FrameStyle->Thickness[0.00005],
   FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
   GridLines->{None, None},
   GridLinesStyle->Directive[
     GrayLevel[0.5, 0.4]],
   ImageSize->Scaled[0.3],
   LabelStyle->Directive[
     GrayLevel[0]],
   Method->{
    "OptimizePlotMarkers" -> True, "OptimizePlotMarkers" -> True, 
     "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
         Identity[
          Part[#, 1]], 
         Identity[
          Part[#, 2]]}& ), "CopiedValueFunction" -> ({
         Identity[
          Part[#, 1]], 
         Identity[
          Part[#, 2]]}& )}},
   PlotLabel->FormBox["\"Acetate levels\"", TraditionalForm],
   PlotRange->{{0, 250.}, {-6.345373269780379*^-25, 2.5295263434365}},
   PlotRangeClipping->True,
   PlotRangePadding->{{
      Scaled[0.02], 
      Scaled[0.02]}, {
      Scaled[0.05], 
      Scaled[0.05]}},
   Ticks->{Automatic, Automatic}],
  InterpretTemplate[Legended[
    Graphics[{{}, {{{}, {}, {
         Hue[0.67, 0.6, 0.6], 
         Directive[
          PointSize[
           Rational[1, 120]], FontSize -> 18, FontWeight -> "3", 
          AbsoluteThickness[2], 
          RGBColor[1, 0, 0]], 
         Line[CompressedData["
1:eJw913s01Pkfx/HRVmTpSim3sSgpLWlbyeUVJbfkNq5hxjAzGJeVUlEGu2y1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          "]]}, {
         Hue[0.9060679774997897, 0.6, 0.6], 
         Directive[
          PointSize[
           Rational[1, 120]], FontSize -> 18, FontWeight -> "3", 
          AbsoluteThickness[2], 
          RGBColor[0, 0, 1]], 
         Line[CompressedData["
1:eJw913k81Ikfx/FJpS2rH5UcKUeSY9xnFG9XRJFz3GaMOcwYstrSYcu21ZK0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          "]]}, {
         Hue[0.1421359549995791, 0.6, 0.6], 
         Directive[
          PointSize[
           Rational[1, 120]], FontSize -> 18, FontWeight -> "3", 
          AbsoluteThickness[2], 
          RGBColor[1, 0, 0]], 
         Line[CompressedData["
1:eJw113tUzHkfB/Afiy6Ua5Ruk2pro7YLNineRLpJ96tqpqlmmqaLtGRLTbUr
WVmXbVPo9uwmZcNi3dsJmUKucaRlJyFUKKHWlsezz+c753TmvM573uf9V9/f
92cUleQbM5rjuA+f/v73/e8HSdgv/CulevjR4n/NS4Ku28DN05M7/28uCftc
fY68NiUrEzHTdGaquwNZnojJ/7zNbPIilyfCZs4M+3ghWZaIhhRnFbs0Mj8R
oiV/BvAKyEhEmlfXNrtKMi8RRYIZhgkn2H4iPCPvpLZcZfsJ2FXoxgU8YvsJ
eOcRYzdmkO0nIK+4J7td4zHtf/p9rkzQbkzmJ2C/6IDbGAcyEtB3tONooDeZ
lwDzvnLd27FkLgH5PNHIho1kpRSJKU3tHj+S5VLIgzbMc6sll0vR2R/6Q8p5
ti9FX3deUlMb25fCq1YQ4dHH9qV4xZU+/aD6hPalaHcIKLzPI3NSNBye9HeX
PVkZD0VzW5WJD1keD4tsN+sdceTyeFxM3m1plUOWxWMk+pD9PyVkfjyScu1f
fjhKRjwuqB7ptWxh+/H46pf0tp1P2X48RLI3gbO5p7QvQdyLLM1BHbJcAvHF
6tohO3K5BPnVsx9Ye5FlEpy/PzmgVEzmS8BpKJqW5pIhQTdn02dQSuZJsG1K
0xa7U2ROgpsnDwdkt7L9ONwad1dL7TXbj0Od09hdV8Z30X4ctmeoFzebkWVx
0Cu99v6zZWR+HCr91+Wm88mIg/SnnGk2G8m8OMxK6M8zLSFzcUhziv0j5ARZ
KcbTkmUV11rJcjEyG5Ta3/WzfTG8rlZOz5z0jPbF2NNos/20FZkvRl5tmWzh
SjLEcN1S9GyUlMwTY+LVgmua35M5MbjO/kXCGrJShNxUsSd3mSwXYfeXQxO7
npPLRRiT7ndAW/057YsQZKmy+CcLMl+ExzmXRvgeZIjQ+H2N/jdSMk+EK6vS
7z0qIHMiBPZ8WLv3EFkZC7O3Dk7VN8nyWFSKu/JVBsjlsXDcVnPyzPQXtP/p
9wZ5NpcWkPmxyNdZFGseTkYstjaeutUpI/NiUe+cNTz0M5mLhdTbLE3aTFbG
4NiZh385viTLY/AErx5Ip3bTfgx0kn3MR+zJshjEJ7nm9EeQ+TFITlI95/Ed
GTHgXxCfHH+QzIvBL9WVwrm3yVwMjB/r1yv+JiujMSPL855iVg/tR0NvYlHr
fA9yeTTSDcOeTU8ly6JRnD28WrKPzI/G44wpO+wUZEQjb3rpUGofmReN7S8S
jW30emk/Gh2Cn45JVpCVQswSj0o0WUuWCzHPap6loIxcLsTHIbuXxlfJMiFS
d25rSRoi84XwTt6v7mr2kvaFKCmyVD8cQOYJoXbnTnDtt2ROiDVTQuucjpGV
UagoVbyWPCbLo9BY/Ln9V1qvaD8Kd3033apyIcuiYIYM1/o0Mj8K1zeaRuXU
khEFk+hzcwYfknlR0MxMku1Ue037UeBvaFymYkJWCrDbXDX2wSKyXIAbbzZq
a4eSywV4XqGnOP01WSbATGdPneYdZL4AHSnpQy51ZAhgFFGz1/4KmSdAH2/m
95XP2L4AvYHBNfnj+mifD8fz3a5vTMhyPjL3vp/9xJlczkdFDcpihGQZH0es
dTen55L5fMQc6023+pkMPmQi0/ZNjWQeH/YNp/sKusgcH7lG9QZe6v20F4kT
sX+NuW1JlkXCQvDDpS98yYhERLiXj2A9mYtEyzi9c1v2sX4EFqqMVZy6yPoR
mHy2LXlsL+tHoL3wRuvm6W+oHwG58yrn6CVkeTgUJe4t9QlkWTgOrgxMadpD
Rjj0bHtXnrvC+uHoOPI86sUw669G3tZQ8+O2A9RfjcKG3knVEjJWIzyy4uLm
KjK3GgaaVVa5XWR5GEKOD8jzvnxL/TDoxD/41TmHjDDs1Gv3r35G5sKwzzsj
2X/HO+qH4vDldD+N40PUD0X9ua0NA3VkhMJ/+MFvNdVkLhQqC8b5WleS5SEw
rdZct2kP64cgpUP7yK8/sn4IlnRnh1UVsH4IkgLX7k3exPrBCI3ekjwhi/WD
MXP7hEMb1rN+MCZVfdQ4mcT6wbDNjzZViFg/CN2ZF9ZURbJ+EBZbWgYGBLF+
ED4OXta/7cX6QbhpNXXYwIX1A1Fz/PAUeyfWD8TbbAux/lzWD8QjL//+FgvW
D0SJ5vYdrkasHwDtR08mb53B+gEQGL23KNJg/QBUvrueJf6M9QPQ6VBSOjI4
SH1/FBTaccEvyTJ/vF5VrbK2kwx/7GndNcrrHpnzR2icyLjrKuv7ITC4aItj
A+v7wV5St9DzOOv7IdVthdG0A6zvBzWjbvWde1nfFxc3tdZe+IH1fWEiKyyu
ymF9XzRbl7nbf836vijKOjBtnYj1fRBwdtAiPIT1fdClmrX3hTvr+8Bh5K6P
riPr+6D52LTxPXNY3xsaoyXhIfqs741fw0sOR2qwvjc8v3Fw/PDPe+p7o2f2
iTHmPWTZKpSdNLjXcZ/lqzBgst/dpJnlXtiQ0v3bi99Z7gWPmW2m1j+zfCVq
PVxSXm1n+Up4lJrrGW9kuSdGDUQFNYpZ7ol3trzRN/xY7oHnHodKHRex3APS
itueY8xZ7g6z4PTzhpNZ7o6ggCvOeUP0/ydzQ+ehxBLbDjLnhgcTtSboNLHc
FdI/Vb1t6ljuilrdC7lrdrF8BdakRxpcX8/yFahSu/5oURjLXXCj+D83jjmx
3AXKItepJoYsX46Fg+tfZX5k58NyjOr+re73h+w8WQan5o2bz5xl+TL8aaqV
n1HMcmccbXD5uiuV5c5wV5tQ+8yL5UuRFpY6IjFj+VIkzgnbGTTCzrsl2F3k
fbDwNjvflkBfOipXfT/LgZ7AleOK01gOdKdqlRu5Mi/GveGKnmwt5kXYN98t
7kclO2+dMENwfob1AWZHWPgunWaexLwQmWIjPQ9bZgcoioJGC/vZ82IBJp4s
0Jx7iNkeWt6tSzPEzF+BVzE/t1+feT7uq/kUL7/OnlfzcDfh7ATdDOa5mHsm
WaHBnpecHYQVuukHL7Hnqy2C1x84tV7IbIMuS1HkH2/oPsBZ42rD/Ts5U5it
oHVqmZHCiN1P5iDXslH+2JDdlyyw4Nwf1W/V6T7FmWOqy7rlzUp2n/wcQfqL
y+6UsvutCYSxty6bLGX37VmYxH2xyUnB3j94+PzSkm/GWrD3IT1sK9o1dk8M
ez/VhuGqN3uMUzvI0zCU56Ojte8heRJuxWp4+d9rI6vC8Iuyawe/bSVzyGiL
Gnyl2UJ+vbjsy5aW4Q/1LOd6vuXSx3Mxp/8LHGLvQg==
          "]]}, {
         Hue[0.37820393249936934`, 0.6, 0.6], 
         Directive[
          PointSize[
           Rational[1, 120]], FontSize -> 18, FontWeight -> "3", 
          AbsoluteThickness[2], 
          RGBColor[0, 0, 1]], 
         Line[CompressedData["
1:eJw913s01Akfx/FJpS2rh0oyKZIkxv2Skvq4RRS5jrsZYy5mMFlddFFs2xZJ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          "]]}}}, {{}, {}}}, {
     DisplayFunction -> Identity, DisplayFunction -> Identity, AspectRatio -> 
      0.75, Axes -> {True, True}, AxesLabel -> {None, None}, 
      AxesOrigin -> {0, 0}, AxesStyle -> Directive[
        GrayLevel[0], 16], BaseStyle -> {FontSize -> 18, FontWeight -> "3", 
        AbsoluteThickness[2]}, DisplayFunction :> Identity, 
      Frame -> {{True, False}, {True, False}}, 
      FrameLabel -> {{
        "Uptake Flux(\[Mu]mol.\!\(\*SuperscriptBox[\(min\), \
\(-1\)]\).\!\(\*SuperscriptBox[\(gProtein\), \(-1\)]\))", None}, {
        "Palmitoyl-CoA(\[Mu]M)", None}}, FrameStyle -> Thickness[0.00005], 
      FrameTicks -> {{Automatic, Automatic}, {Automatic, Automatic}}, 
      GridLines -> {None, None}, GridLinesStyle -> Directive[
        GrayLevel[0.5, 0.4]], ImageSize -> Scaled[0.3], LabelStyle -> 
      Directive[
        GrayLevel[0]], 
      Method -> {
       "OptimizePlotMarkers" -> True, "OptimizePlotMarkers" -> True, 
        "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
            Identity[
             Part[#, 1]], 
            Identity[
             Part[#, 2]]}& ), "CopiedValueFunction" -> ({
            Identity[
             Part[#, 1]], 
            Identity[
             Part[#, 2]]}& )}}, PlotLabel -> "Acetate levels", 
      PlotRange -> {{0, 250.}, {-6.345373269780379*^-25, 2.5295263434365}}, 
      PlotRangeClipping -> True, PlotRangePadding -> {{
         Scaled[0.02], 
         Scaled[0.02]}, {
         Scaled[0.05], 
         Scaled[0.05]}}, Ticks -> {Automatic, Automatic}}], 
    Placed[
     Unevaluated[
      LineLegend[{
        Directive[
         PointSize[
          Rational[1, 120]], FontSize -> 18, FontWeight -> "3", 
         AbsoluteThickness[2], 
         RGBColor[1, 0, 0]], 
        Directive[
         PointSize[
          Rational[1, 120]], FontSize -> 18, FontWeight -> "3", 
         AbsoluteThickness[2], 
         RGBColor[0, 0, 1]], 
        Directive[
         PointSize[
          Rational[1, 120]], FontSize -> 18, FontWeight -> "3", 
         AbsoluteThickness[2], 
         RGBColor[1, 0, 0]], 
        Directive[
         PointSize[
          Rational[1, 120]], FontSize -> 18, FontWeight -> "3", 
         AbsoluteThickness[2], 
         RGBColor[0, 0, 1]]}, {"0 mM", "3 mM"}, 
       LegendMarkers -> {{False, Automatic}, {False, Automatic}}, 
       Joined -> {True, True, True, True}, LabelStyle -> {FontSize -> 16}, 
       LegendLayout -> "Column"]], {Center, Bottom}, Identity]]& ],
  AutoDelete->True,
  Editable->True,
  SelectWithContents->False,
  Selectable->True]], "Output",
 CellChangeTimes->{
  3.8192274694261312`*^9, 3.819228787363639*^9, {3.8192288801772385`*^9, 
   3.8192289201184974`*^9}, 3.8295868139863896`*^9},
 CellLabel->
  "Out[423]=",ExpressionUUID->"8c81c34f-e1fe-4832-a55c-d053755fa0ca"]
}, Open  ]]
}, Open  ]]
},
WindowSize->{1350, 669},
WindowMargins->{{0, Automatic}, {Automatic, 0}},
Magnification:>1.1 Inherited,
FrontEndVersion->"12.2 for Microsoft Windows (64-bit) (December 12, 2020)",
StyleDefinitions->"Default.nb",
ExpressionUUID->"cc642700-3cfb-45df-9ffd-158f6ba7b941"
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{}
*)
(*CellTagsIndex
CellTagsIndex->{}
*)
(*NotebookFileOutline
Notebook[{
Cell[CellGroupData[{
Cell[580, 22, 450, 9, 127, "Section",ExpressionUUID->"49094d9c-edae-41e2-91f5-4c7cb9638d14"],
Cell[1033, 33, 848, 13, 123, "Text",ExpressionUUID->"c6166c54-c9d0-4d06-9d3d-8a939d8a0f72"],
Cell[1884, 48, 1608, 41, 102, "Input",ExpressionUUID->"65d74be1-bddb-4b2c-b6c0-8b394e0dc692"],
Cell[3495, 91, 228, 4, 32, "Input",ExpressionUUID->"35c681e9-f798-4ea9-8810-4a0e39bbc00f"],
Cell[3726, 97, 1513, 40, 102, "Input",ExpressionUUID->"1154a7ed-f6cf-40a7-b435-09f31129a382"],
Cell[5242, 139, 2158, 51, 124, "Input",ExpressionUUID->"44cc4dc8-fa5f-47a6-a1fc-480ead1af464"],
Cell[7403, 192, 1537, 40, 102, "Input",ExpressionUUID->"644e2d1f-80ac-4d10-b6fc-adf6ed462cc1"],
Cell[8943, 234, 1757, 45, 102, "Input",ExpressionUUID->"51490068-d40f-4616-afe6-8ed7767bc8bc"],
Cell[10703, 281, 1778, 45, 102, "Input",ExpressionUUID->"b4ab62a6-33b7-4b16-bcca-c53ae51a2133"],
Cell[12484, 328, 1361, 37, 76, "Input",ExpressionUUID->"fb4a3454-74fb-44e6-9746-3615c64a5631"],
Cell[13848, 367, 1725, 39, 99, "Input",ExpressionUUID->"7af20f79-2684-4fd7-8398-bdd9448680d0"],
Cell[15576, 408, 1987, 50, 124, "Input",ExpressionUUID->"2ade593c-e4c0-478d-8eaf-e9c919d9d895"],
Cell[17566, 460, 2335, 55, 138, "Input",ExpressionUUID->"695562d8-b36a-498c-95db-6427d4bd7804"],
Cell[19904, 517, 2530, 64, 138, "Input",ExpressionUUID->"b21983fb-49f4-4b07-a762-697409a383a1"],
Cell[22437, 583, 2399, 58, 141, "Input",ExpressionUUID->"16b71fc7-21dd-430e-9168-ea4efa2a7c67"],
Cell[24839, 643, 365, 10, 32, "Input",ExpressionUUID->"ab492a5b-8f88-4459-96cd-bbc045bded9a"],
Cell[25207, 655, 1171, 27, 71, "Input",ExpressionUUID->"365dfb41-a139-4fa6-b04a-83da663bb56a"],
Cell[26381, 684, 668, 17, 71, "Input",ExpressionUUID->"80bd1703-6837-4bbf-8fb5-cc2b56d1e596"],
Cell[27052, 703, 153, 3, 32, "Input",ExpressionUUID->"64ec67f6-8148-4e6b-9239-c99870f00ba4"],
Cell[27208, 708, 337, 6, 50, "Text",ExpressionUUID->"b53fc1ed-147a-4f3c-a559-1266eee3f57d"],
Cell[27548, 716, 153369, 2671, 9714, "Input",ExpressionUUID->"bb39335b-4973-40e2-8a87-741dcdc582c9"],
Cell[180920, 3389, 2344, 42, 121, "Input",ExpressionUUID->"22429411-4fbc-4beb-a65d-a8e8f6400bbe"],
Cell[183267, 3433, 2222, 40, 55, "Input",ExpressionUUID->"88e9e9e0-bdd0-4f01-ba8c-a8d210f0ff5a"],
Cell[CellGroupData[{
Cell[185514, 3477, 642, 20, 32, "Input",ExpressionUUID->"1d982bc7-c127-4a22-a28e-2f8658319885"],
Cell[186159, 3499, 6021, 187, 257, "Output",ExpressionUUID->"d39dba12-0f7e-4753-8ae8-2455e22b2995"]
}, Open  ]],
Cell[192195, 3689, 412, 8, 45, "Text",ExpressionUUID->"06a5e6a9-cf9a-4bff-80a4-19a9af448635"],
Cell[192610, 3699, 26716, 472, 1291, "Input",ExpressionUUID->"f697131a-fa4b-4a5d-9381-8be1421b406c"],
Cell[219329, 4173, 9461, 195, 641, "Input",ExpressionUUID->"ff18a486-2099-4d1c-8bdc-ac68431e18c9"],
Cell[CellGroupData[{
Cell[228815, 4372, 1001, 15, 32, "Input",ExpressionUUID->"3565d482-20aa-466e-886c-fe66a4af1ced"],
Cell[229819, 4389, 241, 6, 23, "PrintTemporary",ExpressionUUID->"55efad7e-81b0-46ad-bcd0-fc82317914c8"]
}, Open  ]],
Cell[230075, 4398, 9405, 194, 707, "Input",ExpressionUUID->"b090c50a-1367-4a86-bdf0-fe9d597d794c"],
Cell[239483, 4594, 848, 13, 32, "Input",ExpressionUUID->"2b141ae5-1563-4829-9d26-38a9e0d15195"],
Cell[CellGroupData[{
Cell[240356, 4611, 3321, 86, 149, "Input",ExpressionUUID->"17267328-372c-4e07-938f-f976dd0dd588"],
Cell[243680, 4699, 47233, 898, 387, "Output",ExpressionUUID->"8c81c34f-e1fe-4832-a55c-d053755fa0ca"]
}, Open  ]]
}, Open  ]]
}
]
*)

